Class: Plaid::AccountIdentityMatchScore
- Inherits:
-
Object
- Object
- Plaid::AccountIdentityMatchScore
- Defined in:
- lib/plaid/models/account_identity_match_score.rb
Overview
Identity match scores for an account
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Plaid’s unique identifier for the account.
-
#address ⇒ Object
Returns the value of attribute address.
-
#balances ⇒ Object
Returns the value of attribute balances.
-
#email_address ⇒ Object
Returns the value of attribute email_address.
-
#holder_category ⇒ Object
Returns the value of attribute holder_category.
-
#legal_name ⇒ Object
Returns the value of attribute legal_name.
-
#mask ⇒ Object
Returns the value of attribute mask.
-
#name ⇒ Object
Returns the value of attribute name.
-
#official_name ⇒ Object
Returns the value of attribute official_name.
-
#persistent_account_id ⇒ Object
A unique and persistent identifier for accounts that can be used to trace multiple instances of the same account across different Items for depository accounts.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#subtype ⇒ Object
Returns the value of attribute subtype.
-
#type ⇒ Object
Returns the value of attribute type.
-
#verification_insights ⇒ Object
Returns the value of attribute verification_insights.
-
#verification_name ⇒ Object
Returns the value of attribute verification_name.
-
#verification_status ⇒ Object
Indicates an Item’s micro-deposit-based verification or database verification status.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AccountIdentityMatchScore
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AccountIdentityMatchScore
Initializes the object
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 149 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::AccountIdentityMatchScore` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::AccountIdentityMatchScore`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'balances') self.balances = attributes[:'balances'] end if attributes.key?(:'mask') self.mask = attributes[:'mask'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'official_name') self.official_name = attributes[:'official_name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'subtype') self.subtype = attributes[:'subtype'] end if attributes.key?(:'verification_status') self.verification_status = attributes[:'verification_status'] end if attributes.key?(:'verification_name') self.verification_name = attributes[:'verification_name'] end if attributes.key?(:'verification_insights') self.verification_insights = attributes[:'verification_insights'] end if attributes.key?(:'persistent_account_id') self.persistent_account_id = attributes[:'persistent_account_id'] end if attributes.key?(:'holder_category') self.holder_category = attributes[:'holder_category'] end if attributes.key?(:'legal_name') self.legal_name = attributes[:'legal_name'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'address') self.address = attributes[:'address'] end end |
Instance Attribute Details
#account_id ⇒ Object
Plaid’s unique identifier for the account. This value will not change unless Plaid can’t reconcile the account with the data returned by the financial institution. This may occur, for example, when the name of the account changes. If this happens a new ‘account_id` will be assigned to the account. The `account_id` can also change if the `access_token` is deleted and the same credentials that were used to generate that `access_token` are used to generate a new `access_token` on a later date. In that case, the new `account_id` will be different from the old `account_id`. If an account with a specific `account_id` disappears instead of changing, the account is likely closed. Closed accounts are not returned by the Plaid API. When using a CRA endpoint (an endpoint associated with Plaid Check Consumer Report, i.e. any endpoint beginning with `/cra/`), the `account_id` returned will not match the `account_id` returned by a non-CRA endpoint. Like all Plaid identifiers, the `account_id` is case sensitive.
20 21 22 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 20 def account_id @account_id end |
#address ⇒ Object
Returns the value of attribute address.
52 53 54 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 52 def address @address end |
#balances ⇒ Object
Returns the value of attribute balances.
22 23 24 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 22 def balances @balances end |
#email_address ⇒ Object
Returns the value of attribute email_address.
50 51 52 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 50 def email_address @email_address end |
#holder_category ⇒ Object
Returns the value of attribute holder_category.
44 45 46 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 44 def holder_category @holder_category end |
#legal_name ⇒ Object
Returns the value of attribute legal_name.
46 47 48 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 46 def legal_name @legal_name end |
#mask ⇒ Object
Returns the value of attribute mask.
24 25 26 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 24 def mask @mask end |
#name ⇒ Object
Returns the value of attribute name.
26 27 28 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 26 def name @name end |
#official_name ⇒ Object
Returns the value of attribute official_name.
28 29 30 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 28 def official_name @official_name end |
#persistent_account_id ⇒ Object
A unique and persistent identifier for accounts that can be used to trace multiple instances of the same account across different Items for depository accounts. This field is currently supported only for Items at institutions that use Tokenized Account Numbers (i.e., Chase, PNC, and US Bank). Because these accounts have a different account number each time they are linked, this field may be used instead of the account number to uniquely identify an account across multiple Items for payments use cases, helping to reduce duplicate Items or attempted fraud. In Sandbox, this field is populated for TAN-based institutions (‘ins_56`, `ins_13`, `ins_127990`) as well as the OAuth Sandbox institution (`ins_127287`); in Production, it will only be populated for accounts at applicable institutions.
42 43 44 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 42 def persistent_account_id @persistent_account_id end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
48 49 50 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 48 def phone_number @phone_number end |
#subtype ⇒ Object
Returns the value of attribute subtype.
32 33 34 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 32 def subtype @subtype end |
#type ⇒ Object
Returns the value of attribute type.
30 31 32 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 30 def type @type end |
#verification_insights ⇒ Object
Returns the value of attribute verification_insights.
39 40 41 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 39 def verification_insights @verification_insights end |
#verification_name ⇒ Object
Returns the value of attribute verification_name.
37 38 39 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 37 def verification_name @verification_name end |
#verification_status ⇒ Object
Indicates an Item’s micro-deposit-based verification or database verification status. This field is only populated when using Auth and falling back to micro-deposit or database verification. Possible values are: ‘pending_automatic_verification`: The Item is pending automatic verification. `pending_manual_verification`: The Item is pending manual micro-deposit verification. Items remain in this state until the user successfully verifies the code. `automatically_verified`: The Item has successfully been automatically verified. `manually_verified`: The Item has successfully been manually verified. `verification_expired`: Plaid was unable to automatically verify the deposit within 7 calendar days and will no longer attempt to validate the Item. Users may retry by submitting their information again through Link. `verification_failed`: The Item failed manual micro-deposit verification because the user exhausted all 3 verification attempts. Users may retry by submitting their information again through Link. `unsent`: The Item is pending micro-deposit verification, but Plaid has not yet sent the micro-deposit. `database_insights_fail`: The Item’s numbers have been verified using Plaid’s data sources and have signal for being invalid and/or have no signal for being valid. Typically this indicates that the routing number is invalid, the account number does not match the account number format associated with the routing number, or the account has been reported as closed or frozen. Only returned for Auth Items created via Database Auth. ‘database_insights_pass`: The Item’s numbers have been verified using Plaid’s data sources: the routing and account number match a routing and account number of an account recognized on the Plaid network, and the account is not known by Plaid to be frozen or closed. Only returned for Auth Items created via Database Auth. ‘database_insights_pass_with_caution`: The Item’s numbers have been verified using Plaid’s data sources and have some signal for being valid: the routing and account number were not recognized on the Plaid network, but the routing number is valid and the account number is a potential valid account number for that routing number. Only returned for Auth Items created via Database Auth. ‘database_matched`: (deprecated) The Item has successfully been verified using Plaid’s data sources. Only returned for Auth Items created via Database Match. ‘null` or empty string: Neither micro-deposit-based verification nor database verification are being used for the Item.
35 36 37 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 35 def verification_status @verification_status end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 99 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 77 def self.attribute_map { :'account_id' => :'account_id', :'balances' => :'balances', :'mask' => :'mask', :'name' => :'name', :'official_name' => :'official_name', :'type' => :'type', :'subtype' => :'subtype', :'verification_status' => :'verification_status', :'verification_name' => :'verification_name', :'verification_insights' => :'verification_insights', :'persistent_account_id' => :'persistent_account_id', :'holder_category' => :'holder_category', :'legal_name' => :'legal_name', :'phone_number' => :'phone_number', :'email_address' => :'email_address', :'address' => :'address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
310 311 312 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 310 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
140 141 142 143 144 145 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 140 def self.openapi_all_of [ :'AccountBase', :'AccountIdentityMatchScoreAllOf' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 126 def self.openapi_nullable Set.new([ :'mask', :'official_name', :'subtype', :'holder_category', :'legal_name', :'phone_number', :'email_address', :'address' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 104 def self.openapi_types { :'account_id' => :'String', :'balances' => :'AccountBalance', :'mask' => :'String', :'name' => :'String', :'official_name' => :'String', :'type' => :'AccountType', :'subtype' => :'AccountSubtype', :'verification_status' => :'String', :'verification_name' => :'String', :'verification_insights' => :'AccountVerificationInsights', :'persistent_account_id' => :'String', :'holder_category' => :'AccountHolderCategory', :'legal_name' => :'NameMatchScore', :'phone_number' => :'PhoneNumberMatchScore', :'email_address' => :'EmailAddressMatchScore', :'address' => :'AddressMatchScore' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && balances == o.balances && mask == o.mask && name == o.name && official_name == o.official_name && type == o.type && subtype == o.subtype && verification_status == o.verification_status && verification_name == o.verification_name && verification_insights == o.verification_insights && persistent_account_id == o.persistent_account_id && holder_category == o.holder_category && legal_name == o.legal_name && phone_number == o.phone_number && email_address == o.email_address && address == o.address end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 341 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 412 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 317 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
297 298 299 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 297 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
303 304 305 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 303 def hash [account_id, balances, mask, name, official_name, type, subtype, verification_status, verification_name, verification_insights, persistent_account_id, holder_category, legal_name, phone_number, email_address, address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 229 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @balances.nil? invalid_properties.push('invalid value for "balances", balances cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
388 389 390 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 388 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 394 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
382 383 384 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 382 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
252 253 254 255 256 257 258 259 260 |
# File 'lib/plaid/models/account_identity_match_score.rb', line 252 def valid? return false if @account_id.nil? return false if @balances.nil? return false if @name.nil? return false if @type.nil? verification_status_validator = EnumAttributeValidator.new('String', ["automatically_verified", "pending_automatic_verification", "pending_manual_verification", "unsent", "manually_verified", "verification_expired", "verification_failed", "database_matched", "database_insights_pass", "database_insights_pass_with_caution", "database_insights_fail"]) return false unless verification_status_validator.valid?(@verification_status) true end |