Class: Plaid::AssetHolding
- Inherits:
-
Object
- Object
- Plaid::AssetHolding
- Defined in:
- lib/plaid/models/asset_holding.rb
Overview
Documentation not found in the MISMO model viewer and not provided by Freddie Mac.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset_holding_current_price_amount ⇒ Object
current price of investment holding.
-
#asset_holding_description ⇒ Object
Description of holding.
-
#asset_holding_id ⇒ Object
Unique id of investment position.
-
#asset_holding_market_value_amount ⇒ Object
market value of investment position.
-
#asset_holding_restricted_indicator ⇒ Object
Whether or not the stock is restricted, i.e.
-
#asset_holding_security_name ⇒ Object
Security name of investment holding.
-
#asset_holding_symbol ⇒ Object
Investment position’s market ticker symbol.
-
#asset_holding_type ⇒ Object
Type of holding (e.g. bond, stock, crypto, other).
-
#asset_holding_units ⇒ Object
Number of units of holding.
-
#asset_holding_vested_amount ⇒ Object
Amount of holding vested.
-
#currency ⇒ Object
US Dollar.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssetHolding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AssetHolding
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/plaid/models/asset_holding.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::AssetHolding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::AssetHolding`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_holding_id') self.asset_holding_id = attributes[:'asset_holding_id'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'asset_holding_description') self.asset_holding_description = attributes[:'asset_holding_description'] end if attributes.key?(:'asset_holding_symbol') self.asset_holding_symbol = attributes[:'asset_holding_symbol'] end if attributes.key?(:'asset_holding_security_name') self.asset_holding_security_name = attributes[:'asset_holding_security_name'] end if attributes.key?(:'asset_holding_units') self.asset_holding_units = attributes[:'asset_holding_units'] end if attributes.key?(:'asset_holding_market_value_amount') self.asset_holding_market_value_amount = attributes[:'asset_holding_market_value_amount'] end if attributes.key?(:'asset_holding_current_price_amount') self.asset_holding_current_price_amount = attributes[:'asset_holding_current_price_amount'] end if attributes.key?(:'asset_holding_type') self.asset_holding_type = attributes[:'asset_holding_type'] end if attributes.key?(:'asset_holding_restricted_indicator') self.asset_holding_restricted_indicator = attributes[:'asset_holding_restricted_indicator'] end if attributes.key?(:'asset_holding_vested_amount') self.asset_holding_vested_amount = attributes[:'asset_holding_vested_amount'] end end |
Instance Attribute Details
#asset_holding_current_price_amount ⇒ Object
current price of investment holding
41 42 43 |
# File 'lib/plaid/models/asset_holding.rb', line 41 def asset_holding_current_price_amount @asset_holding_current_price_amount end |
#asset_holding_description ⇒ Object
Description of holding
26 27 28 |
# File 'lib/plaid/models/asset_holding.rb', line 26 def asset_holding_description @asset_holding_description end |
#asset_holding_id ⇒ Object
Unique id of investment position
20 21 22 |
# File 'lib/plaid/models/asset_holding.rb', line 20 def asset_holding_id @asset_holding_id end |
#asset_holding_market_value_amount ⇒ Object
market value of investment position
38 39 40 |
# File 'lib/plaid/models/asset_holding.rb', line 38 def asset_holding_market_value_amount @asset_holding_market_value_amount end |
#asset_holding_restricted_indicator ⇒ Object
Whether or not the stock is restricted, i.e. "Restricted" or "Not Restricted"
47 48 49 |
# File 'lib/plaid/models/asset_holding.rb', line 47 def asset_holding_restricted_indicator @asset_holding_restricted_indicator end |
#asset_holding_security_name ⇒ Object
Security name of investment holding
32 33 34 |
# File 'lib/plaid/models/asset_holding.rb', line 32 def asset_holding_security_name @asset_holding_security_name end |
#asset_holding_symbol ⇒ Object
Investment position’s market ticker symbol
29 30 31 |
# File 'lib/plaid/models/asset_holding.rb', line 29 def asset_holding_symbol @asset_holding_symbol end |
#asset_holding_type ⇒ Object
Type of holding (e.g. bond, stock, crypto, other)
44 45 46 |
# File 'lib/plaid/models/asset_holding.rb', line 44 def asset_holding_type @asset_holding_type end |
#asset_holding_units ⇒ Object
Number of units of holding
35 36 37 |
# File 'lib/plaid/models/asset_holding.rb', line 35 def asset_holding_units @asset_holding_units end |
#asset_holding_vested_amount ⇒ Object
Amount of holding vested
50 51 52 |
# File 'lib/plaid/models/asset_holding.rb', line 50 def asset_holding_vested_amount @asset_holding_vested_amount end |
#currency ⇒ Object
US Dollar
23 24 25 |
# File 'lib/plaid/models/asset_holding.rb', line 23 def currency @currency end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/plaid/models/asset_holding.rb', line 92 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/plaid/models/asset_holding.rb', line 75 def self.attribute_map { :'asset_holding_id' => :'AssetHoldingID', :'currency' => :'Currency', :'asset_holding_description' => :'AssetHoldingDescription', :'asset_holding_symbol' => :'AssetHoldingSymbol', :'asset_holding_security_name' => :'AssetHoldingSecurityName', :'asset_holding_units' => :'AssetHoldingUnits', :'asset_holding_market_value_amount' => :'AssetHoldingMarketValueAmount', :'asset_holding_current_price_amount' => :'AssetHoldingCurrentPriceAmount', :'asset_holding_type' => :'AssetHoldingType', :'asset_holding_restricted_indicator' => :'AssetHoldingRestrictedIndicator', :'asset_holding_vested_amount' => :'AssetHoldingVestedAmount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 |
# File 'lib/plaid/models/asset_holding.rb', line 260 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/plaid/models/asset_holding.rb', line 114 def self.openapi_nullable Set.new([ :'asset_holding_id', :'currency', :'asset_holding_description', :'asset_holding_symbol', :'asset_holding_security_name', :'asset_holding_units', :'asset_holding_market_value_amount', :'asset_holding_current_price_amount', :'asset_holding_type', :'asset_holding_restricted_indicator', :'asset_holding_vested_amount' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/plaid/models/asset_holding.rb', line 97 def self.openapi_types { :'asset_holding_id' => :'String', :'currency' => :'String', :'asset_holding_description' => :'String', :'asset_holding_symbol' => :'String', :'asset_holding_security_name' => :'String', :'asset_holding_units' => :'Float', :'asset_holding_market_value_amount' => :'Float', :'asset_holding_current_price_amount' => :'Float', :'asset_holding_type' => :'String', :'asset_holding_restricted_indicator' => :'String', :'asset_holding_vested_amount' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/plaid/models/asset_holding.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && asset_holding_id == o.asset_holding_id && currency == o.currency && asset_holding_description == o.asset_holding_description && asset_holding_symbol == o.asset_holding_symbol && asset_holding_security_name == o.asset_holding_security_name && asset_holding_units == o.asset_holding_units && asset_holding_market_value_amount == o.asset_holding_market_value_amount && asset_holding_current_price_amount == o.asset_holding_current_price_amount && asset_holding_type == o.asset_holding_type && asset_holding_restricted_indicator == o.asset_holding_restricted_indicator && asset_holding_vested_amount == o.asset_holding_vested_amount end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/plaid/models/asset_holding.rb', line 291 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/plaid/models/asset_holding.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/plaid/models/asset_holding.rb', line 267 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/plaid/models/asset_holding.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/plaid/models/asset_holding.rb', line 253 def hash [asset_holding_id, currency, asset_holding_description, asset_holding_symbol, asset_holding_security_name, asset_holding_units, asset_holding_market_value_amount, asset_holding_current_price_amount, asset_holding_type, asset_holding_restricted_indicator, asset_holding_vested_amount].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 |
# File 'lib/plaid/models/asset_holding.rb', line 192 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/plaid/models/asset_holding.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/plaid/models/asset_holding.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/plaid/models/asset_holding.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 |
# File 'lib/plaid/models/asset_holding.rb', line 199 def valid? asset_holding_type_validator = EnumAttributeValidator.new('String', ["Bond", "Stock", "Crypto", "Other"]) return false unless asset_holding_type_validator.valid?(@asset_holding_type) asset_holding_restricted_indicator_validator = EnumAttributeValidator.new('String', ["true", "false"]) return false unless asset_holding_restricted_indicator_validator.valid?(@asset_holding_restricted_indicator) true end |