Class: Plaid::BankTransferEvent

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/bank_transfer_event.rb

Overview

Represents an event in the Bank Transfers API.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BankTransferEvent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/plaid/models/bank_transfer_event.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::BankTransferEvent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::BankTransferEvent`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event_id')
    self.event_id = attributes[:'event_id']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'bank_transfer_id')
    self.bank_transfer_id = attributes[:'bank_transfer_id']
  end

  if attributes.key?(:'origination_account_id')
    self. = attributes[:'origination_account_id']
  end

  if attributes.key?(:'bank_transfer_type')
    self.bank_transfer_type = attributes[:'bank_transfer_type']
  end

  if attributes.key?(:'bank_transfer_amount')
    self.bank_transfer_amount = attributes[:'bank_transfer_amount']
  end

  if attributes.key?(:'bank_transfer_iso_currency_code')
    self.bank_transfer_iso_currency_code = attributes[:'bank_transfer_iso_currency_code']
  end

  if attributes.key?(:'failure_reason')
    self.failure_reason = attributes[:'failure_reason']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'receiver_details')
    self.receiver_details = attributes[:'receiver_details']
  end
end

Instance Attribute Details

#account_idObject

The account ID associated with the bank transfer.



28
29
30
# File 'lib/plaid/models/bank_transfer_event.rb', line 28

def 
  @account_id
end

#bank_transfer_amountObject

The bank transfer amount.



39
40
41
# File 'lib/plaid/models/bank_transfer_event.rb', line 39

def bank_transfer_amount
  @bank_transfer_amount
end

#bank_transfer_idObject

Plaid's unique identifier for a bank transfer.



31
32
33
# File 'lib/plaid/models/bank_transfer_event.rb', line 31

def bank_transfer_id
  @bank_transfer_id
end

#bank_transfer_iso_currency_codeObject

The currency of the bank transfer amount.



42
43
44
# File 'lib/plaid/models/bank_transfer_event.rb', line 42

def bank_transfer_iso_currency_code
  @bank_transfer_iso_currency_code
end

#bank_transfer_typeObject

Returns the value of attribute bank_transfer_type.



36
37
38
# File 'lib/plaid/models/bank_transfer_event.rb', line 36

def bank_transfer_type
  @bank_transfer_type
end

#directionObject

Returns the value of attribute direction.



46
47
48
# File 'lib/plaid/models/bank_transfer_event.rb', line 46

def direction
  @direction
end

#event_idObject

Plaid's unique identifier for this event. IDs are sequential unsigned 64-bit integers.



20
21
22
# File 'lib/plaid/models/bank_transfer_event.rb', line 20

def event_id
  @event_id
end

#event_typeObject

Returns the value of attribute event_type.



25
26
27
# File 'lib/plaid/models/bank_transfer_event.rb', line 25

def event_type
  @event_type
end

#failure_reasonObject

Returns the value of attribute failure_reason.



44
45
46
# File 'lib/plaid/models/bank_transfer_event.rb', line 44

def failure_reason
  @failure_reason
end

#origination_account_idObject

The ID of the origination account that this balance belongs to.



34
35
36
# File 'lib/plaid/models/bank_transfer_event.rb', line 34

def 
  @origination_account_id
end

#receiver_detailsObject

Returns the value of attribute receiver_details.



48
49
50
# File 'lib/plaid/models/bank_transfer_event.rb', line 48

def receiver_details
  @receiver_details
end

#timestampObject

The datetime when this event occurred. This will be of the form 2006-01-02T15:04:05Z.



23
24
25
# File 'lib/plaid/models/bank_transfer_event.rb', line 23

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/plaid/models/bank_transfer_event.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/plaid/models/bank_transfer_event.rb', line 73

def self.attribute_map
  {
    :'event_id' => :'event_id',
    :'timestamp' => :'timestamp',
    :'event_type' => :'event_type',
    :'account_id' => :'account_id',
    :'bank_transfer_id' => :'bank_transfer_id',
    :'origination_account_id' => :'origination_account_id',
    :'bank_transfer_type' => :'bank_transfer_type',
    :'bank_transfer_amount' => :'bank_transfer_amount',
    :'bank_transfer_iso_currency_code' => :'bank_transfer_iso_currency_code',
    :'failure_reason' => :'failure_reason',
    :'direction' => :'direction',
    :'receiver_details' => :'receiver_details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
# File 'lib/plaid/models/bank_transfer_event.rb', line 295

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
118
119
120
121
# File 'lib/plaid/models/bank_transfer_event.rb', line 114

def self.openapi_nullable
  Set.new([
    :'origination_account_id',
    :'failure_reason',
    :'direction',
    :'receiver_details'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/plaid/models/bank_transfer_event.rb', line 96

def self.openapi_types
  {
    :'event_id' => :'Integer',
    :'timestamp' => :'Time',
    :'event_type' => :'BankTransferEventType',
    :'account_id' => :'String',
    :'bank_transfer_id' => :'String',
    :'origination_account_id' => :'String',
    :'bank_transfer_type' => :'BankTransferType',
    :'bank_transfer_amount' => :'String',
    :'bank_transfer_iso_currency_code' => :'String',
    :'failure_reason' => :'BankTransferFailure',
    :'direction' => :'BankTransferDirection',
    :'receiver_details' => :'ReceiverDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/plaid/models/bank_transfer_event.rb', line 263

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event_id == o.event_id &&
      timestamp == o.timestamp &&
      event_type == o.event_type &&
       == o. &&
      bank_transfer_id == o.bank_transfer_id &&
       == o. &&
      bank_transfer_type == o.bank_transfer_type &&
      bank_transfer_amount == o.bank_transfer_amount &&
      bank_transfer_iso_currency_code == o.bank_transfer_iso_currency_code &&
      failure_reason == o.failure_reason &&
      direction == o.direction &&
      receiver_details == o.receiver_details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/plaid/models/bank_transfer_event.rb', line 326

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/plaid/models/bank_transfer_event.rb', line 397

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/plaid/models/bank_transfer_event.rb', line 302

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/plaid/models/bank_transfer_event.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/plaid/models/bank_transfer_event.rb', line 288

def hash
  [event_id, timestamp, event_type, , bank_transfer_id, , bank_transfer_type, bank_transfer_amount, bank_transfer_iso_currency_code, failure_reason, direction, receiver_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/plaid/models/bank_transfer_event.rb', line 189

def list_invalid_properties
  invalid_properties = Array.new
  if @event_id.nil?
    invalid_properties.push('invalid value for "event_id", event_id cannot be nil.')
  end

  if @event_id < 0
    invalid_properties.push('invalid value for "event_id", must be greater than or equal to 0.')
  end


  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @bank_transfer_id.nil?
    invalid_properties.push('invalid value for "bank_transfer_id", bank_transfer_id cannot be nil.')
  end

  if @bank_transfer_type.nil?
    invalid_properties.push('invalid value for "bank_transfer_type", bank_transfer_type cannot be nil.')
  end

  if @bank_transfer_amount.nil?
    invalid_properties.push('invalid value for "bank_transfer_amount", bank_transfer_amount cannot be nil.')
  end

  if @bank_transfer_iso_currency_code.nil?
    invalid_properties.push('invalid value for "bank_transfer_iso_currency_code", bank_transfer_iso_currency_code cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



373
374
375
# File 'lib/plaid/models/bank_transfer_event.rb', line 373

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/plaid/models/bank_transfer_event.rb', line 379

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



367
368
369
# File 'lib/plaid/models/bank_transfer_event.rb', line 367

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/plaid/models/bank_transfer_event.rb', line 233

def valid?
  return false if @event_id.nil?
  return false if @event_id < 0
  return false if @timestamp.nil?
  return false if @event_type.nil?
  return false if @account_id.nil?
  return false if @bank_transfer_id.nil?
  return false if @bank_transfer_type.nil?
  return false if @bank_transfer_amount.nil?
  return false if @bank_transfer_iso_currency_code.nil?
  true
end