Class: Plaid::BetaIssuesV1GetResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/beta_issues_v1_get_response.rb

Overview

BetaIssuesV1GetResponse defines the response schema for /beta/issues/v1/get.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BetaIssuesV1GetResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 171

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::BetaIssuesV1GetResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::BetaIssuesV1GetResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'issue_id')
    self.issue_id = attributes[:'issue_id']
  end

  if attributes.key?(:'issue_type')
    self.issue_type = attributes[:'issue_type']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'institution_id')
    self.institution_id = attributes[:'institution_id']
  end

  if attributes.key?(:'institution_name')
    self.institution_name = attributes[:'institution_name']
  end

  if attributes.key?(:'behaviors')
    if (value = attributes[:'behaviors']).is_a?(Array)
      self.behaviors = value
    end
  end

  if attributes.key?(:'issue_error_type')
    self.issue_error_type = attributes[:'issue_error_type']
  end

  if attributes.key?(:'issue_error_code')
    self.issue_error_code = attributes[:'issue_error_code']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'attribution')
    self.attribution = attributes[:'attribution']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'user_guidance')
    self.user_guidance = attributes[:'user_guidance']
  end

  if attributes.key?(:'estimated_resolution_time')
    self.estimated_resolution_time = attributes[:'estimated_resolution_time']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'impact')
    self.impact = attributes[:'impact']
  end

  if attributes.key?(:'affected_products')
    if (value = attributes[:'affected_products']).is_a?(Array)
      self.affected_products = value
    end
  end

  if attributes.key?(:'resolution_log')
    if (value = attributes[:'resolution_log']).is_a?(Array)
      self.resolution_log = value
    end
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  end
end

Instance Attribute Details

#affected_productsObject

The Plaid products affected by the issue.



63
64
65
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 63

def affected_products
  @affected_products
end

#attributionObject

Returns the value of attribute attribution.



44
45
46
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 44

def attribution
  @attribution
end

#behaviorsObject

The customer-visible effects of the issue.



33
34
35
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 33

def behaviors
  @behaviors
end

#descriptionObject

A customer-facing explanation of the issue.



42
43
44
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 42

def description
  @description
end

#end_timeObject

The time the issue ended, or null while it remains active.



58
59
60
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 58

def end_time
  @end_time
end

#estimated_resolution_timeObject

The estimated resolution time, or null when no estimate is available.



52
53
54
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 52

def estimated_resolution_time
  @estimated_resolution_time
end

#impactObject

Returns the value of attribute impact.



60
61
62
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 60

def impact
  @impact
end

#institution_idObject

The identifier of the institution affected by the issue.



27
28
29
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 27

def institution_id
  @institution_id
end

#institution_nameObject

The name of the institution affected by the issue.



30
31
32
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 30

def institution_name
  @institution_name
end

#issue_error_codeObject

The API error code associated with the issue if available. Always null or non-null together with issue_error_type.



39
40
41
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 39

def issue_error_code
  @issue_error_code
end

#issue_error_typeObject

The API error type associated with the issue if available. Mirrors the error_type field on PlaidError returned on error responses and is safe for programmatic use. Always null or non-null together with issue_error_code.



36
37
38
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 36

def issue_error_type
  @issue_error_type
end

#issue_idObject

The customer-visible identifier of the issue.



20
21
22
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 20

def issue_id
  @issue_id
end

#issue_typeObject

Returns the value of attribute issue_type.



22
23
24
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 22

def issue_type
  @issue_type
end

#request_idObject

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.



69
70
71
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 69

def request_id
  @request_id
end

#resolution_logObject

Resolution events recorded for the issue.



66
67
68
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 66

def resolution_log
  @resolution_log
end

#severityObject

Returns the value of attribute severity.



24
25
26
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 24

def severity
  @severity
end

#start_timeObject

The time the issue began, or null when it is unknown. Only populated for incidents.



55
56
57
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 55

def start_time
  @start_time
end

#statusObject

Returns the value of attribute status.



46
47
48
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 46

def status
  @status
end

#user_guidanceObject

Guidance for an end user affected by the issue, or null when no guidance is available.



49
50
51
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 49

def user_guidance
  @user_guidance
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 119

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 94

def self.attribute_map
  {
    :'issue_id' => :'issue_id',
    :'issue_type' => :'issue_type',
    :'severity' => :'severity',
    :'institution_id' => :'institution_id',
    :'institution_name' => :'institution_name',
    :'behaviors' => :'behaviors',
    :'issue_error_type' => :'issue_error_type',
    :'issue_error_code' => :'issue_error_code',
    :'description' => :'description',
    :'attribution' => :'attribution',
    :'status' => :'status',
    :'user_guidance' => :'user_guidance',
    :'estimated_resolution_time' => :'estimated_resolution_time',
    :'start_time' => :'start_time',
    :'end_time' => :'end_time',
    :'impact' => :'impact',
    :'affected_products' => :'affected_products',
    :'resolution_log' => :'resolution_log',
    :'request_id' => :'request_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



381
382
383
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 381

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



162
163
164
165
166
167
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 162

def self.openapi_all_of
  [
  :'BetaIssuesV1Issue',
  :'PaymentInitiationRecipientGetResponseAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



149
150
151
152
153
154
155
156
157
158
159
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 149

def self.openapi_nullable
  Set.new([
    :'issue_error_type',
    :'issue_error_code',
    :'user_guidance',
    :'estimated_resolution_time',
    :'start_time',
    :'end_time',
    :'impact',
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 124

def self.openapi_types
  {
    :'issue_id' => :'String',
    :'issue_type' => :'BetaIssuesV1IssueType',
    :'severity' => :'BetaIssuesV1IssueSeverity',
    :'institution_id' => :'String',
    :'institution_name' => :'String',
    :'behaviors' => :'Array<BetaIssuesV1IssueBehavior>',
    :'issue_error_type' => :'String',
    :'issue_error_code' => :'String',
    :'description' => :'String',
    :'attribution' => :'BetaIssuesV1IssueAttribution',
    :'status' => :'BetaIssuesV1IssueStatus',
    :'user_guidance' => :'String',
    :'estimated_resolution_time' => :'Time',
    :'start_time' => :'Time',
    :'end_time' => :'Time',
    :'impact' => :'BetaIssuesV1IssueImpact',
    :'affected_products' => :'Array<Products>',
    :'resolution_log' => :'Array<BetaIssuesV1IssueResolutionEvent>',
    :'request_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 342

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      issue_id == o.issue_id &&
      issue_type == o.issue_type &&
      severity == o.severity &&
      institution_id == o.institution_id &&
      institution_name == o.institution_name &&
      behaviors == o.behaviors &&
      issue_error_type == o.issue_error_type &&
      issue_error_code == o.issue_error_code &&
      description == o.description &&
      attribution == o.attribution &&
      status == o.status &&
      user_guidance == o.user_guidance &&
      estimated_resolution_time == o.estimated_resolution_time &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      impact == o.impact &&
      affected_products == o.affected_products &&
      resolution_log == o.resolution_log &&
      request_id == o.request_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 412

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 483

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 388

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


368
369
370
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 368

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



374
375
376
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 374

def hash
  [issue_id, issue_type, severity, institution_id, institution_name, behaviors, issue_error_type, issue_error_code, description, attribution, status, user_guidance, estimated_resolution_time, start_time, end_time, impact, affected_products, resolution_log, request_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 269

def list_invalid_properties
  invalid_properties = Array.new
  if @issue_id.nil?
    invalid_properties.push('invalid value for "issue_id", issue_id cannot be nil.')
  end

  if @issue_type.nil?
    invalid_properties.push('invalid value for "issue_type", issue_type cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @institution_id.nil?
    invalid_properties.push('invalid value for "institution_id", institution_id cannot be nil.')
  end

  if @institution_name.nil?
    invalid_properties.push('invalid value for "institution_name", institution_name cannot be nil.')
  end

  if @behaviors.nil?
    invalid_properties.push('invalid value for "behaviors", behaviors cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @attribution.nil?
    invalid_properties.push('invalid value for "attribution", attribution cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @affected_products.nil?
    invalid_properties.push('invalid value for "affected_products", affected_products cannot be nil.')
  end

  if @resolution_log.nil?
    invalid_properties.push('invalid value for "resolution_log", resolution_log cannot be nil.')
  end

  if @request_id.nil?
    invalid_properties.push('invalid value for "request_id", request_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



459
460
461
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 459

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 465

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



453
454
455
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 453

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/plaid/models/beta_issues_v1_get_response.rb', line 324

def valid?
  return false if @issue_id.nil?
  return false if @issue_type.nil?
  return false if @severity.nil?
  return false if @institution_id.nil?
  return false if @institution_name.nil?
  return false if @behaviors.nil?
  return false if @description.nil?
  return false if @attribution.nil?
  return false if @status.nil?
  return false if @affected_products.nil?
  return false if @resolution_log.nil?
  return false if @request_id.nil?
  true
end