Class: Plaid::BetaIssuesV1Issue
- Inherits:
-
Object
- Object
- Plaid::BetaIssuesV1Issue
- Defined in:
- lib/plaid/models/beta_issues_v1_issue.rb
Overview
A customer-facing institution issue.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#affected_products ⇒ Object
The Plaid products affected by the issue.
-
#attribution ⇒ Object
Returns the value of attribute attribution.
-
#behaviors ⇒ Object
The customer-visible effects of the issue.
-
#description ⇒ Object
A customer-facing explanation of the issue.
-
#end_time ⇒ Object
The time the issue ended, or null while it remains active.
-
#estimated_resolution_time ⇒ Object
The estimated resolution time, or null when no estimate is available.
-
#impact ⇒ Object
Returns the value of attribute impact.
-
#institution_id ⇒ Object
The identifier of the institution affected by the issue.
-
#institution_name ⇒ Object
The name of the institution affected by the issue.
-
#issue_error_code ⇒ Object
The API error code associated with the issue if available.
-
#issue_error_type ⇒ Object
The API error type associated with the issue if available.
-
#issue_id ⇒ Object
The customer-visible identifier of the issue.
-
#issue_type ⇒ Object
Returns the value of attribute issue_type.
-
#resolution_log ⇒ Object
Resolution events recorded for the issue.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#start_time ⇒ Object
The time the issue began, or null when it is unknown.
-
#status ⇒ Object
Returns the value of attribute status.
-
#user_guidance ⇒ Object
Guidance for an end user affected by the issue, or null when no guidance is available.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaIssuesV1Issue
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BetaIssuesV1Issue
Initializes the object
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 158 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::BetaIssuesV1Issue` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::BetaIssuesV1Issue`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'issue_id') self.issue_id = attributes[:'issue_id'] end if attributes.key?(:'issue_type') self.issue_type = attributes[:'issue_type'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'institution_id') self.institution_id = attributes[:'institution_id'] end if attributes.key?(:'institution_name') self.institution_name = attributes[:'institution_name'] end if attributes.key?(:'behaviors') if (value = attributes[:'behaviors']).is_a?(Array) self.behaviors = value end end if attributes.key?(:'issue_error_type') self.issue_error_type = attributes[:'issue_error_type'] end if attributes.key?(:'issue_error_code') self.issue_error_code = attributes[:'issue_error_code'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'attribution') self.attribution = attributes[:'attribution'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'user_guidance') self.user_guidance = attributes[:'user_guidance'] end if attributes.key?(:'estimated_resolution_time') self.estimated_resolution_time = attributes[:'estimated_resolution_time'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'impact') self.impact = attributes[:'impact'] end if attributes.key?(:'affected_products') if (value = attributes[:'affected_products']).is_a?(Array) self.affected_products = value end end if attributes.key?(:'resolution_log') if (value = attributes[:'resolution_log']).is_a?(Array) self.resolution_log = value end end end |
Instance Attribute Details
#affected_products ⇒ Object
The Plaid products affected by the issue.
63 64 65 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 63 def affected_products @affected_products end |
#attribution ⇒ Object
Returns the value of attribute attribution.
44 45 46 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 44 def attribution @attribution end |
#behaviors ⇒ Object
The customer-visible effects of the issue.
33 34 35 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 33 def behaviors @behaviors end |
#description ⇒ Object
A customer-facing explanation of the issue.
42 43 44 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 42 def description @description end |
#end_time ⇒ Object
The time the issue ended, or null while it remains active.
58 59 60 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 58 def end_time @end_time end |
#estimated_resolution_time ⇒ Object
The estimated resolution time, or null when no estimate is available.
52 53 54 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 52 def estimated_resolution_time @estimated_resolution_time end |
#impact ⇒ Object
Returns the value of attribute impact.
60 61 62 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 60 def impact @impact end |
#institution_id ⇒ Object
The identifier of the institution affected by the issue.
27 28 29 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 27 def institution_id @institution_id end |
#institution_name ⇒ Object
The name of the institution affected by the issue.
30 31 32 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 30 def institution_name @institution_name end |
#issue_error_code ⇒ Object
The API error code associated with the issue if available. Always null or non-null together with issue_error_type.
39 40 41 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 39 def issue_error_code @issue_error_code end |
#issue_error_type ⇒ Object
The API error type associated with the issue if available. Mirrors the error_type field on PlaidError returned on error responses and is safe for programmatic use. Always null or non-null together with issue_error_code.
36 37 38 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 36 def issue_error_type @issue_error_type end |
#issue_id ⇒ Object
The customer-visible identifier of the issue.
20 21 22 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 20 def issue_id @issue_id end |
#issue_type ⇒ Object
Returns the value of attribute issue_type.
22 23 24 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 22 def issue_type @issue_type end |
#resolution_log ⇒ Object
Resolution events recorded for the issue.
66 67 68 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 66 def resolution_log @resolution_log end |
#severity ⇒ Object
Returns the value of attribute severity.
24 25 26 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 24 def severity @severity end |
#start_time ⇒ Object
The time the issue began, or null when it is unknown. Only populated for incidents.
55 56 57 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 55 def start_time @start_time end |
#status ⇒ Object
Returns the value of attribute status.
46 47 48 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 46 def status @status end |
#user_guidance ⇒ Object
Guidance for an end user affected by the issue, or null when no guidance is available.
49 50 51 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 49 def user_guidance @user_guidance end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
115 116 117 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 115 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 91 def self.attribute_map { :'issue_id' => :'issue_id', :'issue_type' => :'issue_type', :'severity' => :'severity', :'institution_id' => :'institution_id', :'institution_name' => :'institution_name', :'behaviors' => :'behaviors', :'issue_error_type' => :'issue_error_type', :'issue_error_code' => :'issue_error_code', :'description' => :'description', :'attribution' => :'attribution', :'status' => :'status', :'user_guidance' => :'user_guidance', :'estimated_resolution_time' => :'estimated_resolution_time', :'start_time' => :'start_time', :'end_time' => :'end_time', :'impact' => :'impact', :'affected_products' => :'affected_products', :'resolution_log' => :'resolution_log' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
358 359 360 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 358 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 144 def self.openapi_nullable Set.new([ :'issue_error_type', :'issue_error_code', :'user_guidance', :'estimated_resolution_time', :'start_time', :'end_time', :'impact', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 120 def self.openapi_types { :'issue_id' => :'String', :'issue_type' => :'BetaIssuesV1IssueType', :'severity' => :'BetaIssuesV1IssueSeverity', :'institution_id' => :'String', :'institution_name' => :'String', :'behaviors' => :'Array<BetaIssuesV1IssueBehavior>', :'issue_error_type' => :'String', :'issue_error_code' => :'String', :'description' => :'String', :'attribution' => :'BetaIssuesV1IssueAttribution', :'status' => :'BetaIssuesV1IssueStatus', :'user_guidance' => :'String', :'estimated_resolution_time' => :'Time', :'start_time' => :'Time', :'end_time' => :'Time', :'impact' => :'BetaIssuesV1IssueImpact', :'affected_products' => :'Array<Products>', :'resolution_log' => :'Array<BetaIssuesV1IssueResolutionEvent>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 320 def ==(o) return true if self.equal?(o) self.class == o.class && issue_id == o.issue_id && issue_type == o.issue_type && severity == o.severity && institution_id == o.institution_id && institution_name == o.institution_name && behaviors == o.behaviors && issue_error_type == o.issue_error_type && issue_error_code == o.issue_error_code && description == o.description && attribution == o.attribution && status == o.status && user_guidance == o.user_guidance && estimated_resolution_time == o.estimated_resolution_time && start_time == o.start_time && end_time == o.end_time && impact == o.impact && affected_products == o.affected_products && resolution_log == o.resolution_log end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 389 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 460 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 365 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
345 346 347 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 345 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
351 352 353 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 351 def hash [issue_id, issue_type, severity, institution_id, institution_name, behaviors, issue_error_type, issue_error_code, description, attribution, status, user_guidance, estimated_resolution_time, start_time, end_time, impact, affected_products, resolution_log].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 252 def list_invalid_properties invalid_properties = Array.new if @issue_id.nil? invalid_properties.push('invalid value for "issue_id", issue_id cannot be nil.') end if @issue_type.nil? invalid_properties.push('invalid value for "issue_type", issue_type cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end if @institution_id.nil? invalid_properties.push('invalid value for "institution_id", institution_id cannot be nil.') end if @institution_name.nil? invalid_properties.push('invalid value for "institution_name", institution_name cannot be nil.') end if @behaviors.nil? invalid_properties.push('invalid value for "behaviors", behaviors cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @attribution.nil? invalid_properties.push('invalid value for "attribution", attribution cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @affected_products.nil? invalid_properties.push('invalid value for "affected_products", affected_products cannot be nil.') end if @resolution_log.nil? invalid_properties.push('invalid value for "resolution_log", resolution_log cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
436 437 438 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 436 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 442 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
430 431 432 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 430 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/plaid/models/beta_issues_v1_issue.rb', line 303 def valid? return false if @issue_id.nil? return false if @issue_type.nil? return false if @severity.nil? return false if @institution_id.nil? return false if @institution_name.nil? return false if @behaviors.nil? return false if @description.nil? return false if @attribution.nil? return false if @status.nil? return false if @affected_products.nil? return false if @resolution_log.nil? true end |