Class: Plaid::BetaIssuesV1IssueBehavior
- Inherits:
-
Object
- Object
- Plaid::BetaIssuesV1IssueBehavior
- Defined in:
- lib/plaid/models/beta_issues_v1_issue_behavior.rb
Constant Summary collapse
- NEW_CONNECTIONS_CANNOT_BE_ESTABLISHED =
"NEW_CONNECTIONS_CANNOT_BE_ESTABLISHED".freeze
- EXISTING_CONNECTIONS_WILL_NOT_RECEIVE_UPDATES =
"EXISTING_CONNECTIONS_WILL_NOT_RECEIVE_UPDATES".freeze
- EXISTING_CONNECTIONS_WILL_BE_DISCONNECTED =
"EXISTING_CONNECTIONS_WILL_BE_DISCONNECTED".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
25 26 27 |
# File 'lib/plaid/models/beta_issues_v1_issue_behavior.rb', line 25 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
32 33 34 35 36 37 |
# File 'lib/plaid/models/beta_issues_v1_issue_behavior.rb', line 32 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |