Class: Plaid::BetaIssuesV1IssueSeverity
- Inherits:
-
Object
- Object
- Plaid::BetaIssuesV1IssueSeverity
- Defined in:
- lib/plaid/models/beta_issues_v1_issue_severity.rb
Constant Summary collapse
- CRITICAL =
"CRITICAL".freeze
- HIGH =
"HIGH".freeze
- MEDIUM =
"MEDIUM".freeze
- LOW =
"LOW".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
26 27 28 |
# File 'lib/plaid/models/beta_issues_v1_issue_severity.rb', line 26 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
33 34 35 36 37 38 |
# File 'lib/plaid/models/beta_issues_v1_issue_severity.rb', line 33 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |