Class: Plaid::BetaIssuesV1IssueStatus

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/beta_issues_v1_issue_status.rb

Constant Summary collapse

USER_ACTION_REQUIRED =
"USER_ACTION_REQUIRED".freeze
BACKLOGGED =
"BACKLOGGED".freeze
LIKELY_TO_BE_PRIORITIZED =
"LIKELY_TO_BE_PRIORITIZED".freeze
IN_PROGRESS =
"IN_PROGRESS".freeze
RESOLVED =
"RESOLVED".freeze
PENDING_NOTIFICATION =
"PENDING_NOTIFICATION".freeze
DATA_PARTNER_NOTIFIED =
"DATA_PARTNER_NOTIFIED".freeze
DATA_PARTNER_FIX_IN_PROGRESS =
"DATA_PARTNER_FIX_IN_PROGRESS".freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



30
31
32
# File 'lib/plaid/models/beta_issues_v1_issue_status.rb', line 30

def self.build_from_hash(value)
  new.build_from_hash(value)
end

Instance Method Details

#build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



37
38
39
40
41
42
# File 'lib/plaid/models/beta_issues_v1_issue_status.rb', line 37

def build_from_hash(value)
  # We do not validate that the value is one of the enums set in the OpenAPI
  # file because we want to be able to add to our list of enums without
  # breaking this client library.
  value
end