Class: Plaid::BetaWebhookEventsListRequest
- Inherits:
-
Object
- Object
- Plaid::BetaWebhookEventsListRequest
- Defined in:
- lib/plaid/models/beta_webhook_events_list_request.rb
Overview
BetaWebhookEventsListRequest defines the request schema for /beta/webhook_events/list
Instance Attribute Summary collapse
-
#client_id ⇒ Object
Your Plaid API
client_id. -
#count ⇒ Object
Page size.
-
#cursor ⇒ Object
Opaque cursor from a prior
/beta/webhook_events/listresponsenext_cursor. -
#delivery_statuses ⇒ Object
Filter by delivery status.
-
#item_ids ⇒ Object
Filter to specific Items.
-
#secret ⇒ Object
Your Plaid API
secret. -
#start_time ⇒ Object
ISO-8601 timestamp.
-
#webhook_codes ⇒ Object
Filter by webhook code.
-
#webhook_types ⇒ Object
Filter by webhook type.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BetaWebhookEventsListRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ BetaWebhookEventsListRequest
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::BetaWebhookEventsListRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::BetaWebhookEventsListRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'cursor') self.cursor = attributes[:'cursor'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] end if attributes.key?(:'count') self.count = attributes[:'count'] else self.count = 100 end if attributes.key?(:'webhook_types') if (value = attributes[:'webhook_types']).is_a?(Array) self.webhook_types = value end end if attributes.key?(:'webhook_codes') if (value = attributes[:'webhook_codes']).is_a?(Array) self.webhook_codes = value end end if attributes.key?(:'item_ids') if (value = attributes[:'item_ids']).is_a?(Array) self.item_ids = value end end if attributes.key?(:'delivery_statuses') if (value = attributes[:'delivery_statuses']).is_a?(Array) self.delivery_statuses = value end end end |
Instance Attribute Details
#client_id ⇒ Object
Your Plaid API client_id. The client_id is required and may be provided either in the PLAID-CLIENT-ID header or as part of a request body.
20 21 22 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 20 def client_id @client_id end |
#count ⇒ Object
Page size. Default 100, maximum 100.
32 33 34 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 32 def count @count end |
#cursor ⇒ Object
Opaque cursor from a prior /beta/webhook_events/list response next_cursor. Use this on subsequent requests to continue forward. Mutually exclusive with start_time.
26 27 28 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 26 def cursor @cursor end |
#delivery_statuses ⇒ Object
Filter by delivery status. Returns webhook events whose latest delivery state matches any of the supplied values. Combined with other filters using AND.
44 45 46 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 44 def delivery_statuses @delivery_statuses end |
#item_ids ⇒ Object
Filter to specific Items. Multiple values are OR'd. Combined with other filters using AND.
41 42 43 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 41 def item_ids @item_ids end |
#secret ⇒ Object
Your Plaid API secret. The secret is required and may be provided either in the PLAID-SECRET header or as part of a request body.
23 24 25 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 23 def secret @secret end |
#start_time ⇒ Object
ISO-8601 timestamp. Returns webhook events with sent_time greater than or equal to this value. Must fall within the last 7 days (the retention window). Mutually exclusive with cursor. Omit to begin from the oldest retained event.
29 30 31 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 29 def start_time @start_time end |
#webhook_codes ⇒ Object
Filter by webhook code. Multiple values are OR'd. Combined with other filters using AND.
38 39 40 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 38 def webhook_codes @webhook_codes end |
#webhook_types ⇒ Object
Filter by webhook type. Multiple values are OR'd. Combined with other filters using AND.
35 36 37 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 35 def webhook_types @webhook_types end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 62 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 47 def self.attribute_map { :'client_id' => :'client_id', :'secret' => :'secret', :'cursor' => :'cursor', :'start_time' => :'start_time', :'count' => :'count', :'webhook_types' => :'webhook_types', :'webhook_codes' => :'webhook_codes', :'item_ids' => :'item_ids', :'delivery_statuses' => :'delivery_statuses' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 238 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 87 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 82 def self.openapi_nullable Set.new([ :'start_time', :'count', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 67 def self.openapi_types { :'client_id' => :'String', :'secret' => :'String', :'cursor' => :'String', :'start_time' => :'Time', :'count' => :'Integer', :'webhook_types' => :'Array<String>', :'webhook_codes' => :'Array<String>', :'item_ids' => :'Array<String>', :'delivery_statuses' => :'Array<WebhookEventDeliveryStatus>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 209 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && secret == o.secret && cursor == o.cursor && start_time == o.start_time && count == o.count && webhook_types == o.webhook_types && webhook_codes == o.webhook_codes && item_ids == o.item_ids && delivery_statuses == o.delivery_statuses end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 269 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 340 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 245 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 231 def hash [client_id, secret, cursor, start_time, count, webhook_types, webhook_codes, item_ids, delivery_statuses].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 153 def list_invalid_properties invalid_properties = Array.new if !@cursor.nil? && @cursor.to_s.length > 512 invalid_properties.push('invalid value for "cursor", the character length must be smaller than or equal to 512.') end if !@count.nil? && @count > 100 invalid_properties.push('invalid value for "count", must be smaller than or equal to 100.') end if !@count.nil? && @count < 1 invalid_properties.push('invalid value for "count", must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
316 317 318 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 316 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
310 311 312 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 310 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 |
# File 'lib/plaid/models/beta_webhook_events_list_request.rb', line 174 def valid? return false if !@cursor.nil? && @cursor.to_s.length > 512 return false if !@count.nil? && @count > 100 return false if !@count.nil? && @count < 1 true end |