Class: Plaid::CraCheckReportCreateRequest
- Inherits:
-
Object
- Object
- Plaid::CraCheckReportCreateRequest
- Defined in:
- lib/plaid/models/cra_check_report_create_request.rb
Overview
CraCheckReportCreateRequest defines the request schema for /cra/check_report/create.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#base_report ⇒ Object
Returns the value of attribute base_report.
-
#cashflow_insights ⇒ Object
Returns the value of attribute cashflow_insights.
-
#client_id ⇒ Object
Your Plaid API
client_id. -
#client_report_id ⇒ Object
Client-generated identifier, which can be used by lenders to track loan applications.
-
#consumer_report_permissible_purpose ⇒ Object
Returns the value of attribute consumer_report_permissible_purpose.
-
#days_requested ⇒ Object
The number of days of data to request for the report.
-
#days_required ⇒ Object
The minimum number of days of data required for the report to be successfully generated.
-
#include_investments ⇒ Object
Indicates that investment data should be extracted from the linked account(s).
-
#income_insights ⇒ Object
Returns the value of attribute income_insights.
-
#lend_score ⇒ Object
Returns the value of attribute lend_score.
-
#network_insights ⇒ Object
Returns the value of attribute network_insights.
-
#partner_insights ⇒ Object
Returns the value of attribute partner_insights.
-
#products ⇒ Object
Specifies a list of products that will be eagerly generated when creating the report (in addition to the Base Report, which is always eagerly generated).
-
#secret ⇒ Object
Your Plaid API
secret. -
#user_id ⇒ Object
A unique user identifier, created by
/user/create. -
#user_token ⇒ Object
The user token associated with the User data is being requested for.
-
#webhook ⇒ Object
The destination URL to which webhooks will be sent.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CraCheckReportCreateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CraCheckReportCreateRequest
Initializes the object
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 153 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraCheckReportCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraCheckReportCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'user_token') self.user_token = attributes[:'user_token'] end if attributes.key?(:'webhook') self.webhook = attributes[:'webhook'] end if attributes.key?(:'days_requested') self.days_requested = attributes[:'days_requested'] end if attributes.key?(:'days_required') self.days_required = attributes[:'days_required'] end if attributes.key?(:'client_report_id') self.client_report_id = attributes[:'client_report_id'] end if attributes.key?(:'products') if (value = attributes[:'products']).is_a?(Array) self.products = value end end if attributes.key?(:'base_report') self.base_report = attributes[:'base_report'] end if attributes.key?(:'cashflow_insights') self.cashflow_insights = attributes[:'cashflow_insights'] end if attributes.key?(:'partner_insights') self.partner_insights = attributes[:'partner_insights'] end if attributes.key?(:'lend_score') self.lend_score = attributes[:'lend_score'] end if attributes.key?(:'network_insights') self.network_insights = attributes[:'network_insights'] end if attributes.key?(:'include_investments') self.include_investments = attributes[:'include_investments'] end if attributes.key?(:'income_insights') self.income_insights = attributes[:'income_insights'] end if attributes.key?(:'consumer_report_permissible_purpose') self.consumer_report_permissible_purpose = attributes[:'consumer_report_permissible_purpose'] end end |
Instance Attribute Details
#base_report ⇒ Object
Returns the value of attribute base_report.
46 47 48 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 46 def base_report @base_report end |
#cashflow_insights ⇒ Object
Returns the value of attribute cashflow_insights.
48 49 50 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 48 def cashflow_insights @cashflow_insights end |
#client_id ⇒ Object
Your Plaid API client_id. The client_id is required and may be provided either in the PLAID-CLIENT-ID header or as part of a request body.
20 21 22 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 20 def client_id @client_id end |
#client_report_id ⇒ Object
Client-generated identifier, which can be used by lenders to track loan applications.
41 42 43 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 41 def client_report_id @client_report_id end |
#consumer_report_permissible_purpose ⇒ Object
Returns the value of attribute consumer_report_permissible_purpose.
61 62 63 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 61 def consumer_report_permissible_purpose @consumer_report_permissible_purpose end |
#days_requested ⇒ Object
The number of days of data to request for the report. Default value is 365; maximum is 731; minimum is 180. If a value lower than 180 is provided, a minimum of 180 days of history will be requested.
35 36 37 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 35 def days_requested @days_requested end |
#days_required ⇒ Object
The minimum number of days of data required for the report to be successfully generated.
38 39 40 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 38 def days_required @days_required end |
#include_investments ⇒ Object
Indicates that investment data should be extracted from the linked account(s).
57 58 59 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 57 def include_investments @include_investments end |
#income_insights ⇒ Object
Returns the value of attribute income_insights.
59 60 61 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 59 def income_insights @income_insights end |
#lend_score ⇒ Object
Returns the value of attribute lend_score.
52 53 54 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 52 def lend_score @lend_score end |
#network_insights ⇒ Object
Returns the value of attribute network_insights.
54 55 56 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 54 def network_insights @network_insights end |
#partner_insights ⇒ Object
Returns the value of attribute partner_insights.
50 51 52 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 50 def partner_insights @partner_insights end |
#products ⇒ Object
Specifies a list of products that will be eagerly generated when creating the report (in addition to the Base Report, which is always eagerly generated). These products will be made available before a success webhook is sent. Use this option to minimize response latency for product /get endpoints. Note that specifying cra_partner_insights in this field will trigger a billable event. Other products are not billed until the respective reports are fetched via product-specific /get endpoints.
44 45 46 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 44 def products @products end |
#secret ⇒ Object
Your Plaid API secret. The secret is required and may be provided either in the PLAID-SECRET header or as part of a request body.
23 24 25 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 23 def secret @secret end |
#user_id ⇒ Object
A unique user identifier, created by /user/create. Integrations that began using /user/create after December 10, 2025 use this field to identify a user instead of the user_token. For more details, see [new user APIs](plaid.com/docs/api/users/user-apis).
26 27 28 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 26 def user_id @user_id end |
#user_token ⇒ Object
The user token associated with the User data is being requested for. This field is used only by customers with pre-existing integrations that already use the user_token field. All other customers should use the user_id instead. For more details, see [New User APIs](plaid.com/docs/api/users/user-apis).
29 30 31 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 29 def user_token @user_token end |
#webhook ⇒ Object
The destination URL to which webhooks will be sent
32 33 34 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 32 def webhook @webhook end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 109 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 86 def self.attribute_map { :'client_id' => :'client_id', :'secret' => :'secret', :'user_id' => :'user_id', :'user_token' => :'user_token', :'webhook' => :'webhook', :'days_requested' => :'days_requested', :'days_required' => :'days_required', :'client_report_id' => :'client_report_id', :'products' => :'products', :'base_report' => :'base_report', :'cashflow_insights' => :'cashflow_insights', :'partner_insights' => :'partner_insights', :'lend_score' => :'lend_score', :'network_insights' => :'network_insights', :'include_investments' => :'include_investments', :'income_insights' => :'income_insights', :'consumer_report_permissible_purpose' => :'consumer_report_permissible_purpose' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
359 360 361 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 359 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 137 def self.openapi_nullable Set.new([ :'client_report_id', :'products', :'base_report', :'cashflow_insights', :'partner_insights', :'lend_score', :'network_insights', :'include_investments', :'income_insights', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 114 def self.openapi_types { :'client_id' => :'String', :'secret' => :'String', :'user_id' => :'String', :'user_token' => :'String', :'webhook' => :'String', :'days_requested' => :'Integer', :'days_required' => :'Integer', :'client_report_id' => :'String', :'products' => :'Array<Products>', :'base_report' => :'CraCheckReportCreateBaseReportOptions', :'cashflow_insights' => :'CraCheckReportCashflowInsightsGetOptions', :'partner_insights' => :'CraCheckReportCreatePartnerInsightsOptions', :'lend_score' => :'CraCheckReportLendScoreGetOptions', :'network_insights' => :'CraCheckReportNetworkInsightsGetOptions', :'include_investments' => :'Boolean', :'income_insights' => :'CraCheckReportIncomeInsightsGetOptions', :'consumer_report_permissible_purpose' => :'ConsumerReportPermissiblePurpose' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && secret == o.secret && user_id == o.user_id && user_token == o.user_token && webhook == o.webhook && days_requested == o.days_requested && days_required == o.days_required && client_report_id == o.client_report_id && products == o.products && base_report == o.base_report && cashflow_insights == o.cashflow_insights && partner_insights == o.partner_insights && lend_score == o.lend_score && network_insights == o.network_insights && include_investments == o.include_investments && income_insights == o.income_insights && consumer_report_permissible_purpose == o.consumer_report_permissible_purpose end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 390 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 461 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 366 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
346 347 348 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 346 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
352 353 354 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 352 def hash [client_id, secret, user_id, user_token, webhook, days_requested, days_required, client_report_id, products, base_report, cashflow_insights, partner_insights, lend_score, network_insights, include_investments, income_insights, consumer_report_permissible_purpose].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 239 def list_invalid_properties invalid_properties = Array.new if @webhook.nil? invalid_properties.push('invalid value for "webhook", webhook cannot be nil.') end if @days_requested.nil? invalid_properties.push('invalid value for "days_requested", days_requested cannot be nil.') end if @days_requested > 731 invalid_properties.push('invalid value for "days_requested", must be smaller than or equal to 731.') end if !@days_required.nil? && @days_required > 184 invalid_properties.push('invalid value for "days_required", must be smaller than or equal to 184.') end if !@products.nil? && @products.length < 1 invalid_properties.push('invalid value for "products", number of items must be greater than or equal to 1.') end if @consumer_report_permissible_purpose.nil? invalid_properties.push('invalid value for "consumer_report_permissible_purpose", consumer_report_permissible_purpose cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
437 438 439 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 437 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
443 444 445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 443 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
431 432 433 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 431 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
273 274 275 276 277 278 279 280 281 |
# File 'lib/plaid/models/cra_check_report_create_request.rb', line 273 def valid? return false if @webhook.nil? return false if @days_requested.nil? return false if @days_requested > 731 return false if !@days_required.nil? && @days_required > 184 return false if !@products.nil? && @products.length < 1 return false if @consumer_report_permissible_purpose.nil? true end |