Class: Plaid::CraCheckReportVerificationPdfGetRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/cra_check_report_verification_pdf_get_request.rb

Overview

CraCheckReportVerificationPdfGetRequest defines the request schema for /cra/check_report/verification/pdf/get.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CraCheckReportVerificationPdfGetRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraCheckReportVerificationPdfGetRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraCheckReportVerificationPdfGetRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'third_party_user_token')
    self.third_party_user_token = attributes[:'third_party_user_token']
  end

  if attributes.key?(:'report_requested')
    self.report_requested = attributes[:'report_requested']
  end

  if attributes.key?(:'reports_requested')
    if (value = attributes[:'reports_requested']).is_a?(Array)
      self.reports_requested = value
    end
  end

  if attributes.key?(:'hide_gse_details')
    self.hide_gse_details = attributes[:'hide_gse_details']
  end

  if attributes.key?(:'user_token')
    self.user_token = attributes[:'user_token']
  end
end

Instance Attribute Details

#client_idObject

Your Plaid API client_id. The client_id is required and may be provided either in the PLAID-CLIENT-ID header or as part of a request body.



20
21
22
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 20

def client_id
  @client_id
end

#hide_gse_detailsObject

If true, the GSE identifiers (the Report ID and gse_reference_id) are omitted from the returned Home Lending Report PDF. Defaults to false. These identifiers are always present in the /cra/check_report/verification/get JSON response regardless of this field.



37
38
39
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 37

def hide_gse_details
  @hide_gse_details
end

#report_requestedObject

Returns the value of attribute report_requested.



31
32
33
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 31

def report_requested
  @report_requested
end

#reports_requestedObject

Specifies which types of verification reports to include in the returned PDF. Supported combinations are: [voa], [employment_refresh], [income], or [voa, income]. Other combinations are not supported.



34
35
36
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 34

def reports_requested
  @reports_requested
end

#secretObject

Your Plaid API secret. The secret is required and may be provided either in the PLAID-SECRET header or as part of a request body.



23
24
25
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 23

def secret
  @secret
end

#third_party_user_tokenObject

The third-party user token associated with the requested User data.



29
30
31
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 29

def third_party_user_token
  @third_party_user_token
end

#user_idObject

A unique user identifier, created by /user/create. Integrations that began using /user/create after December 10, 2025 use this field to identify a user instead of the user_token. For more details, see New User APIs.



26
27
28
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 26

def user_id
  @user_id
end

#user_tokenObject

The user token associated with the user for which data is being requested. This field is used only by customers with pre-existing integrations that already use the user_token field. All other customers should use the user_id instead. For more details, see New User APIs.



40
41
42
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 40

def user_token
  @user_token
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 57

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 43

def self.attribute_map
  {
    :'client_id' => :'client_id',
    :'secret' => :'secret',
    :'user_id' => :'user_id',
    :'third_party_user_token' => :'third_party_user_token',
    :'report_requested' => :'report_requested',
    :'reports_requested' => :'reports_requested',
    :'hide_gse_details' => :'hide_gse_details',
    :'user_token' => :'user_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 191

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 62

def self.openapi_types
  {
    :'client_id' => :'String',
    :'secret' => :'String',
    :'user_id' => :'String',
    :'third_party_user_token' => :'String',
    :'report_requested' => :'CraCheckReportVerificationPdfReportType',
    :'reports_requested' => :'Array<CraCheckReportVerificationPdfReportType>',
    :'hide_gse_details' => :'Boolean',
    :'user_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      secret == o.secret &&
      user_id == o.user_id &&
      third_party_user_token == o.third_party_user_token &&
      report_requested == o.report_requested &&
      reports_requested == o.reports_requested &&
      hide_gse_details == o.hide_gse_details &&
      user_token == o.user_token
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 222

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 293

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 198

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 184

def hash
  [client_id, secret, user_id, third_party_user_token, report_requested, reports_requested, hide_gse_details, user_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 133

def list_invalid_properties
  invalid_properties = Array.new

  if !@reports_requested.nil? && @reports_requested.length < 1
    invalid_properties.push('invalid value for "reports_requested", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 269

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



263
264
265
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 263

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
# File 'lib/plaid/models/cra_check_report_verification_pdf_get_request.rb', line 145

def valid?
  return false if !@reports_requested.nil? && @reports_requested.length < 1
  true
end