Class: Plaid::CraCreditProfileReportMetadata
- Inherits:
-
Object
- Object
- Plaid::CraCreditProfileReportMetadata
- Defined in:
- lib/plaid/models/cra_credit_profile_report_metadata.rb
Overview
Metadata about the CRA Credit Profile Report.
Instance Attribute Summary collapse
-
#account_count ⇒ Object
The total number of accounts in the report.
-
#credit_account_type_count ⇒ Object
The number of credit accounts in the report.
-
#depository_account_type_count ⇒ Object
The number of depository accounts in the report.
-
#generated_at ⇒ Object
The time when the report was generated.
-
#institution_ids ⇒ Object
The institution IDs associated with the report.
-
#item_count ⇒ Object
The number of items used to calculate the report.
-
#most_recent_transaction_date ⇒ Object
The date of the most recent transaction in the report.
-
#multiple_owner_account_count ⇒ Object
The number of accounts with multiple owners in the report.
-
#oldest_transaction_date ⇒ Object
The date of the oldest transaction in the report.
-
#other_account_type_count ⇒ Object
The number of other accounts in the report.
-
#primary_account_count ⇒ Object
The number of primary accounts in the report.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CraCreditProfileReportMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CraCreditProfileReportMetadata
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraCreditProfileReportMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraCreditProfileReportMetadata`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'item_count') self.item_count = attributes[:'item_count'] end if attributes.key?(:'institution_ids') if (value = attributes[:'institution_ids']).is_a?(Array) self.institution_ids = value end end if attributes.key?(:'account_count') self.account_count = attributes[:'account_count'] end if attributes.key?(:'primary_account_count') self.primary_account_count = attributes[:'primary_account_count'] end if attributes.key?(:'depository_account_type_count') self.depository_account_type_count = attributes[:'depository_account_type_count'] end if attributes.key?(:'credit_account_type_count') self.credit_account_type_count = attributes[:'credit_account_type_count'] end if attributes.key?(:'other_account_type_count') self.other_account_type_count = attributes[:'other_account_type_count'] end if attributes.key?(:'multiple_owner_account_count') self.multiple_owner_account_count = attributes[:'multiple_owner_account_count'] end if attributes.key?(:'generated_at') self.generated_at = attributes[:'generated_at'] end if attributes.key?(:'oldest_transaction_date') self.oldest_transaction_date = attributes[:'oldest_transaction_date'] end if attributes.key?(:'most_recent_transaction_date') self.most_recent_transaction_date = attributes[:'most_recent_transaction_date'] end end |
Instance Attribute Details
#account_count ⇒ Object
The total number of accounts in the report.
26 27 28 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 26 def account_count @account_count end |
#credit_account_type_count ⇒ Object
The number of credit accounts in the report.
35 36 37 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 35 def credit_account_type_count @credit_account_type_count end |
#depository_account_type_count ⇒ Object
The number of depository accounts in the report.
32 33 34 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 32 def depository_account_type_count @depository_account_type_count end |
#generated_at ⇒ Object
The time when the report was generated.
44 45 46 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 44 def generated_at @generated_at end |
#institution_ids ⇒ Object
The institution IDs associated with the report.
23 24 25 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 23 def institution_ids @institution_ids end |
#item_count ⇒ Object
The number of items used to calculate the report.
20 21 22 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 20 def item_count @item_count end |
#most_recent_transaction_date ⇒ Object
The date of the most recent transaction in the report.
50 51 52 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 50 def most_recent_transaction_date @most_recent_transaction_date end |
#multiple_owner_account_count ⇒ Object
The number of accounts with multiple owners in the report.
41 42 43 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 41 def multiple_owner_account_count @multiple_owner_account_count end |
#oldest_transaction_date ⇒ Object
The date of the oldest transaction in the report.
47 48 49 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 47 def oldest_transaction_date @oldest_transaction_date end |
#other_account_type_count ⇒ Object
The number of other accounts in the report.
38 39 40 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 38 def other_account_type_count @other_account_type_count end |
#primary_account_count ⇒ Object
The number of primary accounts in the report.
29 30 31 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 29 def primary_account_count @primary_account_count end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 70 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 53 def self.attribute_map { :'item_count' => :'item_count', :'institution_ids' => :'institution_ids', :'account_count' => :'account_count', :'primary_account_count' => :'primary_account_count', :'depository_account_type_count' => :'depository_account_type_count', :'credit_account_type_count' => :'credit_account_type_count', :'other_account_type_count' => :'other_account_type_count', :'multiple_owner_account_count' => :'multiple_owner_account_count', :'generated_at' => :'generated_at', :'oldest_transaction_date' => :'oldest_transaction_date', :'most_recent_transaction_date' => :'most_recent_transaction_date' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
260 261 262 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 260 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 75 def self.openapi_types { :'item_count' => :'Integer', :'institution_ids' => :'Array<String>', :'account_count' => :'Integer', :'primary_account_count' => :'Integer', :'depository_account_type_count' => :'Integer', :'credit_account_type_count' => :'Integer', :'other_account_type_count' => :'Integer', :'multiple_owner_account_count' => :'Integer', :'generated_at' => :'Time', :'oldest_transaction_date' => :'Date', :'most_recent_transaction_date' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && item_count == o.item_count && institution_ids == o.institution_ids && account_count == o.account_count && primary_account_count == o.primary_account_count && depository_account_type_count == o.depository_account_type_count && credit_account_type_count == o.credit_account_type_count && other_account_type_count == o.other_account_type_count && multiple_owner_account_count == o.multiple_owner_account_count && generated_at == o.generated_at && oldest_transaction_date == o.oldest_transaction_date && most_recent_transaction_date == o.most_recent_transaction_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 291 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 267 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
247 248 249 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 247 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
253 254 255 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 253 def hash [item_count, institution_ids, account_count, primary_account_count, depository_account_type_count, credit_account_type_count, other_account_type_count, multiple_owner_account_count, generated_at, oldest_transaction_date, most_recent_transaction_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 161 def list_invalid_properties invalid_properties = Array.new if @item_count.nil? invalid_properties.push('invalid value for "item_count", item_count cannot be nil.') end if @institution_ids.nil? invalid_properties.push('invalid value for "institution_ids", institution_ids cannot be nil.') end if @account_count.nil? invalid_properties.push('invalid value for "account_count", account_count cannot be nil.') end if @primary_account_count.nil? invalid_properties.push('invalid value for "primary_account_count", primary_account_count cannot be nil.') end if @depository_account_type_count.nil? invalid_properties.push('invalid value for "depository_account_type_count", depository_account_type_count cannot be nil.') end if @credit_account_type_count.nil? invalid_properties.push('invalid value for "credit_account_type_count", credit_account_type_count cannot be nil.') end if @other_account_type_count.nil? invalid_properties.push('invalid value for "other_account_type_count", other_account_type_count cannot be nil.') end if @multiple_owner_account_count.nil? invalid_properties.push('invalid value for "multiple_owner_account_count", multiple_owner_account_count cannot be nil.') end if @generated_at.nil? invalid_properties.push('invalid value for "generated_at", generated_at cannot be nil.') end if @oldest_transaction_date.nil? invalid_properties.push('invalid value for "oldest_transaction_date", oldest_transaction_date cannot be nil.') end if @most_recent_transaction_date.nil? invalid_properties.push('invalid value for "most_recent_transaction_date", most_recent_transaction_date cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/plaid/models/cra_credit_profile_report_metadata.rb', line 212 def valid? return false if @item_count.nil? return false if @institution_ids.nil? return false if @account_count.nil? return false if @primary_account_count.nil? return false if @depository_account_type_count.nil? return false if @credit_account_type_count.nil? return false if @other_account_type_count.nil? return false if @multiple_owner_account_count.nil? return false if @generated_at.nil? return false if @oldest_transaction_date.nil? return false if @most_recent_transaction_date.nil? true end |