Class: Plaid::CraPartnerInsightsBaseFicoScore

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/cra_partner_insights_base_fico_score.rb

Overview

Details about the base FICO score associated with an UltraFICO® scoring request.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CraPartnerInsightsBaseFicoScore

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraPartnerInsightsBaseFicoScore` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraPartnerInsightsBaseFicoScore`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'bureau')
    self.bureau = attributes[:'bureau']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'reason_codes')
    if (value = attributes[:'reason_codes']).is_a?(Array)
      self.reason_codes = value
    end
  end

  if attributes.key?(:'reason_code_1')
    self.reason_code_1 = attributes[:'reason_code_1']
  end

  if attributes.key?(:'reason_code_2')
    self.reason_code_2 = attributes[:'reason_code_2']
  end

  if attributes.key?(:'reason_code_3')
    self.reason_code_3 = attributes[:'reason_code_3']
  end

  if attributes.key?(:'reason_code_4')
    self.reason_code_4 = attributes[:'reason_code_4']
  end

  if attributes.key?(:'did_inquiries_adversely_affect_score')
    self.did_inquiries_adversely_affect_score = attributes[:'did_inquiries_adversely_affect_score']
  end

  if attributes.key?(:'base_fico_score_version')
    self.base_fico_score_version = attributes[:'base_fico_score_version']
  end
end

Instance Attribute Details

#base_fico_score_versionObject

Returns the value of attribute base_fico_score_version.



42
43
44
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 42

def base_fico_score_version
  @base_fico_score_version
end

#bureauObject

Returns the value of attribute bureau.



19
20
21
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 19

def bureau
  @bureau
end

#did_inquiries_adversely_affect_scoreObject

Whether inquiries adversely affected the score but were not represented in one of the four reason codes. Sometimes referred to as the FACTA Flag.



40
41
42
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 40

def did_inquiries_adversely_affect_score
  @did_inquiries_adversely_affect_score
end

#reason_code_1Object

Deprecated. Use ‘reason_codes` instead. The first reason code associated with the score.



28
29
30
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 28

def reason_code_1
  @reason_code_1
end

#reason_code_2Object

Deprecated. Use ‘reason_codes` instead. The second reason code associated with the score.



31
32
33
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 31

def reason_code_2
  @reason_code_2
end

#reason_code_3Object

Deprecated. Use ‘reason_codes` instead. The third reason code associated with the score.



34
35
36
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 34

def reason_code_3
  @reason_code_3
end

#reason_code_4Object

Deprecated. Use ‘reason_codes` instead. The fourth reason code associated with the score.



37
38
39
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 37

def reason_code_4
  @reason_code_4
end

#reason_codesObject

Reason codes associated with the score, in priority order. May contain up to 4 items.



25
26
27
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 25

def reason_codes
  @reason_codes
end

#scoreObject

Numeric value of the base FICO score.



22
23
24
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 22

def score
  @score
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 82

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 67

def self.attribute_map
  {
    :'bureau' => :'bureau',
    :'score' => :'score',
    :'reason_codes' => :'reason_codes',
    :'reason_code_1' => :'reason_code_1',
    :'reason_code_2' => :'reason_code_2',
    :'reason_code_3' => :'reason_code_3',
    :'reason_code_4' => :'reason_code_4',
    :'did_inquiries_adversely_affect_score' => :'did_inquiries_adversely_affect_score',
    :'base_fico_score_version' => :'base_fico_score_version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 234

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 102

def self.openapi_nullable
  Set.new([
    :'reason_code_1',
    :'reason_code_2',
    :'reason_code_3',
    :'reason_code_4',
    :'did_inquiries_adversely_affect_score',
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 87

def self.openapi_types
  {
    :'bureau' => :'CraPartnerInsightsBureau',
    :'score' => :'Integer',
    :'reason_codes' => :'Array<String>',
    :'reason_code_1' => :'String',
    :'reason_code_2' => :'String',
    :'reason_code_3' => :'String',
    :'reason_code_4' => :'String',
    :'did_inquiries_adversely_affect_score' => :'Boolean',
    :'base_fico_score_version' => :'CraPartnerInsightsBaseFicoScoreVersion'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      bureau == o.bureau &&
      score == o.score &&
      reason_codes == o.reason_codes &&
      reason_code_1 == o.reason_code_1 &&
      reason_code_2 == o.reason_code_2 &&
      reason_code_3 == o.reason_code_3 &&
      reason_code_4 == o.reason_code_4 &&
      did_inquiries_adversely_affect_score == o.did_inquiries_adversely_affect_score &&
      base_fico_score_version == o.base_fico_score_version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 265

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 336

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 241

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 227

def hash
  [bureau, score, reason_codes, reason_code_1, reason_code_2, reason_code_3, reason_code_4, did_inquiries_adversely_affect_score, base_fico_score_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 168

def list_invalid_properties
  invalid_properties = Array.new
  if @bureau.nil?
    invalid_properties.push('invalid value for "bureau", bureau cannot be nil.')
  end

  if @score.nil?
    invalid_properties.push('invalid value for "score", score cannot be nil.')
  end


  if @base_fico_score_version.nil?
    invalid_properties.push('invalid value for "base_fico_score_version", base_fico_score_version cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



312
313
314
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 312

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



306
307
308
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 306

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



188
189
190
191
192
193
194
# File 'lib/plaid/models/cra_partner_insights_base_fico_score.rb', line 188

def valid?
  return false if @bureau.nil?
  return false if @score.nil?
  return false if !@reason_codes.nil? && @reason_codes.length > 4
  return false if @base_fico_score_version.nil?
  true
end