Class: Plaid::CraPartnerInsightsFicoReportCharacteristics

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb

Overview

Report characteristics returned by FICO describing the banking data used to generate the UltraFICO score.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CraPartnerInsightsFicoReportCharacteristics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 170

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraPartnerInsightsFicoReportCharacteristics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraPartnerInsightsFicoReportCharacteristics`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'num_accounts')
    self.num_accounts = attributes[:'num_accounts']
  end

  if attributes.key?(:'avg_daily_balance_over_1_month')
    self.avg_daily_balance_over_1_month = attributes[:'avg_daily_balance_over_1_month']
  end

  if attributes.key?(:'avg_daily_balance_over_3_months')
    self.avg_daily_balance_over_3_months = attributes[:'avg_daily_balance_over_3_months']
  end

  if attributes.key?(:'avg_daily_balance_over_6_months')
    self.avg_daily_balance_over_6_months = attributes[:'avg_daily_balance_over_6_months']
  end

  if attributes.key?(:'avg_daily_balance_over_12_months')
    self.avg_daily_balance_over_12_months = attributes[:'avg_daily_balance_over_12_months']
  end

  if attributes.key?(:'days_since_earliest_tx')
    self.days_since_earliest_tx = attributes[:'days_since_earliest_tx']
  end

  if attributes.key?(:'days_since_most_recent_negative_ending_balance')
    self.days_since_most_recent_negative_ending_balance = attributes[:'days_since_most_recent_negative_ending_balance']
  end

  if attributes.key?(:'days_since_most_recent_insufficient_funds_fee_debit_tx')
    self.days_since_most_recent_insufficient_funds_fee_debit_tx = attributes[:'days_since_most_recent_insufficient_funds_fee_debit_tx']
  end

  if attributes.key?(:'tot_number_days_with_negative_balance_over_1_month')
    self.tot_number_days_with_negative_balance_over_1_month = attributes[:'tot_number_days_with_negative_balance_over_1_month']
  end

  if attributes.key?(:'tot_number_days_with_negative_balance_over_3_months')
    self.tot_number_days_with_negative_balance_over_3_months = attributes[:'tot_number_days_with_negative_balance_over_3_months']
  end

  if attributes.key?(:'tot_number_days_with_negative_balance_over_6_months')
    self.tot_number_days_with_negative_balance_over_6_months = attributes[:'tot_number_days_with_negative_balance_over_6_months']
  end

  if attributes.key?(:'tot_number_days_with_negative_balance_over_12_months')
    self.tot_number_days_with_negative_balance_over_12_months = attributes[:'tot_number_days_with_negative_balance_over_12_months']
  end

  if attributes.key?(:'days_since_most_recent_tx')
    self.days_since_most_recent_tx = attributes[:'days_since_most_recent_tx']
  end

  if attributes.key?(:'days_with_tx_over_1_month')
    self.days_with_tx_over_1_month = attributes[:'days_with_tx_over_1_month']
  end

  if attributes.key?(:'days_with_tx_over_3_months')
    self.days_with_tx_over_3_months = attributes[:'days_with_tx_over_3_months']
  end

  if attributes.key?(:'days_with_tx_over_6_months')
    self.days_with_tx_over_6_months = attributes[:'days_with_tx_over_6_months']
  end

  if attributes.key?(:'days_with_tx_over_12_months')
    self.days_with_tx_over_12_months = attributes[:'days_with_tx_over_12_months']
  end

  if attributes.key?(:'tot_current_balances')
    self.tot_current_balances = attributes[:'tot_current_balances']
  end

  if attributes.key?(:'num_checking_accounts')
    self.num_checking_accounts = attributes[:'num_checking_accounts']
  end

  if attributes.key?(:'num_money_market_accounts')
    self.num_money_market_accounts = attributes[:'num_money_market_accounts']
  end

  if attributes.key?(:'num_savings_accounts')
    self.num_savings_accounts = attributes[:'num_savings_accounts']
  end
end

Instance Attribute Details

#avg_daily_balance_over_12_monthsObject

Average daily balance over the past 12 months.



32
33
34
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 32

def avg_daily_balance_over_12_months
  @avg_daily_balance_over_12_months
end

#avg_daily_balance_over_1_monthObject

Average daily balance over the past 1 month.



23
24
25
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 23

def avg_daily_balance_over_1_month
  @avg_daily_balance_over_1_month
end

#avg_daily_balance_over_3_monthsObject

Average daily balance over the past 3 months.



26
27
28
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 26

def avg_daily_balance_over_3_months
  @avg_daily_balance_over_3_months
end

#avg_daily_balance_over_6_monthsObject

Average daily balance over the past 6 months.



29
30
31
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 29

def avg_daily_balance_over_6_months
  @avg_daily_balance_over_6_months
end

#days_since_earliest_txObject

Number of days since the earliest transaction in the report.



35
36
37
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 35

def days_since_earliest_tx
  @days_since_earliest_tx
end

#days_since_most_recent_insufficient_funds_fee_debit_txObject

Number of days since the most recent insufficient funds fee debit transaction.



41
42
43
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 41

def days_since_most_recent_insufficient_funds_fee_debit_tx
  @days_since_most_recent_insufficient_funds_fee_debit_tx
end

#days_since_most_recent_negative_ending_balanceObject

Number of days since the most recent day with a negative ending balance.



38
39
40
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 38

def days_since_most_recent_negative_ending_balance
  @days_since_most_recent_negative_ending_balance
end

#days_since_most_recent_txObject

Number of days since the most recent transaction.



56
57
58
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 56

def days_since_most_recent_tx
  @days_since_most_recent_tx
end

#days_with_tx_over_12_monthsObject

Number of days with at least one transaction over the past 12 months.



68
69
70
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 68

def days_with_tx_over_12_months
  @days_with_tx_over_12_months
end

#days_with_tx_over_1_monthObject

Number of days with at least one transaction over the past 1 month.



59
60
61
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 59

def days_with_tx_over_1_month
  @days_with_tx_over_1_month
end

#days_with_tx_over_3_monthsObject

Number of days with at least one transaction over the past 3 months.



62
63
64
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 62

def days_with_tx_over_3_months
  @days_with_tx_over_3_months
end

#days_with_tx_over_6_monthsObject

Number of days with at least one transaction over the past 6 months.



65
66
67
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 65

def days_with_tx_over_6_months
  @days_with_tx_over_6_months
end

#num_accountsObject

Total number of accounts included in the report. Limited to checking, savings, and money market accounts.



20
21
22
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 20

def num_accounts
  @num_accounts
end

#num_checking_accountsObject

Number of checking accounts included in the report.



74
75
76
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 74

def num_checking_accounts
  @num_checking_accounts
end

#num_money_market_accountsObject

Number of money market accounts included in the report.



77
78
79
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 77

def num_money_market_accounts
  @num_money_market_accounts
end

#num_savings_accountsObject

Number of savings accounts included in the report.



80
81
82
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 80

def num_savings_accounts
  @num_savings_accounts
end

#tot_current_balancesObject

Sum of current balances across all accounts in the report.



71
72
73
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 71

def tot_current_balances
  @tot_current_balances
end

#tot_number_days_with_negative_balance_over_12_monthsObject

Total number of days with a negative balance over the past 12 months.



53
54
55
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 53

def tot_number_days_with_negative_balance_over_12_months
  @tot_number_days_with_negative_balance_over_12_months
end

#tot_number_days_with_negative_balance_over_1_monthObject

Total number of days with a negative balance over the past 1 month.



44
45
46
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 44

def tot_number_days_with_negative_balance_over_1_month
  @tot_number_days_with_negative_balance_over_1_month
end

#tot_number_days_with_negative_balance_over_3_monthsObject

Total number of days with a negative balance over the past 3 months.



47
48
49
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 47

def tot_number_days_with_negative_balance_over_3_months
  @tot_number_days_with_negative_balance_over_3_months
end

#tot_number_days_with_negative_balance_over_6_monthsObject

Total number of days with a negative balance over the past 6 months.



50
51
52
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 50

def tot_number_days_with_negative_balance_over_6_months
  @tot_number_days_with_negative_balance_over_6_months
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 110

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 83

def self.attribute_map
  {
    :'num_accounts' => :'num_accounts',
    :'avg_daily_balance_over_1_month' => :'avg_daily_balance_over_1_month',
    :'avg_daily_balance_over_3_months' => :'avg_daily_balance_over_3_months',
    :'avg_daily_balance_over_6_months' => :'avg_daily_balance_over_6_months',
    :'avg_daily_balance_over_12_months' => :'avg_daily_balance_over_12_months',
    :'days_since_earliest_tx' => :'days_since_earliest_tx',
    :'days_since_most_recent_negative_ending_balance' => :'days_since_most_recent_negative_ending_balance',
    :'days_since_most_recent_insufficient_funds_fee_debit_tx' => :'days_since_most_recent_insufficient_funds_fee_debit_tx',
    :'tot_number_days_with_negative_balance_over_1_month' => :'tot_number_days_with_negative_balance_over_1_month',
    :'tot_number_days_with_negative_balance_over_3_months' => :'tot_number_days_with_negative_balance_over_3_months',
    :'tot_number_days_with_negative_balance_over_6_months' => :'tot_number_days_with_negative_balance_over_6_months',
    :'tot_number_days_with_negative_balance_over_12_months' => :'tot_number_days_with_negative_balance_over_12_months',
    :'days_since_most_recent_tx' => :'days_since_most_recent_tx',
    :'days_with_tx_over_1_month' => :'days_with_tx_over_1_month',
    :'days_with_tx_over_3_months' => :'days_with_tx_over_3_months',
    :'days_with_tx_over_6_months' => :'days_with_tx_over_6_months',
    :'days_with_tx_over_12_months' => :'days_with_tx_over_12_months',
    :'tot_current_balances' => :'tot_current_balances',
    :'num_checking_accounts' => :'num_checking_accounts',
    :'num_money_market_accounts' => :'num_money_market_accounts',
    :'num_savings_accounts' => :'num_savings_accounts'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



324
325
326
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 324

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 142

def self.openapi_nullable
  Set.new([
    :'num_accounts',
    :'avg_daily_balance_over_1_month',
    :'avg_daily_balance_over_3_months',
    :'avg_daily_balance_over_6_months',
    :'avg_daily_balance_over_12_months',
    :'days_since_earliest_tx',
    :'days_since_most_recent_negative_ending_balance',
    :'days_since_most_recent_insufficient_funds_fee_debit_tx',
    :'tot_number_days_with_negative_balance_over_1_month',
    :'tot_number_days_with_negative_balance_over_3_months',
    :'tot_number_days_with_negative_balance_over_6_months',
    :'tot_number_days_with_negative_balance_over_12_months',
    :'days_since_most_recent_tx',
    :'days_with_tx_over_1_month',
    :'days_with_tx_over_3_months',
    :'days_with_tx_over_6_months',
    :'days_with_tx_over_12_months',
    :'tot_current_balances',
    :'num_checking_accounts',
    :'num_money_market_accounts',
    :'num_savings_accounts'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 115

def self.openapi_types
  {
    :'num_accounts' => :'Integer',
    :'avg_daily_balance_over_1_month' => :'Float',
    :'avg_daily_balance_over_3_months' => :'Float',
    :'avg_daily_balance_over_6_months' => :'Float',
    :'avg_daily_balance_over_12_months' => :'Float',
    :'days_since_earliest_tx' => :'Integer',
    :'days_since_most_recent_negative_ending_balance' => :'Integer',
    :'days_since_most_recent_insufficient_funds_fee_debit_tx' => :'Integer',
    :'tot_number_days_with_negative_balance_over_1_month' => :'Integer',
    :'tot_number_days_with_negative_balance_over_3_months' => :'Integer',
    :'tot_number_days_with_negative_balance_over_6_months' => :'Integer',
    :'tot_number_days_with_negative_balance_over_12_months' => :'Integer',
    :'days_since_most_recent_tx' => :'Integer',
    :'days_with_tx_over_1_month' => :'Integer',
    :'days_with_tx_over_3_months' => :'Integer',
    :'days_with_tx_over_6_months' => :'Integer',
    :'days_with_tx_over_12_months' => :'Integer',
    :'tot_current_balances' => :'Float',
    :'num_checking_accounts' => :'Integer',
    :'num_money_market_accounts' => :'Integer',
    :'num_savings_accounts' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      num_accounts == o.num_accounts &&
      avg_daily_balance_over_1_month == o.avg_daily_balance_over_1_month &&
      avg_daily_balance_over_3_months == o.avg_daily_balance_over_3_months &&
      avg_daily_balance_over_6_months == o.avg_daily_balance_over_6_months &&
      avg_daily_balance_over_12_months == o.avg_daily_balance_over_12_months &&
      days_since_earliest_tx == o.days_since_earliest_tx &&
      days_since_most_recent_negative_ending_balance == o.days_since_most_recent_negative_ending_balance &&
      days_since_most_recent_insufficient_funds_fee_debit_tx == o.days_since_most_recent_insufficient_funds_fee_debit_tx &&
      tot_number_days_with_negative_balance_over_1_month == o.tot_number_days_with_negative_balance_over_1_month &&
      tot_number_days_with_negative_balance_over_3_months == o.tot_number_days_with_negative_balance_over_3_months &&
      tot_number_days_with_negative_balance_over_6_months == o.tot_number_days_with_negative_balance_over_6_months &&
      tot_number_days_with_negative_balance_over_12_months == o.tot_number_days_with_negative_balance_over_12_months &&
      days_since_most_recent_tx == o.days_since_most_recent_tx &&
      days_with_tx_over_1_month == o.days_with_tx_over_1_month &&
      days_with_tx_over_3_months == o.days_with_tx_over_3_months &&
      days_with_tx_over_6_months == o.days_with_tx_over_6_months &&
      days_with_tx_over_12_months == o.days_with_tx_over_12_months &&
      tot_current_balances == o.tot_current_balances &&
      num_checking_accounts == o.num_checking_accounts &&
      num_money_market_accounts == o.num_money_market_accounts &&
      num_savings_accounts == o.num_savings_accounts
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 355

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 331

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


311
312
313
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 311

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



317
318
319
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 317

def hash
  [num_accounts, avg_daily_balance_over_1_month, avg_daily_balance_over_3_months, avg_daily_balance_over_6_months, avg_daily_balance_over_12_months, days_since_earliest_tx, days_since_most_recent_negative_ending_balance, days_since_most_recent_insufficient_funds_fee_debit_tx, tot_number_days_with_negative_balance_over_1_month, tot_number_days_with_negative_balance_over_3_months, tot_number_days_with_negative_balance_over_6_months, tot_number_days_with_negative_balance_over_12_months, days_since_most_recent_tx, days_with_tx_over_1_month, days_with_tx_over_3_months, days_with_tx_over_6_months, days_with_tx_over_12_months, tot_current_balances, num_checking_accounts, num_money_market_accounts, num_savings_accounts].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



270
271
272
273
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 270

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



277
278
279
# File 'lib/plaid/models/cra_partner_insights_fico_report_characteristics.rb', line 277

def valid?
  true
end