Class: Plaid::CraUserCheckReportFailedWebhook

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/cra_user_check_report_failed_webhook.rb

Overview

Fired when a Check Report has failed to generate. To get more details, call /user/items/get and check for non-null error objects on the associated Items in the response. These error objects will contain more details on why the Item is in an error state and how to resolve it. After resolving the errors, you can try to re-generate the report.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CraUserCheckReportFailedWebhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraUserCheckReportFailedWebhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraUserCheckReportFailedWebhook`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'webhook_type')
    self.webhook_type = attributes[:'webhook_type']
  end

  if attributes.key?(:'webhook_code')
    self.webhook_code = attributes[:'webhook_code']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'repairable_items')
    if (value = attributes[:'repairable_items']).is_a?(Array)
      self.repairable_items = value
    end
  end

  if attributes.key?(:'failed_products')
    if (value = attributes[:'failed_products']).is_a?(Array)
      self.failed_products = value
    end
  end

  if attributes.key?(:'item_ids')
    if (value = attributes[:'item_ids']).is_a?(Array)
      self.item_ids = value
    end
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end
end

Instance Attribute Details

#environmentObject

Returns the value of attribute environment.



39
40
41
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 39

def environment
  @environment
end

#errorObject

Returns the value of attribute error.



28
29
30
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 28

def error
  @error
end

#failed_productsObject

Specifies a list of products that failed to generate for the report. Populated when generation was attempted and all requested products failed. Additional detail on what caused the failure can be found by calling the product /get endpoint.



34
35
36
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 34

def failed_products
  @failed_products
end

#item_idsObject

A list of item_ids included in the Check Report. Access to this field is in closed beta.



37
38
39
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 37

def item_ids
  @item_ids
end

#repairable_itemsObject

A list of Items that the end user can repair via Link update mode. Empty when no Item is user-repairable. After repairing these Items, call /cra/check_report/create to regenerate the report.



31
32
33
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 31

def repairable_items
  @repairable_items
end

#user_idObject

The user_id associated with the user whose data is being requested. This is received by calling /user/create.



26
27
28
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 26

def user_id
  @user_id
end

#webhook_codeObject

USER_CHECK_REPORT_FAILED



23
24
25
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 23

def webhook_code
  @webhook_code
end

#webhook_typeObject

CHECK_REPORT



20
21
22
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 20

def webhook_type
  @webhook_type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 64

def self.attribute_map
  {
    :'webhook_type' => :'webhook_type',
    :'webhook_code' => :'webhook_code',
    :'user_id' => :'user_id',
    :'error' => :'error',
    :'repairable_items' => :'repairable_items',
    :'failed_products' => :'failed_products',
    :'item_ids' => :'item_ids',
    :'environment' => :'environment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 221

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 97

def self.openapi_nullable
  Set.new([
    :'error',
    :'item_ids',
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 83

def self.openapi_types
  {
    :'webhook_type' => :'String',
    :'webhook_code' => :'String',
    :'user_id' => :'String',
    :'error' => :'CraCheckReportFailedWebhookError',
    :'repairable_items' => :'Array<CheckReportRepairableItem>',
    :'failed_products' => :'Array<Products>',
    :'item_ids' => :'Array<String>',
    :'environment' => :'WebhookEnvironmentValues'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      webhook_type == o.webhook_type &&
      webhook_code == o.webhook_code &&
      user_id == o.user_id &&
      error == o.error &&
      repairable_items == o.repairable_items &&
      failed_products == o.failed_products &&
      item_ids == o.item_ids &&
      environment == o.environment
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 252

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 323

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 228

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 214

def hash
  [webhook_type, webhook_code, user_id, error, repairable_items, failed_products, item_ids, environment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  if @webhook_type.nil?
    invalid_properties.push('invalid value for "webhook_type", webhook_type cannot be nil.')
  end

  if @webhook_code.nil?
    invalid_properties.push('invalid value for "webhook_code", webhook_code cannot be nil.')
  end

  if @user_id.nil?
    invalid_properties.push('invalid value for "user_id", user_id cannot be nil.')
  end

  if @environment.nil?
    invalid_properties.push('invalid value for "environment", environment cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 299

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



293
294
295
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 293

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
# File 'lib/plaid/models/cra_user_check_report_failed_webhook.rb', line 183

def valid?
  return false if @webhook_type.nil?
  return false if @webhook_code.nil?
  return false if @user_id.nil?
  return false if @environment.nil?
  true
end