Class: Plaid::CreditI20

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/credit_i20.rb

Overview

An object representing an end user's Form I-20 US immigration student document.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreditI20

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/plaid/models/credit_i20.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CreditI20` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CreditI20`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'document_id')
    self.document_id = attributes[:'document_id']
  end

  if attributes.key?(:'document_metadata')
    self. = attributes[:'document_metadata']
  end

  if attributes.key?(:'student')
    self.student = attributes[:'student']
  end

  if attributes.key?(:'personal_funds')
    self.personal_funds = attributes[:'personal_funds']
  end

  if attributes.key?(:'on_campus_employment')
    self.on_campus_employment = attributes[:'on_campus_employment']
  end

  if attributes.key?(:'funds_from_this_school')
    self.funds_from_this_school = attributes[:'funds_from_this_school']
  end

  if attributes.key?(:'students_funding_total')
    self.students_funding_total = attributes[:'students_funding_total']
  end

  if attributes.key?(:'funds_from_another_source')
    self.funds_from_another_source = attributes[:'funds_from_another_source']
  end

  if attributes.key?(:'estimated_average_costs_total')
    self.estimated_average_costs_total = attributes[:'estimated_average_costs_total']
  end

  if attributes.key?(:'estimated_average_living_expenses')
    self.estimated_average_living_expenses = attributes[:'estimated_average_living_expenses']
  end

  if attributes.key?(:'students_funding_period_months')
    self.students_funding_period_months = attributes[:'students_funding_period_months']
  end

  if attributes.key?(:'estimated_average_costs_period_months')
    self.estimated_average_costs_period_months = attributes[:'estimated_average_costs_period_months']
  end
end

Instance Attribute Details

#document_idObject

An identifier of the document referenced by the document metadata.



20
21
22
# File 'lib/plaid/models/credit_i20.rb', line 20

def document_id
  @document_id
end

#document_metadataObject

Returns the value of attribute document_metadata.



22
23
24
# File 'lib/plaid/models/credit_i20.rb', line 22

def 
  @document_metadata
end

#estimated_average_costs_period_monthsObject

Number of months the estimated average costs cover.



51
52
53
# File 'lib/plaid/models/credit_i20.rb', line 51

def estimated_average_costs_period_months
  @estimated_average_costs_period_months
end

#estimated_average_costs_totalObject

Estimated total average costs for the program period.



42
43
44
# File 'lib/plaid/models/credit_i20.rb', line 42

def estimated_average_costs_total
  @estimated_average_costs_total
end

#estimated_average_living_expensesObject

Estimated average living expenses.



45
46
47
# File 'lib/plaid/models/credit_i20.rb', line 45

def estimated_average_living_expenses
  @estimated_average_living_expenses
end

#funds_from_another_sourceObject

Amount of funds from another source.



39
40
41
# File 'lib/plaid/models/credit_i20.rb', line 39

def funds_from_another_source
  @funds_from_another_source
end

#funds_from_this_schoolObject

Amount of funds provided by the issuing school.



33
34
35
# File 'lib/plaid/models/credit_i20.rb', line 33

def funds_from_this_school
  @funds_from_this_school
end

#on_campus_employmentObject

Amount of funds from on-campus employment.



30
31
32
# File 'lib/plaid/models/credit_i20.rb', line 30

def on_campus_employment
  @on_campus_employment
end

#personal_fundsObject

Amount of the student's personal funds.



27
28
29
# File 'lib/plaid/models/credit_i20.rb', line 27

def personal_funds
  @personal_funds
end

#studentObject

Returns the value of attribute student.



24
25
26
# File 'lib/plaid/models/credit_i20.rb', line 24

def student
  @student
end

#students_funding_period_monthsObject

Number of months the student's funding covers.



48
49
50
# File 'lib/plaid/models/credit_i20.rb', line 48

def students_funding_period_months
  @students_funding_period_months
end

#students_funding_totalObject

Total amount of funds available to the student.



36
37
38
# File 'lib/plaid/models/credit_i20.rb', line 36

def students_funding_total
  @students_funding_total
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/plaid/models/credit_i20.rb', line 72

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/plaid/models/credit_i20.rb', line 54

def self.attribute_map
  {
    :'document_id' => :'document_id',
    :'document_metadata' => :'document_metadata',
    :'student' => :'student',
    :'personal_funds' => :'personal_funds',
    :'on_campus_employment' => :'on_campus_employment',
    :'funds_from_this_school' => :'funds_from_this_school',
    :'students_funding_total' => :'students_funding_total',
    :'funds_from_another_source' => :'funds_from_another_source',
    :'estimated_average_costs_total' => :'estimated_average_costs_total',
    :'estimated_average_living_expenses' => :'estimated_average_living_expenses',
    :'students_funding_period_months' => :'students_funding_period_months',
    :'estimated_average_costs_period_months' => :'estimated_average_costs_period_months'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
# File 'lib/plaid/models/credit_i20.rb', line 221

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/plaid/models/credit_i20.rb', line 95

def self.openapi_nullable
  Set.new([
    :'document_id',
    :'personal_funds',
    :'on_campus_employment',
    :'funds_from_this_school',
    :'students_funding_total',
    :'funds_from_another_source',
    :'estimated_average_costs_total',
    :'estimated_average_living_expenses',
    :'students_funding_period_months',
    :'estimated_average_costs_period_months'
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/plaid/models/credit_i20.rb', line 77

def self.openapi_types
  {
    :'document_id' => :'String',
    :'document_metadata' => :'CreditDocumentMetadata',
    :'student' => :'CreditI20Student',
    :'personal_funds' => :'Float',
    :'on_campus_employment' => :'Float',
    :'funds_from_this_school' => :'Float',
    :'students_funding_total' => :'Float',
    :'funds_from_another_source' => :'Float',
    :'estimated_average_costs_total' => :'Float',
    :'estimated_average_living_expenses' => :'Float',
    :'students_funding_period_months' => :'Integer',
    :'estimated_average_costs_period_months' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/plaid/models/credit_i20.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      document_id == o.document_id &&
       == o. &&
      student == o.student &&
      personal_funds == o.personal_funds &&
      on_campus_employment == o.on_campus_employment &&
      funds_from_this_school == o.funds_from_this_school &&
      students_funding_total == o.students_funding_total &&
      funds_from_another_source == o.funds_from_another_source &&
      estimated_average_costs_total == o.estimated_average_costs_total &&
      estimated_average_living_expenses == o.estimated_average_living_expenses &&
      students_funding_period_months == o.students_funding_period_months &&
      estimated_average_costs_period_months == o.estimated_average_costs_period_months
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/plaid/models/credit_i20.rb', line 252

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/plaid/models/credit_i20.rb', line 323

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/plaid/models/credit_i20.rb', line 228

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/plaid/models/credit_i20.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/plaid/models/credit_i20.rb', line 214

def hash
  [document_id, , student, personal_funds, on_campus_employment, funds_from_this_school, students_funding_total, funds_from_another_source, estimated_average_costs_total, estimated_average_living_expenses, students_funding_period_months, estimated_average_costs_period_months].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
# File 'lib/plaid/models/credit_i20.rb', line 176

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
# File 'lib/plaid/models/credit_i20.rb', line 299

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/plaid/models/credit_i20.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



293
294
295
# File 'lib/plaid/models/credit_i20.rb', line 293

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
# File 'lib/plaid/models/credit_i20.rb', line 183

def valid?
  true
end