Class: Plaid::Enrichments

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/enrichments.rb

Overview

A grouping of the Plaid produced transaction enrichment fields.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Enrichments

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/plaid/models/enrichments.rb', line 137

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::Enrichments` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::Enrichments`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'check_number')
    self.check_number = attributes[:'check_number']
  end

  if attributes.key?(:'counterparties')
    if (value = attributes[:'counterparties']).is_a?(Array)
      self.counterparties = value
    end
  end

  if attributes.key?(:'entity_id')
    self.entity_id = attributes[:'entity_id']
  end

  if attributes.key?(:'legacy_category_id')
    self.legacy_category_id = attributes[:'legacy_category_id']
  end

  if attributes.key?(:'legacy_category')
    if (value = attributes[:'legacy_category']).is_a?(Array)
      self.legacy_category = value
    end
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'logo_url')
    self.logo_url = attributes[:'logo_url']
  end

  if attributes.key?(:'merchant_name')
    self.merchant_name = attributes[:'merchant_name']
  end

  if attributes.key?(:'payment_channel')
    self.payment_channel = attributes[:'payment_channel']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'personal_finance_category')
    self.personal_finance_category = attributes[:'personal_finance_category']
  end

  if attributes.key?(:'personal_finance_category_icon_url')
    self.personal_finance_category_icon_url = attributes[:'personal_finance_category_icon_url']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end
end

Instance Attribute Details

#check_numberObject

The check number of the transaction. This field is only populated for check transactions.



20
21
22
# File 'lib/plaid/models/enrichments.rb', line 20

def check_number
  @check_number
end

#counterpartiesObject

The counterparties present in the transaction. Counterparties, such as the merchant or the financial institution, are extracted by Plaid from the raw description.



23
24
25
# File 'lib/plaid/models/enrichments.rb', line 23

def counterparties
  @counterparties
end

#entity_idObject

A unique, stable, Plaid-generated ID that maps to the primary counterparty.



26
27
28
# File 'lib/plaid/models/enrichments.rb', line 26

def entity_id
  @entity_id
end

#legacy_categoryObject

A hierarchical array of the legacy categories to which this transaction belongs. For a full list of legacy categories, see [‘/categories/get`](plaid.com/docs/api/products/transactions/#categoriesget). We recommend using the `personal_finance_category` for transaction categorization to obtain the best results.



32
33
34
# File 'lib/plaid/models/enrichments.rb', line 32

def legacy_category
  @legacy_category
end

#legacy_category_idObject

The ID of the legacy category to which this transaction belongs. For a full list of legacy categories, see [‘/categories/get`](plaid.com/docs/api/products/transactions/#categoriesget). We recommend using the `personal_finance_category` for transaction categorization to obtain the best results.



29
30
31
# File 'lib/plaid/models/enrichments.rb', line 29

def legacy_category_id
  @legacy_category_id
end

#locationObject

Returns the value of attribute location.



34
35
36
# File 'lib/plaid/models/enrichments.rb', line 34

def location
  @location
end

#logo_urlObject

The URL of a logo associated with this transaction, if available. The logo will always be 100×100 pixel PNG file.



37
38
39
# File 'lib/plaid/models/enrichments.rb', line 37

def logo_url
  @logo_url
end

#merchant_nameObject

The name of the primary counterparty, such as the merchant or the financial institution, as extracted by Plaid from the raw description.



40
41
42
# File 'lib/plaid/models/enrichments.rb', line 40

def merchant_name
  @merchant_name
end

#payment_channelObject

Returns the value of attribute payment_channel.



42
43
44
# File 'lib/plaid/models/enrichments.rb', line 42

def payment_channel
  @payment_channel
end

#personal_finance_categoryObject

Returns the value of attribute personal_finance_category.



47
48
49
# File 'lib/plaid/models/enrichments.rb', line 47

def personal_finance_category
  @personal_finance_category
end

#personal_finance_category_icon_urlObject

The URL of an icon associated with the primary personal finance category. The icon will always be 100×100 pixel PNG file.



50
51
52
# File 'lib/plaid/models/enrichments.rb', line 50

def personal_finance_category_icon_url
  @personal_finance_category_icon_url
end

#phone_numberObject

The phone number associated with the counterparty in E. 164 format. If there is a location match (i.e. a street address is returned in the location object), the phone number will be location specific.



45
46
47
# File 'lib/plaid/models/enrichments.rb', line 45

def phone_number
  @phone_number
end

#websiteObject

The website associated with this transaction.



53
54
55
# File 'lib/plaid/models/enrichments.rb', line 53

def website
  @website
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/plaid/models/enrichments.rb', line 97

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/plaid/models/enrichments.rb', line 78

def self.attribute_map
  {
    :'check_number' => :'check_number',
    :'counterparties' => :'counterparties',
    :'entity_id' => :'entity_id',
    :'legacy_category_id' => :'legacy_category_id',
    :'legacy_category' => :'legacy_category',
    :'location' => :'location',
    :'logo_url' => :'logo_url',
    :'merchant_name' => :'merchant_name',
    :'payment_channel' => :'payment_channel',
    :'phone_number' => :'phone_number',
    :'personal_finance_category' => :'personal_finance_category',
    :'personal_finance_category_icon_url' => :'personal_finance_category_icon_url',
    :'website' => :'website'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
# File 'lib/plaid/models/enrichments.rb', line 275

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/plaid/models/enrichments.rb', line 121

def self.openapi_nullable
  Set.new([
    :'check_number',
    :'entity_id',
    :'legacy_category_id',
    :'legacy_category',
    :'logo_url',
    :'merchant_name',
    :'phone_number',
    :'personal_finance_category',
    :'website'
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/plaid/models/enrichments.rb', line 102

def self.openapi_types
  {
    :'check_number' => :'String',
    :'counterparties' => :'Array<Counterparty>',
    :'entity_id' => :'String',
    :'legacy_category_id' => :'String',
    :'legacy_category' => :'Array<String>',
    :'location' => :'Location',
    :'logo_url' => :'String',
    :'merchant_name' => :'String',
    :'payment_channel' => :'PaymentChannel',
    :'phone_number' => :'String',
    :'personal_finance_category' => :'PersonalFinanceCategory',
    :'personal_finance_category_icon_url' => :'String',
    :'website' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/plaid/models/enrichments.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      check_number == o.check_number &&
      counterparties == o.counterparties &&
      entity_id == o.entity_id &&
      legacy_category_id == o.legacy_category_id &&
      legacy_category == o.legacy_category &&
      location == o.location &&
      logo_url == o.logo_url &&
      merchant_name == o.merchant_name &&
      payment_channel == o.payment_channel &&
      phone_number == o.phone_number &&
      personal_finance_category == o.personal_finance_category &&
      personal_finance_category_icon_url == o.personal_finance_category_icon_url &&
      website == o.website
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/plaid/models/enrichments.rb', line 306

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/plaid/models/enrichments.rb', line 377

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/plaid/models/enrichments.rb', line 282

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/plaid/models/enrichments.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/plaid/models/enrichments.rb', line 268

def hash
  [check_number, counterparties, entity_id, legacy_category_id, legacy_category, location, logo_url, merchant_name, payment_channel, phone_number, personal_finance_category, personal_finance_category_icon_url, website].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/plaid/models/enrichments.rb', line 209

def list_invalid_properties
  invalid_properties = Array.new
  if @counterparties.nil?
    invalid_properties.push('invalid value for "counterparties", counterparties cannot be nil.')
  end

  if @location.nil?
    invalid_properties.push('invalid value for "location", location cannot be nil.')
  end

  if @payment_channel.nil?
    invalid_properties.push('invalid value for "payment_channel", payment_channel cannot be nil.')
  end

  if @personal_finance_category_icon_url.nil?
    invalid_properties.push('invalid value for "personal_finance_category_icon_url", personal_finance_category_icon_url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



353
354
355
# File 'lib/plaid/models/enrichments.rb', line 353

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/plaid/models/enrichments.rb', line 359

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



347
348
349
# File 'lib/plaid/models/enrichments.rb', line 347

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
# File 'lib/plaid/models/enrichments.rb', line 232

def valid?
  return false if @counterparties.nil?
  return false if @location.nil?
  return false if @payment_channel.nil?
  return false if @personal_finance_category_icon_url.nil?
  true
end