Class: Plaid::ExpenditureSummary
- Inherits:
-
Object
- Object
- Plaid::ExpenditureSummary
- Defined in:
- lib/plaid/models/expenditure_summary.rb
Overview
Summary statistics for a specific expenditure category, including total amount, monthly average, and percentage of income.
Instance Attribute Summary collapse
-
#amount ⇒ Object
The total value of all the aggregated transactions in this expenditure category.
-
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the amount.
-
#monthly_average ⇒ Object
Returns the value of attribute monthly_average.
-
#percentage_of_income ⇒ Object
The percentage of the total inflows that was spent in this expenses group, within the given time window across all the accounts in the report.
-
#top_categories ⇒ Object
The primary credit categories of the expenses within the given time window, across all the accounts in the report.
-
#transactions_count ⇒ Object
The total number of outflow transactions in this expenses group, within the given time window across all the accounts in the report.
-
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the amount.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpenditureSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ExpenditureSummary
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/plaid/models/expenditure_summary.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::ExpenditureSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::ExpenditureSummary`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'iso_currency_code') self.iso_currency_code = attributes[:'iso_currency_code'] end if attributes.key?(:'unofficial_currency_code') self.unofficial_currency_code = attributes[:'unofficial_currency_code'] end if attributes.key?(:'monthly_average') self.monthly_average = attributes[:'monthly_average'] end if attributes.key?(:'transactions_count') self.transactions_count = attributes[:'transactions_count'] end if attributes.key?(:'percentage_of_income') self.percentage_of_income = attributes[:'percentage_of_income'] end if attributes.key?(:'top_categories') if (value = attributes[:'top_categories']).is_a?(Array) self.top_categories = value end end end |
Instance Attribute Details
#amount ⇒ Object
The total value of all the aggregated transactions in this expenditure category.
20 21 22 |
# File 'lib/plaid/models/expenditure_summary.rb', line 20 def amount @amount end |
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the amount. Always ‘null` if `unofficial_currency_code` is non-`null`.
23 24 25 |
# File 'lib/plaid/models/expenditure_summary.rb', line 23 def iso_currency_code @iso_currency_code end |
#monthly_average ⇒ Object
Returns the value of attribute monthly_average.
28 29 30 |
# File 'lib/plaid/models/expenditure_summary.rb', line 28 def monthly_average @monthly_average end |
#percentage_of_income ⇒ Object
The percentage of the total inflows that was spent in this expenses group, within the given time window across all the accounts in the report. For example, a value of 100 represents that 100% of the inflows were spent on transactions that fall into this expenditure group. If there’s no available income for the giving time period, this field value will be ‘-1`.
34 35 36 |
# File 'lib/plaid/models/expenditure_summary.rb', line 34 def percentage_of_income @percentage_of_income end |
#top_categories ⇒ Object
The primary credit categories of the expenses within the given time window, across all the accounts in the report. The categories are sorted in descending order by the total value spent. See the [category taxonomy](plaid.com/documents/credit-category-taxonomy.csv) for a full listing of category IDs.
37 38 39 |
# File 'lib/plaid/models/expenditure_summary.rb', line 37 def top_categories @top_categories end |
#transactions_count ⇒ Object
The total number of outflow transactions in this expenses group, within the given time window across all the accounts in the report.
31 32 33 |
# File 'lib/plaid/models/expenditure_summary.rb', line 31 def transactions_count @transactions_count end |
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the amount. Always ‘null` if `iso_currency_code` is non-`null`. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.
26 27 28 |
# File 'lib/plaid/models/expenditure_summary.rb', line 26 def unofficial_currency_code @unofficial_currency_code end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/plaid/models/expenditure_summary.rb', line 53 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/plaid/models/expenditure_summary.rb', line 40 def self.attribute_map { :'amount' => :'amount', :'iso_currency_code' => :'iso_currency_code', :'unofficial_currency_code' => :'unofficial_currency_code', :'monthly_average' => :'monthly_average', :'transactions_count' => :'transactions_count', :'percentage_of_income' => :'percentage_of_income', :'top_categories' => :'top_categories' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
170 171 172 |
# File 'lib/plaid/models/expenditure_summary.rb', line 170 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 75 76 77 78 79 80 |
# File 'lib/plaid/models/expenditure_summary.rb', line 71 def self.openapi_nullable Set.new([ :'amount', :'iso_currency_code', :'unofficial_currency_code', :'monthly_average', :'transactions_count', :'percentage_of_income', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/plaid/models/expenditure_summary.rb', line 58 def self.openapi_types { :'amount' => :'Float', :'iso_currency_code' => :'String', :'unofficial_currency_code' => :'String', :'monthly_average' => :'MonthlyAverage', :'transactions_count' => :'Integer', :'percentage_of_income' => :'Float', :'top_categories' => :'Array<CategoryExpenses>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/plaid/models/expenditure_summary.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && amount == o.amount && iso_currency_code == o.iso_currency_code && unofficial_currency_code == o.unofficial_currency_code && monthly_average == o.monthly_average && transactions_count == o.transactions_count && percentage_of_income == o.percentage_of_income && top_categories == o.top_categories end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/plaid/models/expenditure_summary.rb', line 201 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/plaid/models/expenditure_summary.rb', line 272 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/plaid/models/expenditure_summary.rb', line 177 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
157 158 159 |
# File 'lib/plaid/models/expenditure_summary.rb', line 157 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
163 164 165 |
# File 'lib/plaid/models/expenditure_summary.rb', line 163 def hash [amount, iso_currency_code, unofficial_currency_code, monthly_average, transactions_count, percentage_of_income, top_categories].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 |
# File 'lib/plaid/models/expenditure_summary.rb', line 130 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
248 249 250 |
# File 'lib/plaid/models/expenditure_summary.rb', line 248 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/plaid/models/expenditure_summary.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
242 243 244 |
# File 'lib/plaid/models/expenditure_summary.rb', line 242 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 |
# File 'lib/plaid/models/expenditure_summary.rb', line 137 def valid? true end |