Class: Plaid::FDXDataCluster

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/fdx_data_cluster.rb

Constant Summary collapse

ACCOUNT_BASIC =
"ACCOUNT_BASIC".freeze
ACCOUNT_DETAILED =
"ACCOUNT_DETAILED".freeze
ACCOUNT_PAYMENTS =
"ACCOUNT_PAYMENTS".freeze
BILLS =
"BILLS".freeze
CUSTOMER_CONTACT =
"CUSTOMER_CONTACT".freeze
CUSTOMER_PERSONAL =
"CUSTOMER_PERSONAL".freeze
IMAGES =
"IMAGES".freeze
INVESTMENTS =
"INVESTMENTS".freeze
NOTIFICATIONS =
"NOTIFICATIONS".freeze
PAYMENT_SUPPORT =
"PAYMENT_SUPPORT".freeze
REWARDS =
"REWARDS".freeze
STATEMENTS =
"STATEMENTS".freeze
TAX =
"TAX".freeze
TRANSACTIONS =
"TRANSACTIONS".freeze
BALANCES =
"BALANCES".freeze
SCHEDULED_PAYMENTS =
"SCHEDULED_PAYMENTS".freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



38
39
40
# File 'lib/plaid/models/fdx_data_cluster.rb', line 38

def self.build_from_hash(value)
  new.build_from_hash(value)
end

Instance Method Details

#build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



45
46
47
48
49
50
# File 'lib/plaid/models/fdx_data_cluster.rb', line 45

def build_from_hash(value)
  # We do not validate that the value is one of the enums set in the OpenAPI
  # file because we want to be able to add to our list of enums without
  # breaking this client library.
  value
end