Class: Plaid::FDXNotificationType
- Inherits:
-
Object
- Object
- Plaid::FDXNotificationType
- Defined in:
- lib/plaid/models/fdx_notification_type.rb
Constant Summary collapse
- ACCOUNT_TAKEOVER =
"ACCOUNT_TAKEOVER".freeze
- ADDRESS_CHANGED =
"ADDRESS_CHANGED".freeze
- BALANCE =
"BALANCE".freeze
- CONSENT_EXPIRED =
"CONSENT_EXPIRED".freeze
- CONSENT_GRANTED =
"CONSENT_GRANTED".freeze
- CONSENT_REVOKED =
"CONSENT_REVOKED".freeze
- CONSENT_UPDATED =
"CONSENT_UPDATED".freeze
- CUSTOM =
"CUSTOM".freeze
- MFA_TARGET_CHANGED =
"MFA_TARGET_CHANGED".freeze
- PHONE_CHANGED =
"PHONE_CHANGED".freeze
- PLANNED_OUTAGE =
"PLANNED_OUTAGE".freeze
- RISK =
"RISK".freeze
- SERVICE =
"SERVICE".freeze
- SUSPECTED_INCIDENT =
"SUSPECTED_INCIDENT".freeze
- TAN_ACTIVATED =
"TAN_ACTIVATED".freeze
- TAN_CREATED =
"TAN_CREATED".freeze
- TAN_REVOKED =
"TAN_REVOKED".freeze
- TAN_SUSPENDED =
"TAN_SUSPENDED".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
40 41 42 |
# File 'lib/plaid/models/fdx_notification_type.rb', line 40 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
47 48 49 50 51 52 |
# File 'lib/plaid/models/fdx_notification_type.rb', line 47 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |