Class: Plaid::IdentityVerificationCreateRequestUser
- Inherits:
-
Object
- Object
- Plaid::IdentityVerificationCreateRequestUser
- Defined in:
- lib/plaid/models/identity_verification_create_request_user.rb
Overview
User information collected outside of Link, most likely via your own onboarding process. Each of the following identity fields are optional: email_address phone_number date_of_birth name address id_number Specifically, these fields are optional in that they can either be fully provided (satisfying every required field in their subschema) or omitted from the request entirely by not providing the key or value. Providing these fields via the API will result in Link skipping the data collection process for the associated user. All verification steps enabled in the associated Identity Verification Template will still be run. Verification steps will either be run immediately, or once the user completes the accept_tos step, depending on the value provided to the gave_consent field. If you are not using the shareable URL feature, you can optionally provide these fields via /link/token/create instead; both /identity_verification/create and /link/token/create are valid ways to provide this information. Note that if you provide a non-null user data object via /identity_verification/create, any user data fields entered via /link/token/create for the same client_user_id will be ignored when prefilling Link. The ip_address field is optional. Provide the end user's IP address to enable IP-based risk checks for backend-only integrations that do not use the Link SDK; when the Link SDK is used, the IP address is collected automatically. Unlike the identity fields above, ip_address cannot be provided via /link/token/create.
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#client_user_id ⇒ Object
Specifying
user.client_user_idis deprecated. -
#date_of_birth ⇒ Object
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
-
#email_address ⇒ Object
A valid email address.
-
#id_number ⇒ Object
Returns the value of attribute id_number.
-
#ip_address ⇒ Object
An IPv4 or IPv6 address.
-
#name ⇒ Object
Returns the value of attribute name.
-
#phone_number ⇒ Object
A valid phone number in E.164 format.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityVerificationCreateRequestUser
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityVerificationCreateRequestUser
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::IdentityVerificationCreateRequestUser` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::IdentityVerificationCreateRequestUser`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'email_address') self.email_address = attributes[:'email_address'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'id_number') self.id_number = attributes[:'id_number'] end if attributes.key?(:'client_user_id') self.client_user_id = attributes[:'client_user_id'] end if attributes.key?(:'ip_address') self.ip_address = attributes[:'ip_address'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
30 31 32 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 30 def address @address end |
#client_user_id ⇒ Object
Specifying user.client_user_id is deprecated. Please provide client_user_id at the root level instead.
35 36 37 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 35 def client_user_id @client_user_id end |
#date_of_birth ⇒ Object
A date in the format YYYY-MM-DD (RFC 3339 Section 5.6).
26 27 28 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 26 def date_of_birth @date_of_birth end |
#email_address ⇒ Object
A valid email address. Must not have leading or trailing spaces and address must be RFC compliant. For more information, see RFC 3696.
20 21 22 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 20 def email_address @email_address end |
#id_number ⇒ Object
Returns the value of attribute id_number.
32 33 34 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 32 def id_number @id_number end |
#ip_address ⇒ Object
An IPv4 or IPv6 address.
38 39 40 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 38 def ip_address @ip_address end |
#name ⇒ Object
Returns the value of attribute name.
28 29 30 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 28 def name @name end |
#phone_number ⇒ Object
A valid phone number in E.164 format.
23 24 25 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 23 def phone_number @phone_number end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 55 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 41 def self.attribute_map { :'email_address' => :'email_address', :'phone_number' => :'phone_number', :'date_of_birth' => :'date_of_birth', :'name' => :'name', :'address' => :'address', :'id_number' => :'id_number', :'client_user_id' => :'client_user_id', :'ip_address' => :'ip_address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
176 177 178 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 176 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 78 79 80 81 82 83 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 74 def self.openapi_nullable Set.new([ :'phone_number', :'name', :'address', :'id_number', :'client_user_id', :'ip_address' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 60 def self.openapi_types { :'email_address' => :'String', :'phone_number' => :'String', :'date_of_birth' => :'Date', :'name' => :'IdentityVerificationRequestUserName', :'address' => :'UserAddress', :'id_number' => :'UserIDNumber', :'client_user_id' => :'String', :'ip_address' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && email_address == o.email_address && phone_number == o.phone_number && date_of_birth == o.date_of_birth && name == o.name && address == o.address && id_number == o.id_number && client_user_id == o.client_user_id && ip_address == o.ip_address end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 207 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 278 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 183 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
163 164 165 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 163 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
169 170 171 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 169 def hash [email_address, phone_number, date_of_birth, name, address, id_number, client_user_id, ip_address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 135 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
254 255 256 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 254 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
248 249 250 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 248 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 |
# File 'lib/plaid/models/identity_verification_create_request_user.rb', line 142 def valid? true end |