Class: Plaid::InvestmentAccountBalance

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/investment_account_balance.rb

Overview

A set of fields describing the balance for an account, including margin loan information for investment accounts.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InvestmentAccountBalance

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/plaid/models/investment_account_balance.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::InvestmentAccountBalance` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::InvestmentAccountBalance`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'available')
    self.available = attributes[:'available']
  end

  if attributes.key?(:'current')
    self.current = attributes[:'current']
  end

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  end

  if attributes.key?(:'iso_currency_code')
    self.iso_currency_code = attributes[:'iso_currency_code']
  end

  if attributes.key?(:'unofficial_currency_code')
    self.unofficial_currency_code = attributes[:'unofficial_currency_code']
  end

  if attributes.key?(:'last_updated_datetime')
    self.last_updated_datetime = attributes[:'last_updated_datetime']
  end

  if attributes.key?(:'margin_loan_amount')
    self.margin_loan_amount = attributes[:'margin_loan_amount']
  end
end

Instance Attribute Details

#availableObject

The amount of funds available to be withdrawn from the account, as determined by the financial institution. For ‘credit`-type accounts, the `available` balance typically equals the `limit` less the `current` balance, less any pending outflows plus any pending inflows. For `depository`-type accounts, the `available` balance typically equals the `current` balance less any pending outflows plus any pending inflows. For `depository`-type accounts, the `available` balance does not include the overdraft limit. For `investment`-type accounts (or `brokerage`-type accounts for API versions 2018-05-22 and earlier), the `available` balance is the total cash available to withdraw as presented by the institution. Note that not all institutions calculate the `available` balance. In the event that `available` balance is unavailable, Plaid will return an `available` balance value of `null`. Available balance may be cached and is not guaranteed to be up-to-date in realtime unless the value was returned by `/accounts/balance/get`, or by `/signal/evaluate` with a Balance-only ruleset. If `current` is `null` this field is guaranteed not to be `null`.



20
21
22
# File 'lib/plaid/models/investment_account_balance.rb', line 20

def available
  @available
end

#currentObject

The total amount of funds in or owed by the account. For ‘credit`-type accounts, a positive balance indicates the amount owed; a negative amount indicates the lender owing the account holder. For `loan`-type accounts, the current balance is the principal remaining on the loan, except in the case of student loan accounts at Sallie Mae (`ins_116944`). For Sallie Mae student loans, the account’s balance includes both principal and any outstanding interest. Similar to ‘credit`-type accounts, a positive balance is typically expected, while a negative amount indicates the lender owing the account holder. For `investment`-type accounts (or `brokerage`-type accounts for API versions 2018-05-22 and earlier), the current balance is the total value of assets as presented by the institution. Note that balance information may be cached unless the value was returned by `/accounts/balance/get` or by `/signal/evaluate` with a Balance-only ruleset; if the Item is enabled for Transactions, the balance will be at least as recent as the most recent Transaction update. If you require realtime balance information, use the `available` balance as provided by `/accounts/balance/get` or `/signal/evaluate` called with a Balance-only `ruleset_key`. When returned by `/accounts/balance/get`, this field may be `null`. When this happens, `available` is guaranteed not to be `null`.



23
24
25
# File 'lib/plaid/models/investment_account_balance.rb', line 23

def current
  @current
end

#iso_currency_codeObject

The ISO-4217 currency code of the balance. Always null if ‘unofficial_currency_code` is non-null.



29
30
31
# File 'lib/plaid/models/investment_account_balance.rb', line 29

def iso_currency_code
  @iso_currency_code
end

#last_updated_datetimeObject

Timestamp in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format (‘YYYY-MM-DDTHH:mm:ssZ`) indicating the last time the balance was updated. This field is returned only when the institution is `ins_128026` (Capital One).



35
36
37
# File 'lib/plaid/models/investment_account_balance.rb', line 35

def last_updated_datetime
  @last_updated_datetime
end

#limitObject

For ‘credit`-type accounts, this represents the credit limit. For `depository`-type accounts, this represents the pre-arranged overdraft limit, which is common for current (checking) accounts in Europe. In North America, this field is typically only available for `credit`-type accounts.



26
27
28
# File 'lib/plaid/models/investment_account_balance.rb', line 26

def limit
  @limit
end

#margin_loan_amountObject

The total amount of borrowed funds in the account, as determined by the financial institution. For investment-type accounts, the margin balance is the total value of borrowed assets in the account, as presented by the institution. This is commonly referred to as margin or a loan.



38
39
40
# File 'lib/plaid/models/investment_account_balance.rb', line 38

def margin_loan_amount
  @margin_loan_amount
end

#unofficial_currency_codeObject

The unofficial currency code associated with the balance. Always null if ‘iso_currency_code` is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.



32
33
34
# File 'lib/plaid/models/investment_account_balance.rb', line 32

def unofficial_currency_code
  @unofficial_currency_code
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/plaid/models/investment_account_balance.rb', line 54

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/plaid/models/investment_account_balance.rb', line 41

def self.attribute_map
  {
    :'available' => :'available',
    :'current' => :'current',
    :'limit' => :'limit',
    :'iso_currency_code' => :'iso_currency_code',
    :'unofficial_currency_code' => :'unofficial_currency_code',
    :'last_updated_datetime' => :'last_updated_datetime',
    :'margin_loan_amount' => :'margin_loan_amount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
# File 'lib/plaid/models/investment_account_balance.rb', line 178

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



85
86
87
88
89
90
# File 'lib/plaid/models/investment_account_balance.rb', line 85

def self.openapi_all_of
  [
  :'AccountBalance',
  :'InvestmentAccountBalanceAllOf'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
80
81
82
# File 'lib/plaid/models/investment_account_balance.rb', line 72

def self.openapi_nullable
  Set.new([
    :'available',
    :'current',
    :'limit',
    :'iso_currency_code',
    :'unofficial_currency_code',
    :'last_updated_datetime',
    :'margin_loan_amount'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/plaid/models/investment_account_balance.rb', line 59

def self.openapi_types
  {
    :'available' => :'Float',
    :'current' => :'Float',
    :'limit' => :'Float',
    :'iso_currency_code' => :'String',
    :'unofficial_currency_code' => :'String',
    :'last_updated_datetime' => :'Time',
    :'margin_loan_amount' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/plaid/models/investment_account_balance.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      available == o.available &&
      current == o.current &&
      limit == o.limit &&
      iso_currency_code == o.iso_currency_code &&
      unofficial_currency_code == o.unofficial_currency_code &&
      last_updated_datetime == o.last_updated_datetime &&
      margin_loan_amount == o.margin_loan_amount
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/plaid/models/investment_account_balance.rb', line 209

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/plaid/models/investment_account_balance.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/plaid/models/investment_account_balance.rb', line 185

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/plaid/models/investment_account_balance.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/plaid/models/investment_account_balance.rb', line 171

def hash
  [available, current, limit, iso_currency_code, unofficial_currency_code, last_updated_datetime, margin_loan_amount].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
# File 'lib/plaid/models/investment_account_balance.rb', line 138

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
# File 'lib/plaid/models/investment_account_balance.rb', line 256

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/plaid/models/investment_account_balance.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



250
251
252
# File 'lib/plaid/models/investment_account_balance.rb', line 250

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
# File 'lib/plaid/models/investment_account_balance.rb', line 145

def valid?
  true
end