Class: Plaid::ItemHandleFraudReportRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/item_handle_fraud_report_request.rb

Overview

Request object for ‘/item/handle_fraud_report`. Must provide either `user_id` or at least one of the following identifiers in `incident_event`: `link_session_id`, `idv_session_id`, `protect_event_id`, or `signal_client_transaction_id`.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ItemHandleFraudReportRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::ItemHandleFraudReportRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::ItemHandleFraudReportRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  end

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'incident_event')
    self.incident_event = attributes[:'incident_event']
  end

  if attributes.key?(:'report_confidence')
    self.report_confidence = attributes[:'report_confidence']
  end

  if attributes.key?(:'report_type')
    self.report_type = attributes[:'report_type']
  end

  if attributes.key?(:'report_source')
    self.report_source = attributes[:'report_source']
  end

  if attributes.key?(:'bank_account')
    self. = attributes[:'bank_account']
  end

  if attributes.key?(:'ach_return_code')
    self.ach_return_code = attributes[:'ach_return_code']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end
end

Instance Attribute Details

#access_tokenObject

The access token associated with the Item data is being requested for.



26
27
28
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 26

def access_token
  @access_token
end

#ach_return_codeObject

Must be a valid ACH return code (e.g. ‘R01`), required if `report_type` is `ACH_RETURN`.



42
43
44
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 42

def ach_return_code
  @ach_return_code
end

#bank_accountObject

Returns the value of attribute bank_account.



39
40
41
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 39

def 
  @bank_account
end

#client_idObject

Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.



20
21
22
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 20

def client_id
  @client_id
end

#incident_eventObject

Returns the value of attribute incident_event.



31
32
33
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 31

def incident_event
  @incident_event
end

#notesObject

Additional context or details about the report, required if ‘report_type` is `OTHER`.



45
46
47
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 45

def notes
  @notes
end

#report_confidenceObject

Returns the value of attribute report_confidence.



33
34
35
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 33

def report_confidence
  @report_confidence
end

#report_sourceObject

Returns the value of attribute report_source.



37
38
39
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 37

def report_source
  @report_source
end

#report_typeObject

Returns the value of attribute report_type.



35
36
37
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 35

def report_type
  @report_type
end

#secretObject

Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.



23
24
25
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 23

def secret
  @secret
end

#user_idObject

The Plaid User ID associated with the report.



29
30
31
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 29

def user_id
  @user_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 87

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 70

def self.attribute_map
  {
    :'client_id' => :'client_id',
    :'secret' => :'secret',
    :'access_token' => :'access_token',
    :'user_id' => :'user_id',
    :'incident_event' => :'incident_event',
    :'report_confidence' => :'report_confidence',
    :'report_type' => :'report_type',
    :'report_source' => :'report_source',
    :'bank_account' => :'bank_account',
    :'ach_return_code' => :'ach_return_code',
    :'notes' => :'notes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 262

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
113
114
115
116
117
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 109

def self.openapi_nullable
  Set.new([
    :'user_id',
    :'incident_event',
    :'bank_account',
    :'ach_return_code',
    :'notes'
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 92

def self.openapi_types
  {
    :'client_id' => :'String',
    :'secret' => :'String',
    :'access_token' => :'String',
    :'user_id' => :'String',
    :'incident_event' => :'ProtectIncidentEvent',
    :'report_confidence' => :'ProtectReportConfidence',
    :'report_type' => :'ProtectReportType',
    :'report_source' => :'ProtectReportSource',
    :'bank_account' => :'ProtectBankAccount',
    :'ach_return_code' => :'String',
    :'notes' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      secret == o.secret &&
      access_token == o.access_token &&
      user_id == o.user_id &&
      incident_event == o.incident_event &&
      report_confidence == o.report_confidence &&
      report_type == o.report_type &&
      report_source == o.report_source &&
       == o. &&
      ach_return_code == o.ach_return_code &&
      notes == o.notes
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 293

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 364

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 269

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 255

def hash
  [client_id, secret, access_token, user_id, incident_event, report_confidence, report_type, report_source, , ach_return_code, notes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 181

def list_invalid_properties
  invalid_properties = Array.new
  if @access_token.nil?
    invalid_properties.push('invalid value for "access_token", access_token cannot be nil.')
  end

  if @report_confidence.nil?
    invalid_properties.push('invalid value for "report_confidence", report_confidence cannot be nil.')
  end

  if @report_type.nil?
    invalid_properties.push('invalid value for "report_type", report_type cannot be nil.')
  end

  if @report_source.nil?
    invalid_properties.push('invalid value for "report_source", report_source cannot be nil.')
  end

  if !@notes.nil? && @notes.to_s.length > 1024
    invalid_properties.push('invalid value for "notes", the character length must be smaller than or equal to 1024.')
  end


  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



340
341
342
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 340

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 346

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



334
335
336
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 334

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
# File 'lib/plaid/models/item_handle_fraud_report_request.rb', line 209

def valid?
  return false if @access_token.nil?
  return false if @report_confidence.nil?
  return false if @report_type.nil?
  return false if @report_source.nil?
  return false if !@notes.nil? && @notes.to_s.length > 1024
  true
end