Class: Plaid::LineOfCreditLiability
- Inherits:
-
Object
- Object
- Plaid::LineOfCreditLiability
- Defined in:
- lib/plaid/models/line_of_credit_liability.rb
Overview
Contains details about a line of credit account.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that this liability belongs to.
-
#aprs ⇒ Object
The various interest rates that apply to the account.
-
#available_credit ⇒ Object
The amount of credit currently available on the account.
-
#credit_limit ⇒ Object
The maximum amount of credit available on the account.
-
#draw_period_end_date ⇒ Object
The date on which the draw period ends, in ISO 8601 format (YYYY-MM-DD).
-
#finance_charges ⇒ Object
The finance charges assessed on the account.
-
#interest_rate ⇒ Object
Returns the value of attribute interest_rate.
-
#last_payment_amount ⇒ Object
The amount of the most recent payment.
-
#last_payment_date ⇒ Object
The date of the most recent payment, in ISO 8601 format (YYYY-MM-DD).
-
#last_statement_balance ⇒ Object
The total amount owed as of the last statement issued.
-
#last_statement_issue_date ⇒ Object
The date of the last statement, in ISO 8601 format (YYYY-MM-DD).
-
#minimum_payment_amount ⇒ Object
The minimum payment due for the next billing cycle.
-
#next_payment_amount ⇒ Object
The amount of the next scheduled payment.
-
#next_payment_due_date ⇒ Object
The due date of the next payment, in ISO 8601 format (YYYY-MM-DD).
-
#past_due_amount ⇒ Object
The amount of the payment that is currently past due.
-
#principal_balance ⇒ Object
The outstanding principal balance on the account.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LineOfCreditLiability
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LineOfCreditLiability
Initializes the object
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 137 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::LineOfCreditLiability` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::LineOfCreditLiability`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'interest_rate') self.interest_rate = attributes[:'interest_rate'] end if attributes.key?(:'credit_limit') self.credit_limit = attributes[:'credit_limit'] end if attributes.key?(:'available_credit') self.available_credit = attributes[:'available_credit'] end if attributes.key?(:'principal_balance') self.principal_balance = attributes[:'principal_balance'] end if attributes.key?(:'minimum_payment_amount') self.minimum_payment_amount = attributes[:'minimum_payment_amount'] end if attributes.key?(:'next_payment_amount') self.next_payment_amount = attributes[:'next_payment_amount'] end if attributes.key?(:'next_payment_due_date') self.next_payment_due_date = attributes[:'next_payment_due_date'] end if attributes.key?(:'last_payment_amount') self.last_payment_amount = attributes[:'last_payment_amount'] end if attributes.key?(:'last_payment_date') self.last_payment_date = attributes[:'last_payment_date'] end if attributes.key?(:'last_statement_balance') self.last_statement_balance = attributes[:'last_statement_balance'] end if attributes.key?(:'last_statement_issue_date') self.last_statement_issue_date = attributes[:'last_statement_issue_date'] end if attributes.key?(:'past_due_amount') self.past_due_amount = attributes[:'past_due_amount'] end if attributes.key?(:'finance_charges') self.finance_charges = attributes[:'finance_charges'] end if attributes.key?(:'draw_period_end_date') self.draw_period_end_date = attributes[:'draw_period_end_date'] end if attributes.key?(:'aprs') if (value = attributes[:'aprs']).is_a?(Array) self.aprs = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that this liability belongs to.
20 21 22 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 20 def account_id @account_id end |
#aprs ⇒ Object
The various interest rates that apply to the account.
64 65 66 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 64 def aprs @aprs end |
#available_credit ⇒ Object
The amount of credit currently available on the account.
28 29 30 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 28 def available_credit @available_credit end |
#credit_limit ⇒ Object
The maximum amount of credit available on the account.
25 26 27 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 25 def credit_limit @credit_limit end |
#draw_period_end_date ⇒ Object
The date on which the draw period ends, in ISO 8601 format (YYYY-MM-DD).
61 62 63 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 61 def draw_period_end_date @draw_period_end_date end |
#finance_charges ⇒ Object
The finance charges assessed on the account.
58 59 60 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 58 def finance_charges @finance_charges end |
#interest_rate ⇒ Object
Returns the value of attribute interest_rate.
22 23 24 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 22 def interest_rate @interest_rate end |
#last_payment_amount ⇒ Object
The amount of the most recent payment.
43 44 45 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 43 def last_payment_amount @last_payment_amount end |
#last_payment_date ⇒ Object
The date of the most recent payment, in ISO 8601 format (YYYY-MM-DD).
46 47 48 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 46 def last_payment_date @last_payment_date end |
#last_statement_balance ⇒ Object
The total amount owed as of the last statement issued.
49 50 51 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 49 def last_statement_balance @last_statement_balance end |
#last_statement_issue_date ⇒ Object
The date of the last statement, in ISO 8601 format (YYYY-MM-DD).
52 53 54 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 52 def last_statement_issue_date @last_statement_issue_date end |
#minimum_payment_amount ⇒ Object
The minimum payment due for the next billing cycle.
34 35 36 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 34 def minimum_payment_amount @minimum_payment_amount end |
#next_payment_amount ⇒ Object
The amount of the next scheduled payment.
37 38 39 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 37 def next_payment_amount @next_payment_amount end |
#next_payment_due_date ⇒ Object
The due date of the next payment, in ISO 8601 format (YYYY-MM-DD).
40 41 42 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 40 def next_payment_due_date @next_payment_due_date end |
#past_due_amount ⇒ Object
The amount of the payment that is currently past due.
55 56 57 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 55 def past_due_amount @past_due_amount end |
#principal_balance ⇒ Object
The outstanding principal balance on the account.
31 32 33 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 31 def principal_balance @principal_balance end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 67 def self.attribute_map { :'account_id' => :'account_id', :'interest_rate' => :'interest_rate', :'credit_limit' => :'credit_limit', :'available_credit' => :'available_credit', :'principal_balance' => :'principal_balance', :'minimum_payment_amount' => :'minimum_payment_amount', :'next_payment_amount' => :'next_payment_amount', :'next_payment_due_date' => :'next_payment_due_date', :'last_payment_amount' => :'last_payment_amount', :'last_payment_date' => :'last_payment_date', :'last_statement_balance' => :'last_statement_balance', :'last_statement_issue_date' => :'last_statement_issue_date', :'past_due_amount' => :'past_due_amount', :'finance_charges' => :'finance_charges', :'draw_period_end_date' => :'draw_period_end_date', :'aprs' => :'aprs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 278 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 116 def self.openapi_nullable Set.new([ :'interest_rate', :'credit_limit', :'available_credit', :'principal_balance', :'minimum_payment_amount', :'next_payment_amount', :'next_payment_due_date', :'last_payment_amount', :'last_payment_date', :'last_statement_balance', :'last_statement_issue_date', :'past_due_amount', :'finance_charges', :'draw_period_end_date', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 94 def self.openapi_types { :'account_id' => :'String', :'interest_rate' => :'LoanInterestRate', :'credit_limit' => :'Float', :'available_credit' => :'Float', :'principal_balance' => :'Float', :'minimum_payment_amount' => :'Float', :'next_payment_amount' => :'Float', :'next_payment_due_date' => :'Date', :'last_payment_amount' => :'Float', :'last_payment_date' => :'Date', :'last_statement_balance' => :'Float', :'last_statement_issue_date' => :'Date', :'past_due_amount' => :'Float', :'finance_charges' => :'Float', :'draw_period_end_date' => :'Date', :'aprs' => :'Array<APR>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && interest_rate == o.interest_rate && credit_limit == o.credit_limit && available_credit == o.available_credit && principal_balance == o.principal_balance && minimum_payment_amount == o.minimum_payment_amount && next_payment_amount == o.next_payment_amount && next_payment_due_date == o.next_payment_due_date && last_payment_amount == o.last_payment_amount && last_payment_date == o.last_payment_date && last_statement_balance == o.last_statement_balance && last_statement_issue_date == o.last_statement_issue_date && past_due_amount == o.past_due_amount && finance_charges == o.finance_charges && draw_period_end_date == o.draw_period_end_date && aprs == o.aprs end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 309 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 380 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 285 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 271 def hash [account_id, interest_rate, credit_limit, available_credit, principal_balance, minimum_payment_amount, next_payment_amount, next_payment_due_date, last_payment_amount, last_payment_date, last_statement_balance, last_statement_issue_date, past_due_amount, finance_charges, draw_period_end_date, aprs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 219 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @aprs.nil? invalid_properties.push('invalid value for "aprs", aprs cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
356 357 358 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 356 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 362 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
350 351 352 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 350 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
234 235 236 237 238 |
# File 'lib/plaid/models/line_of_credit_liability.rb', line 234 def valid? return false if @account_id.nil? return false if @aprs.nil? true end |