Class: Plaid::LinkEventsWebhook
- Inherits:
-
Object
- Object
- Plaid::LinkEventsWebhook
- Defined in:
- lib/plaid/models/link_events_webhook.rb
Overview
This webhook contains a summary of the events from a Link session and will be fired after the user finishes going through Link. If the user abandons the Link flow (i.e., closes the hosted link webpage or leaves Link open for too long without taking any action), the webhook will be fired 5-15 minutes after the last user interaction. A single Link session may occasionally generate multiple EVENTS webhooks. If this occurs, the new webhook will contain all previous events for the session, as well as new events that occurred since the previous EVENTS webhook was sent. If this occurs, events can be grouped using the link_session_id field and, if necessary, de-duplicated using the event_id field. By default, the EVENTS webhook is sent only for sessions where the end user goes through a Hosted Link flow (including Link Recovery flows). If you would like to receive this webhook for sessions not using Hosted Link, contact your account manager or support. This enablement will also cause you to receive the SESSION_FINISHED webhook for non-Hosted-Link sessions and to be able to use /link/token/get to receive events data for non-Hosted Link sessions.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#environment ⇒ Object
Returns the value of attribute environment.
-
#events ⇒ Object
The Link events emitted during the Link session.
-
#link_session_id ⇒ Object
An identifier for the Link session these events occurred in.
-
#link_token ⇒ Object
The Link token used to create the Link session these events are from.
-
#webhook_code ⇒ Object
EVENTS. -
#webhook_type ⇒ Object
LINK.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkEventsWebhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LinkEventsWebhook
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/plaid/models/link_events_webhook.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::LinkEventsWebhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::LinkEventsWebhook`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'webhook_type') self.webhook_type = attributes[:'webhook_type'] end if attributes.key?(:'webhook_code') self.webhook_code = attributes[:'webhook_code'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'link_session_id') self.link_session_id = attributes[:'link_session_id'] end if attributes.key?(:'link_token') self.link_token = attributes[:'link_token'] end if attributes.key?(:'environment') self.environment = attributes[:'environment'] end end |
Instance Attribute Details
#environment ⇒ Object
Returns the value of attribute environment.
34 35 36 |
# File 'lib/plaid/models/link_events_webhook.rb', line 34 def environment @environment end |
#events ⇒ Object
The Link events emitted during the Link session
26 27 28 |
# File 'lib/plaid/models/link_events_webhook.rb', line 26 def events @events end |
#link_session_id ⇒ Object
An identifier for the Link session these events occurred in
29 30 31 |
# File 'lib/plaid/models/link_events_webhook.rb', line 29 def link_session_id @link_session_id end |
#link_token ⇒ Object
The Link token used to create the Link session these events are from
32 33 34 |
# File 'lib/plaid/models/link_events_webhook.rb', line 32 def link_token @link_token end |
#webhook_code ⇒ Object
EVENTS
23 24 25 |
# File 'lib/plaid/models/link_events_webhook.rb', line 23 def webhook_code @webhook_code end |
#webhook_type ⇒ Object
LINK
20 21 22 |
# File 'lib/plaid/models/link_events_webhook.rb', line 20 def webhook_type @webhook_type end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/plaid/models/link_events_webhook.rb', line 71 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/plaid/models/link_events_webhook.rb', line 59 def self.attribute_map { :'webhook_type' => :'webhook_type', :'webhook_code' => :'webhook_code', :'events' => :'events', :'link_session_id' => :'link_session_id', :'link_token' => :'link_token', :'environment' => :'environment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 |
# File 'lib/plaid/models/link_events_webhook.rb', line 206 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/plaid/models/link_events_webhook.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/plaid/models/link_events_webhook.rb', line 76 def self.openapi_types { :'webhook_type' => :'String', :'webhook_code' => :'String', :'events' => :'Array<LinkEvent>', :'link_session_id' => :'String', :'link_token' => :'String', :'environment' => :'WebhookEnvironmentValues' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/plaid/models/link_events_webhook.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && webhook_type == o.webhook_type && webhook_code == o.webhook_code && events == o.events && link_session_id == o.link_session_id && link_token == o.link_token && environment == o.environment end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/plaid/models/link_events_webhook.rb', line 237 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/plaid/models/link_events_webhook.rb', line 308 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/plaid/models/link_events_webhook.rb', line 213 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/plaid/models/link_events_webhook.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/plaid/models/link_events_webhook.rb', line 199 def hash [webhook_type, webhook_code, events, link_session_id, link_token, environment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/plaid/models/link_events_webhook.rb', line 137 def list_invalid_properties invalid_properties = Array.new if @webhook_type.nil? invalid_properties.push('invalid value for "webhook_type", webhook_type cannot be nil.') end if @webhook_code.nil? invalid_properties.push('invalid value for "webhook_code", webhook_code cannot be nil.') end if @events.nil? invalid_properties.push('invalid value for "events", events cannot be nil.') end if @link_session_id.nil? invalid_properties.push('invalid value for "link_session_id", link_session_id cannot be nil.') end if @link_token.nil? invalid_properties.push('invalid value for "link_token", link_token cannot be nil.') end if @environment.nil? invalid_properties.push('invalid value for "environment", environment cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
284 285 286 |
# File 'lib/plaid/models/link_events_webhook.rb', line 284 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/plaid/models/link_events_webhook.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/plaid/models/link_events_webhook.rb', line 278 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
168 169 170 171 172 173 174 175 176 |
# File 'lib/plaid/models/link_events_webhook.rb', line 168 def valid? return false if @webhook_type.nil? return false if @webhook_code.nil? return false if @events.nil? return false if @link_session_id.nil? return false if @link_token.nil? return false if @environment.nil? true end |