Class: Plaid::LinkTokenCreateRequestCraOptions
- Inherits:
-
Object
- Object
- Plaid::LinkTokenCreateRequestCraOptions
- Defined in:
- lib/plaid/models/link_token_create_request_cra_options.rb
Overview
Specifies options for initializing Link for use with Plaid Check products
Instance Attribute Summary collapse
-
#base_report ⇒ Object
Returns the value of attribute base_report.
-
#cashflow_insights ⇒ Object
Returns the value of attribute cashflow_insights.
-
#client_report_id ⇒ Object
Client-generated identifier, which can be used by lenders to track loan applications.
-
#days_requested ⇒ Object
The number of days of history to include in Plaid Check products.
-
#days_required ⇒ Object
The minimum number of days of data required for the report to be successfully generated.
-
#include_investments ⇒ Object
Indicates that investment data should be extracted from the linked account(s).
-
#income_insights ⇒ Object
Returns the value of attribute income_insights.
-
#lend_score ⇒ Object
Returns the value of attribute lend_score.
-
#network_insights ⇒ Object
Returns the value of attribute network_insights.
-
#partner_insights ⇒ Object
Returns the value of attribute partner_insights.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkTokenCreateRequestCraOptions
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LinkTokenCreateRequestCraOptions
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::LinkTokenCreateRequestCraOptions` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::LinkTokenCreateRequestCraOptions`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'days_requested') self.days_requested = attributes[:'days_requested'] end if attributes.key?(:'days_required') self.days_required = attributes[:'days_required'] end if attributes.key?(:'client_report_id') self.client_report_id = attributes[:'client_report_id'] end if attributes.key?(:'partner_insights') self.partner_insights = attributes[:'partner_insights'] end if attributes.key?(:'base_report') self.base_report = attributes[:'base_report'] end if attributes.key?(:'cashflow_insights') self.cashflow_insights = attributes[:'cashflow_insights'] end if attributes.key?(:'lend_score') self.lend_score = attributes[:'lend_score'] end if attributes.key?(:'network_insights') self.network_insights = attributes[:'network_insights'] end if attributes.key?(:'include_investments') self.include_investments = attributes[:'include_investments'] end if attributes.key?(:'income_insights') self.income_insights = attributes[:'income_insights'] end end |
Instance Attribute Details
#base_report ⇒ Object
Returns the value of attribute base_report.
30 31 32 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 30 def base_report @base_report end |
#cashflow_insights ⇒ Object
Returns the value of attribute cashflow_insights.
32 33 34 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 32 def cashflow_insights @cashflow_insights end |
#client_report_id ⇒ Object
Client-generated identifier, which can be used by lenders to track loan applications.
26 27 28 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 26 def client_report_id @client_report_id end |
#days_requested ⇒ Object
The number of days of history to include in Plaid Check products. Maximum is 731; minimum is 180. If a value lower than 180 is provided, a minimum of 180 days of history will be requested.
20 21 22 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 20 def days_requested @days_requested end |
#days_required ⇒ Object
The minimum number of days of data required for the report to be successfully generated.
23 24 25 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 23 def days_required @days_required end |
#include_investments ⇒ Object
Indicates that investment data should be extracted from the linked account(s).
39 40 41 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 39 def include_investments @include_investments end |
#income_insights ⇒ Object
Returns the value of attribute income_insights.
41 42 43 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 41 def income_insights @income_insights end |
#lend_score ⇒ Object
Returns the value of attribute lend_score.
34 35 36 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 34 def lend_score @lend_score end |
#network_insights ⇒ Object
Returns the value of attribute network_insights.
36 37 38 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 36 def network_insights @network_insights end |
#partner_insights ⇒ Object
Returns the value of attribute partner_insights.
28 29 30 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 28 def partner_insights @partner_insights end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 60 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 44 def self.attribute_map { :'days_requested' => :'days_requested', :'days_required' => :'days_required', :'client_report_id' => :'client_report_id', :'partner_insights' => :'partner_insights', :'base_report' => :'base_report', :'cashflow_insights' => :'cashflow_insights', :'lend_score' => :'lend_score', :'network_insights' => :'network_insights', :'include_investments' => :'include_investments', :'income_insights' => :'income_insights' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 232 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 81 def self.openapi_nullable Set.new([ :'client_report_id', :'include_investments', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 65 def self.openapi_types { :'days_requested' => :'Integer', :'days_required' => :'Integer', :'client_report_id' => :'String', :'partner_insights' => :'LinkTokenCreateRequestCraOptionsPartnerInsights', :'base_report' => :'LinkTokenCreateRequestCraOptionsBaseReport', :'cashflow_insights' => :'LinkTokenCreateRequestCraOptionsCashflowInsights', :'lend_score' => :'LinkTokenCreateRequestCraOptionsLendScore', :'network_insights' => :'LinkTokenCreateRequestCraOptionsNetworkInsights', :'include_investments' => :'Boolean', :'income_insights' => :'LinkTokenCreateRequestCraOptionsIncomeInsights' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && days_requested == o.days_requested && days_required == o.days_required && client_report_id == o.client_report_id && partner_insights == o.partner_insights && base_report == o.base_report && cashflow_insights == o.cashflow_insights && lend_score == o.lend_score && network_insights == o.network_insights && include_investments == o.include_investments && income_insights == o.income_insights end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 263 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 334 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 239 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 225 def hash [days_requested, days_required, client_report_id, partner_insights, base_report, cashflow_insights, lend_score, network_insights, include_investments, income_insights].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 146 def list_invalid_properties invalid_properties = Array.new if @days_requested.nil? invalid_properties.push('invalid value for "days_requested", days_requested cannot be nil.') end if @days_requested > 731 invalid_properties.push('invalid value for "days_requested", must be smaller than or equal to 731.') end if !@days_required.nil? && @days_required > 184 invalid_properties.push('invalid value for "days_required", must be smaller than or equal to 184.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
310 311 312 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 310 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 316 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
304 305 306 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 304 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 |
# File 'lib/plaid/models/link_token_create_request_cra_options.rb', line 167 def valid? return false if @days_requested.nil? return false if @days_requested > 731 return false if !@days_required.nil? && @days_required > 184 true end |