Class: Plaid::LoanPaymentFrequency
- Inherits:
-
Object
- Object
- Plaid::LoanPaymentFrequency
- Defined in:
- lib/plaid/models/loan_payment_frequency.rb
Constant Summary collapse
- DAILY =
"daily".freeze
- WEEKLY =
"weekly".freeze
- BIWEEKLY =
"biweekly".freeze
- SEMIMONTHLY =
"semimonthly".freeze
- MONTHLY =
"monthly".freeze
- SEMIANNUALLY =
"semiannually".freeze
- ANNUALLY =
"annually".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
29 30 31 |
# File 'lib/plaid/models/loan_payment_frequency.rb', line 29 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
36 37 38 39 40 41 |
# File 'lib/plaid/models/loan_payment_frequency.rb', line 36 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |