Class: Plaid::LoanPaymentsIndicators

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/loan_payments_indicators.rb

Overview

Insights into loan payment transactions made by the user, tracking outgoing payments to loan providers.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ LoanPaymentsIndicators

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/plaid/models/loan_payments_indicators.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::LoanPaymentsIndicators` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::LoanPaymentsIndicators`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'iso_currency_code')
    self.iso_currency_code = attributes[:'iso_currency_code']
  end

  if attributes.key?(:'unofficial_currency_code')
    self.unofficial_currency_code = attributes[:'unofficial_currency_code']
  end

  if attributes.key?(:'monthly_average')
    self.monthly_average = attributes[:'monthly_average']
  end

  if attributes.key?(:'category_details')
    if (value = attributes[:'category_details']).is_a?(Array)
      self.category_details = value
    end
  end

  if attributes.key?(:'top_providers')
    if (value = attributes[:'top_providers']).is_a?(Array)
      self.top_providers = value
    end
  end

  if attributes.key?(:'transactions_count')
    self.transactions_count = attributes[:'transactions_count']
  end

  if attributes.key?(:'monthly_summaries')
    if (value = attributes[:'monthly_summaries']).is_a?(Array)
      self.monthly_summaries = value
    end
  end

  if attributes.key?(:'days_since_last_occurrence')
    self.days_since_last_occurrence = attributes[:'days_since_last_occurrence']
  end

  if attributes.key?(:'percentage_of_income')
    self.percentage_of_income = attributes[:'percentage_of_income']
  end
end

Instance Attribute Details

#amountObject

The total value of outflow transactions categorized as ‘LOAN_PAYMENTS`, across all the accounts in the report within the requested time window.



20
21
22
# File 'lib/plaid/models/loan_payments_indicators.rb', line 20

def amount
  @amount
end

#category_detailsObject

Detailed categories view of all the transactions that fall into the ‘LOAN_PAYMENTS` credit category within the given time window, across all the accounts in the report.



31
32
33
# File 'lib/plaid/models/loan_payments_indicators.rb', line 31

def category_details
  @category_details
end

#days_since_last_occurrenceObject

The number of days since the last transaction that falls into the ‘LOAN_PAYMENTS` credit category, across all the accounts in the report.



43
44
45
# File 'lib/plaid/models/loan_payments_indicators.rb', line 43

def days_since_last_occurrence
  @days_since_last_occurrence
end

#iso_currency_codeObject

The ISO-4217 currency code of the amount. Always ‘null` if `unofficial_currency_code` is non-`null`.



23
24
25
# File 'lib/plaid/models/loan_payments_indicators.rb', line 23

def iso_currency_code
  @iso_currency_code
end

#monthly_averageObject

Returns the value of attribute monthly_average.



28
29
30
# File 'lib/plaid/models/loan_payments_indicators.rb', line 28

def monthly_average
  @monthly_average
end

#monthly_summariesObject

The monthly summaries of the transactions that fall into the ‘LOAN_PAYMENTS` credit category within the given time window, across all the accounts in the report.



40
41
42
# File 'lib/plaid/models/loan_payments_indicators.rb', line 40

def monthly_summaries
  @monthly_summaries
end

#percentage_of_incomeObject

The percentage of the user’s monthly inflows that was spent on transactions that fall into the ‘LOAN_PAYMENTS` credit category within the given time window, across all the accounts in the report. For example, a value of 100 indicates that 100% of the inflows were spent on transactions that fall into the `LOAN_PAYMENTS` credit category. If there’s no available income for the giving time period, this field value will be ‘-1`



46
47
48
# File 'lib/plaid/models/loan_payments_indicators.rb', line 46

def percentage_of_income
  @percentage_of_income
end

#top_providersObject

Up to 3 top service providers that the user had the most transactions for in the given time window, in descending order of total spend. If the user has not spent money on any provider in the given time window, this list will be empty.



34
35
36
# File 'lib/plaid/models/loan_payments_indicators.rb', line 34

def top_providers
  @top_providers
end

#transactions_countObject

The total number of transactions that fall into the ‘LOAN_PAYMENTS` credit category, across all the accounts in the report.



37
38
39
# File 'lib/plaid/models/loan_payments_indicators.rb', line 37

def transactions_count
  @transactions_count
end

#unofficial_currency_codeObject

The unofficial currency code associated with the amount. Always ‘null` if `iso_currency_code` is non-`null`. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.



26
27
28
# File 'lib/plaid/models/loan_payments_indicators.rb', line 26

def unofficial_currency_code
  @unofficial_currency_code
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/plaid/models/loan_payments_indicators.rb', line 65

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/plaid/models/loan_payments_indicators.rb', line 49

def self.attribute_map
  {
    :'amount' => :'amount',
    :'iso_currency_code' => :'iso_currency_code',
    :'unofficial_currency_code' => :'unofficial_currency_code',
    :'monthly_average' => :'monthly_average',
    :'category_details' => :'category_details',
    :'top_providers' => :'top_providers',
    :'transactions_count' => :'transactions_count',
    :'monthly_summaries' => :'monthly_summaries',
    :'days_since_last_occurrence' => :'days_since_last_occurrence',
    :'percentage_of_income' => :'percentage_of_income'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
# File 'lib/plaid/models/loan_payments_indicators.rb', line 205

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
91
92
93
94
95
96
# File 'lib/plaid/models/loan_payments_indicators.rb', line 86

def self.openapi_nullable
  Set.new([
    :'amount',
    :'iso_currency_code',
    :'unofficial_currency_code',
    :'monthly_average',
    :'transactions_count',
    :'days_since_last_occurrence',
    :'percentage_of_income'
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/plaid/models/loan_payments_indicators.rb', line 70

def self.openapi_types
  {
    :'amount' => :'Float',
    :'iso_currency_code' => :'String',
    :'unofficial_currency_code' => :'String',
    :'monthly_average' => :'MonthlyAverage',
    :'category_details' => :'Array<CategoryExpenses>',
    :'top_providers' => :'Array<String>',
    :'transactions_count' => :'Integer',
    :'monthly_summaries' => :'Array<MonthlySummary>',
    :'days_since_last_occurrence' => :'Integer',
    :'percentage_of_income' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/plaid/models/loan_payments_indicators.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      iso_currency_code == o.iso_currency_code &&
      unofficial_currency_code == o.unofficial_currency_code &&
      monthly_average == o.monthly_average &&
      category_details == o.category_details &&
      top_providers == o.top_providers &&
      transactions_count == o.transactions_count &&
      monthly_summaries == o.monthly_summaries &&
      days_since_last_occurrence == o.days_since_last_occurrence &&
      percentage_of_income == o.percentage_of_income
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/plaid/models/loan_payments_indicators.rb', line 236

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/plaid/models/loan_payments_indicators.rb', line 307

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/plaid/models/loan_payments_indicators.rb', line 212

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/plaid/models/loan_payments_indicators.rb', line 192

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



198
199
200
# File 'lib/plaid/models/loan_payments_indicators.rb', line 198

def hash
  [amount, iso_currency_code, unofficial_currency_code, monthly_average, category_details, top_providers, transactions_count, monthly_summaries, days_since_last_occurrence, percentage_of_income].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
# File 'lib/plaid/models/loan_payments_indicators.rb', line 162

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



283
284
285
# File 'lib/plaid/models/loan_payments_indicators.rb', line 283

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/plaid/models/loan_payments_indicators.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



277
278
279
# File 'lib/plaid/models/loan_payments_indicators.rb', line 277

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
# File 'lib/plaid/models/loan_payments_indicators.rb', line 169

def valid?
  true
end