Class: Plaid::OverrideAccounts

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/override_accounts.rb

Overview

Data to use to set values of test accounts. Some values cannot be specified in the schema and will instead will be calculated from other test data in order to achieve more consistent, realistic test data.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ OverrideAccounts

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/plaid/models/override_accounts.rb', line 132

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::OverrideAccounts` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::OverrideAccounts`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'subtype')
    self.subtype = attributes[:'subtype']
  end

  if attributes.key?(:'starting_balance')
    self.starting_balance = attributes[:'starting_balance']
  end

  if attributes.key?(:'force_available_balance')
    self.force_available_balance = attributes[:'force_available_balance']
  end

  if attributes.key?(:'has_null_available_balance')
    self.has_null_available_balance = attributes[:'has_null_available_balance']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'meta')
    self.meta = attributes[:'meta']
  end

  if attributes.key?(:'numbers')
    self.numbers = attributes[:'numbers']
  end

  if attributes.key?(:'transactions')
    if (value = attributes[:'transactions']).is_a?(Array)
      self.transactions = value
    end
  end

  if attributes.key?(:'holdings')
    self.holdings = attributes[:'holdings']
  end

  if attributes.key?(:'investment_transactions')
    self.investment_transactions = attributes[:'investment_transactions']
  end

  if attributes.key?(:'identity')
    self.identity = attributes[:'identity']
  end

  if attributes.key?(:'liability')
    self.liability = attributes[:'liability']
  end

  if attributes.key?(:'inflow_model')
    self.inflow_model = attributes[:'inflow_model']
  end

  if attributes.key?(:'income')
    self.income = attributes[:'income']
  end
end

Instance Attribute Details

#currencyObject

ISO-4217 currency code. If provided, the account will be denominated in the given currency. Transactions will also be in this currency by default.



33
34
35
# File 'lib/plaid/models/override_accounts.rb', line 33

def currency
  @currency
end

#force_available_balanceObject

If provided, the account will always have this amount as its available balance, regardless of current balance or changes in transactions over time. Cannot be set together with ‘has_null_available_balance`.



27
28
29
# File 'lib/plaid/models/override_accounts.rb', line 27

def force_available_balance
  @force_available_balance
end

#has_null_available_balanceObject

If set to ‘true`, the account will always have null as its available balance, regardless of current balance or changes in transactions over time. Cannot be set together with `force_available_balance`.



30
31
32
# File 'lib/plaid/models/override_accounts.rb', line 30

def has_null_available_balance
  @has_null_available_balance
end

#holdingsObject

Returns the value of attribute holdings.



42
43
44
# File 'lib/plaid/models/override_accounts.rb', line 42

def holdings
  @holdings
end

#identityObject

Returns the value of attribute identity.



46
47
48
# File 'lib/plaid/models/override_accounts.rb', line 46

def identity
  @identity
end

#incomeObject

Returns the value of attribute income.



52
53
54
# File 'lib/plaid/models/override_accounts.rb', line 52

def income
  @income
end

#inflow_modelObject

Returns the value of attribute inflow_model.



50
51
52
# File 'lib/plaid/models/override_accounts.rb', line 50

def inflow_model
  @inflow_model
end

#investment_transactionsObject

Returns the value of attribute investment_transactions.



44
45
46
# File 'lib/plaid/models/override_accounts.rb', line 44

def investment_transactions
  @investment_transactions
end

#liabilityObject

Returns the value of attribute liability.



48
49
50
# File 'lib/plaid/models/override_accounts.rb', line 48

def liability
  @liability
end

#metaObject

Returns the value of attribute meta.



35
36
37
# File 'lib/plaid/models/override_accounts.rb', line 35

def meta
  @meta
end

#numbersObject

Returns the value of attribute numbers.



37
38
39
# File 'lib/plaid/models/override_accounts.rb', line 37

def numbers
  @numbers
end

#starting_balanceObject

If provided, the account will start with this amount as the current balance.



24
25
26
# File 'lib/plaid/models/override_accounts.rb', line 24

def starting_balance
  @starting_balance
end

#subtypeObject

Returns the value of attribute subtype.



21
22
23
# File 'lib/plaid/models/override_accounts.rb', line 21

def subtype
  @subtype
end

#transactionsObject

Specify the list of transactions on the account.



40
41
42
# File 'lib/plaid/models/override_accounts.rb', line 40

def transactions
  @transactions
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/plaid/models/override_accounts.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/plaid/models/override_accounts.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/plaid/models/override_accounts.rb', line 77

def self.attribute_map
  {
    :'type' => :'type',
    :'subtype' => :'subtype',
    :'starting_balance' => :'starting_balance',
    :'force_available_balance' => :'force_available_balance',
    :'has_null_available_balance' => :'has_null_available_balance',
    :'currency' => :'currency',
    :'meta' => :'meta',
    :'numbers' => :'numbers',
    :'transactions' => :'transactions',
    :'holdings' => :'holdings',
    :'investment_transactions' => :'investment_transactions',
    :'identity' => :'identity',
    :'liability' => :'liability',
    :'inflow_model' => :'inflow_model',
    :'income' => :'income'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



313
314
315
# File 'lib/plaid/models/override_accounts.rb', line 313

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
128
# File 'lib/plaid/models/override_accounts.rb', line 124

def self.openapi_nullable
  Set.new([
    :'subtype',
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/plaid/models/override_accounts.rb', line 103

def self.openapi_types
  {
    :'type' => :'OverrideAccountType',
    :'subtype' => :'AccountSubtype',
    :'starting_balance' => :'Float',
    :'force_available_balance' => :'Float',
    :'has_null_available_balance' => :'Boolean',
    :'currency' => :'String',
    :'meta' => :'Meta',
    :'numbers' => :'Numbers',
    :'transactions' => :'Array<TransactionOverride>',
    :'holdings' => :'HoldingsOverride',
    :'investment_transactions' => :'InvestmentsTransactionsOverride',
    :'identity' => :'OwnerOverride',
    :'liability' => :'LiabilityOverride',
    :'inflow_model' => :'InflowModel',
    :'income' => :'IncomeOverride'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/plaid/models/override_accounts.rb', line 278

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      subtype == o.subtype &&
      starting_balance == o.starting_balance &&
      force_available_balance == o.force_available_balance &&
      has_null_available_balance == o.has_null_available_balance &&
      currency == o.currency &&
      meta == o.meta &&
      numbers == o.numbers &&
      transactions == o.transactions &&
      holdings == o.holdings &&
      investment_transactions == o.investment_transactions &&
      identity == o.identity &&
      liability == o.liability &&
      inflow_model == o.inflow_model &&
      income == o.income
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/plaid/models/override_accounts.rb', line 344

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/plaid/models/override_accounts.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/plaid/models/override_accounts.rb', line 320

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


300
301
302
# File 'lib/plaid/models/override_accounts.rb', line 300

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



306
307
308
# File 'lib/plaid/models/override_accounts.rb', line 306

def hash
  [type, subtype, starting_balance, force_available_balance, has_null_available_balance, currency, meta, numbers, transactions, holdings, investment_transactions, identity, liability, inflow_model, income].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/plaid/models/override_accounts.rb', line 210

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @starting_balance.nil?
    invalid_properties.push('invalid value for "starting_balance", starting_balance cannot be nil.')
  end

  if @force_available_balance.nil?
    invalid_properties.push('invalid value for "force_available_balance", force_available_balance cannot be nil.')
  end

  if @has_null_available_balance.nil?
    invalid_properties.push('invalid value for "has_null_available_balance", has_null_available_balance cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  if @meta.nil?
    invalid_properties.push('invalid value for "meta", meta cannot be nil.')
  end

  if @numbers.nil?
    invalid_properties.push('invalid value for "numbers", numbers cannot be nil.')
  end

  if @transactions.nil?
    invalid_properties.push('invalid value for "transactions", transactions cannot be nil.')
  end

  if @identity.nil?
    invalid_properties.push('invalid value for "identity", identity cannot be nil.')
  end

  if @liability.nil?
    invalid_properties.push('invalid value for "liability", liability cannot be nil.')
  end

  if @inflow_model.nil?
    invalid_properties.push('invalid value for "inflow_model", inflow_model cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
# File 'lib/plaid/models/override_accounts.rb', line 391

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/plaid/models/override_accounts.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/plaid/models/override_accounts.rb', line 385

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/plaid/models/override_accounts.rb', line 261

def valid?
  return false if @type.nil?
  return false if @starting_balance.nil?
  return false if @force_available_balance.nil?
  return false if @has_null_available_balance.nil?
  return false if @currency.nil?
  return false if @meta.nil?
  return false if @numbers.nil?
  return false if @transactions.nil?
  return false if @identity.nil?
  return false if @liability.nil?
  return false if @inflow_model.nil?
  true
end