Class: Plaid::PaymentInitiationConsentCreateRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/payment_initiation_consent_create_request.rb

Overview

PaymentInitiationConsentCreateRequest defines the request schema for /payment_initiation/consent/create

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PaymentInitiationConsentCreateRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::PaymentInitiationConsentCreateRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::PaymentInitiationConsentCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  end

  if attributes.key?(:'recipient_id')
    self.recipient_id = attributes[:'recipient_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'scopes')
    if (value = attributes[:'scopes']).is_a?(Array)
      self.scopes = value
    end
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'constraints')
    self.constraints = attributes[:'constraints']
  end

  if attributes.key?(:'options')
    self.options = attributes[:'options']
  end

  if attributes.key?(:'payer_details')
    self.payer_details = attributes[:'payer_details']
  end
end

Instance Attribute Details

#client_idObject

Your Plaid API client_id. The client_id is required and may be provided either in the PLAID-CLIENT-ID header or as part of a request body.



20
21
22
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 20

def client_id
  @client_id
end

#constraintsObject

Returns the value of attribute constraints.



39
40
41
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 39

def constraints
  @constraints
end

#optionsObject

Returns the value of attribute options.



41
42
43
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 41

def options
  @options
end

#payer_detailsObject

Returns the value of attribute payer_details.



43
44
45
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 43

def payer_details
  @payer_details
end

#recipient_idObject

The ID of the recipient the payment consent is for. The created consent can be used to transfer funds to this recipient only.



26
27
28
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 26

def recipient_id
  @recipient_id
end

#referenceObject

A reference for the payment consent. This must be an alphanumeric string with at most 18 characters and must not contain any special characters.



32
33
34
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 32

def reference
  @reference
end

#scopesObject

An array of payment consent scopes.



35
36
37
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 35

def scopes
  @scopes
end

#secretObject

Your Plaid API secret. The secret is required and may be provided either in the PLAID-SECRET header or as part of a request body.



23
24
25
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 23

def secret
  @secret
end

#typeObject

Returns the value of attribute type.



37
38
39
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 37

def type
  @type
end

#user_idObject

The user_id of the end user the payment consent is for, as returned by /user/create. The user must have a name and either an email address or a phone number. Payments created from this consent inherit this user_id. Required for new integrations.



29
30
31
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 29

def user_id
  @user_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 84

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 68

def self.attribute_map
  {
    :'client_id' => :'client_id',
    :'secret' => :'secret',
    :'recipient_id' => :'recipient_id',
    :'user_id' => :'user_id',
    :'reference' => :'reference',
    :'scopes' => :'scopes',
    :'type' => :'type',
    :'constraints' => :'constraints',
    :'options' => :'options',
    :'payer_details' => :'payer_details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 277

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
110
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 105

def self.openapi_nullable
  Set.new([
    :'options',
    :'payer_details'
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 89

def self.openapi_types
  {
    :'client_id' => :'String',
    :'secret' => :'String',
    :'recipient_id' => :'String',
    :'user_id' => :'String',
    :'reference' => :'String',
    :'scopes' => :'Array<PaymentInitiationConsentScope>',
    :'type' => :'PaymentInitiationConsentType',
    :'constraints' => :'PaymentInitiationConsentConstraints',
    :'options' => :'ExternalPaymentInitiationConsentOptions',
    :'payer_details' => :'PaymentInitiationConsentPayerDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      client_id == o.client_id &&
      secret == o.secret &&
      recipient_id == o.recipient_id &&
      user_id == o.user_id &&
      reference == o.reference &&
      scopes == o.scopes &&
      type == o.type &&
      constraints == o.constraints &&
      options == o.options &&
      payer_details == o.payer_details
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 308

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 284

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



270
271
272
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 270

def hash
  [client_id, secret, recipient_id, user_id, reference, scopes, type, constraints, options, payer_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 172

def list_invalid_properties
  invalid_properties = Array.new
  if @recipient_id.nil?
    invalid_properties.push('invalid value for "recipient_id", recipient_id cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  if @reference.to_s.length > 18
    invalid_properties.push('invalid value for "reference", the character length must be smaller than or equal to 18.')
  end

  if @reference.to_s.length < 1
    invalid_properties.push('invalid value for "reference", the character length must be great than or equal to 1.')
  end



  if !@scopes.nil? && @scopes.length < 1
    invalid_properties.push('invalid value for "scopes", number of items must be greater than or equal to 1.')
  end

  if @constraints.nil?
    invalid_properties.push('invalid value for "constraints", constraints cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
# File 'lib/plaid/models/payment_initiation_consent_create_request.rb', line 205

def valid?
  return false if @recipient_id.nil?
  return false if @reference.nil?
  return false if @reference.to_s.length > 18
  return false if @reference.to_s.length < 1
  return false if !@scopes.nil? && @scopes.length < 1
  return false if @constraints.nil?
  true
end