Class: Plaid::PersonalFinanceCategory

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/personal_finance_category.rb

Overview

Information describing the intent of the transaction. Most relevant for personal finance use cases, but not limited to such use cases. See the [taxonomy CSV file](plaid.com/documents/pfc-taxonomy-all.csv) for a full list of personal finance categories. If you are migrating to personal finance categories from the legacy categories, also refer to the [migration guide](plaid.com/docs/transactions/pfc-migration/).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PersonalFinanceCategory

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/plaid/models/personal_finance_category.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::PersonalFinanceCategory` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::PersonalFinanceCategory`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'primary')
    self.primary = attributes[:'primary']
  end

  if attributes.key?(:'detailed')
    self.detailed = attributes[:'detailed']
  end

  if attributes.key?(:'confidence_level')
    self.confidence_level = attributes[:'confidence_level']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#confidence_levelObject

A description of how confident we are that the provided categories accurately describe the transaction intent. ‘VERY_HIGH`: We are more than 98% confident that this category reflects the intent of the transaction. `HIGH`: We are more than 90% confident that this category reflects the intent of the transaction. `MEDIUM`: We are moderately confident that this category reflects the intent of the transaction. `LOW`: This category may reflect the intent, but there may be other categories that are more accurate. `UNKNOWN`: We don’t know the confidence level for this category.



26
27
28
# File 'lib/plaid/models/personal_finance_category.rb', line 26

def confidence_level
  @confidence_level
end

#detailedObject

A granular category conveying the transaction’s intent. This field can also be used as a unique identifier for the category.



23
24
25
# File 'lib/plaid/models/personal_finance_category.rb', line 23

def detailed
  @detailed
end

#primaryObject

A high level category that communicates the broad category of the transaction.



20
21
22
# File 'lib/plaid/models/personal_finance_category.rb', line 20

def primary
  @primary
end

#versionObject

Returns the value of attribute version.



28
29
30
# File 'lib/plaid/models/personal_finance_category.rb', line 28

def version
  @version
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/plaid/models/personal_finance_category.rb', line 63

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/plaid/models/personal_finance_category.rb', line 53

def self.attribute_map
  {
    :'primary' => :'primary',
    :'detailed' => :'detailed',
    :'confidence_level' => :'confidence_level',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
# File 'lib/plaid/models/personal_finance_category.rb', line 165

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
82
# File 'lib/plaid/models/personal_finance_category.rb', line 78

def self.openapi_nullable
  Set.new([
    :'confidence_level',
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
# File 'lib/plaid/models/personal_finance_category.rb', line 68

def self.openapi_types
  {
    :'primary' => :'String',
    :'detailed' => :'String',
    :'confidence_level' => :'String',
    :'version' => :'PersonalFinanceCategoryVersion'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
# File 'lib/plaid/models/personal_finance_category.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      primary == o.primary &&
      detailed == o.detailed &&
      confidence_level == o.confidence_level &&
      version == o.version
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/plaid/models/personal_finance_category.rb', line 196

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/plaid/models/personal_finance_category.rb', line 267

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/plaid/models/personal_finance_category.rb', line 172

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/plaid/models/personal_finance_category.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/plaid/models/personal_finance_category.rb', line 158

def hash
  [primary, detailed, confidence_level, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/plaid/models/personal_finance_category.rb', line 118

def list_invalid_properties
  invalid_properties = Array.new
  if @primary.nil?
    invalid_properties.push('invalid value for "primary", primary cannot be nil.')
  end

  if @detailed.nil?
    invalid_properties.push('invalid value for "detailed", detailed cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
# File 'lib/plaid/models/personal_finance_category.rb', line 243

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/plaid/models/personal_finance_category.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



237
238
239
# File 'lib/plaid/models/personal_finance_category.rb', line 237

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
# File 'lib/plaid/models/personal_finance_category.rb', line 133

def valid?
  return false if @primary.nil?
  return false if @detailed.nil?
  true
end