Class: Plaid::PlaidErrorType

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/plaid_error_type.rb

Constant Summary collapse

INVALID_REQUEST =
"INVALID_REQUEST".freeze
INVALID_RESULT =
"INVALID_RESULT".freeze
INVALID_INPUT =
"INVALID_INPUT".freeze
INSTITUTION_ERROR =
"INSTITUTION_ERROR".freeze
RATE_LIMIT_EXCEEDED =
"RATE_LIMIT_EXCEEDED".freeze
API_ERROR =
"API_ERROR".freeze
ITEM_ERROR =
"ITEM_ERROR".freeze
ASSET_REPORT_ERROR =
"ASSET_REPORT_ERROR".freeze
BASE_REPORT_ERROR =
"BASE_REPORT_ERROR".freeze
RECAPTCHA_ERROR =
"RECAPTCHA_ERROR".freeze
OAUTH_ERROR =
"OAUTH_ERROR".freeze
PAYMENT_ERROR =
"PAYMENT_ERROR".freeze
BANK_TRANSFER_ERROR =
"BANK_TRANSFER_ERROR".freeze
INCOME_VERIFICATION_ERROR =
"INCOME_VERIFICATION_ERROR".freeze
MICRODEPOSITS_ERROR =
"MICRODEPOSITS_ERROR".freeze
SANDBOX_ERROR =
"SANDBOX_ERROR".freeze
PARTNER_ERROR =
"PARTNER_ERROR".freeze
SIGNAL_ERROR =
"SIGNAL_ERROR".freeze
TRANSACTIONS_ERROR =
"TRANSACTIONS_ERROR".freeze
TRANSACTION_ERROR =
"TRANSACTION_ERROR".freeze
TRANSFER_ERROR =
"TRANSFER_ERROR".freeze
CHECK_REPORT_ERROR =
"CHECK_REPORT_ERROR".freeze
CONSUMER_REPORT_ERROR =
"CONSUMER_REPORT_ERROR".freeze
USER_ERROR =
"USER_ERROR".freeze
IDEMPOTENCY_ERROR =
"IDEMPOTENCY_ERROR".freeze
ASSETS_ERROR =
"ASSETS_ERROR".freeze
CRA_MONITORING_ERROR =
"CRA_MONITORING_ERROR".freeze
CREDIT_PROFILE_REPORT_ERROR =
"CREDIT_PROFILE_REPORT_ERROR".freeze
ENCOMPASS_ERROR =
"ENCOMPASS_ERROR".freeze
ENRICH_ERROR =
"ENRICH_ERROR".freeze
FRAUD_INSIGHTS_ERROR =
"FRAUD_INSIGHTS_ERROR".freeze
FREDDIE_MAC_ERROR =
"FREDDIE_MAC_ERROR".freeze
"LINK_DELIVERY_ERROR".freeze
PROFILE_ERROR =
"PROFILE_ERROR".freeze
RECURRING_TRANSACTIONS_ERROR =
"RECURRING_TRANSACTIONS_ERROR".freeze
STATEMENTS_ERROR =
"STATEMENTS_ERROR".freeze
TRANSFER_RECURRING_ERROR =
"TRANSFER_RECURRING_ERROR".freeze
TRANSFER_REFUND_ERROR =
"TRANSFER_REFUND_ERROR".freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



60
61
62
# File 'lib/plaid/models/plaid_error_type.rb', line 60

def self.build_from_hash(value)
  new.build_from_hash(value)
end

Instance Method Details

#build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



67
68
69
70
71
72
# File 'lib/plaid/models/plaid_error_type.rb', line 67

def build_from_hash(value)
  # We do not validate that the value is one of the enums set in the OpenAPI
  # file because we want to be able to add to our list of enums without
  # breaking this client library.
  value
end