Class: Plaid::ProcessorInvestmentsAuthGetResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/processor_investments_auth_get_response.rb

Overview

ProcessorInvestmentsAuthGetResponse defines the response schema for ‘/processor/investments/auth/get`

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProcessorInvestmentsAuthGetResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::ProcessorInvestmentsAuthGetResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::ProcessorInvestmentsAuthGetResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'holdings')
    if (value = attributes[:'holdings']).is_a?(Array)
      self.holdings = value
    end
  end

  if attributes.key?(:'securities')
    if (value = attributes[:'securities']).is_a?(Array)
      self.securities = value
    end
  end

  if attributes.key?(:'owners')
    if (value = attributes[:'owners']).is_a?(Array)
      self.owners = value
    end
  end

  if attributes.key?(:'numbers')
    self.numbers = attributes[:'numbers']
  end

  if attributes.key?(:'data_sources')
    self.data_sources = attributes[:'data_sources']
  end

  if attributes.key?(:'account_details_401k')
    if (value = attributes[:'account_details_401k']).is_a?(Array)
      self. = value
    end
  end

  if attributes.key?(:'is_investments_fallback_item')
    self.is_investments_fallback_item = attributes[:'is_investments_fallback_item']
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



19
20
21
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 19

def 
  @account
end

#account_details_401kObject

Additional information for accounts of 401k subtype.



35
36
37
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 35

def 
  @account_details_401k
end

#data_sourcesObject

Returns the value of attribute data_sources.



32
33
34
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 32

def data_sources
  @data_sources
end

#holdingsObject

The holdings belonging to the investment account. Details of the securities in the holdings are provided in the ‘securities` field.



22
23
24
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 22

def holdings
  @holdings
end

#is_investments_fallback_itemObject

When true, this field indicates that the Item’s portfolio was manually created with the Investments Fallback flow.



38
39
40
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 38

def is_investments_fallback_item
  @is_investments_fallback_item
end

#numbersObject

Returns the value of attribute numbers.



30
31
32
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 30

def numbers
  @numbers
end

#ownersObject

Information about the account owners for the account.



28
29
30
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 28

def owners
  @owners
end

#request_idObject

A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.



41
42
43
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 41

def request_id
  @request_id
end

#securitiesObject

Objects describing the securities held in the account.



25
26
27
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 25

def securities
  @securities
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 59

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 44

def self.attribute_map
  {
    :'account' => :'account',
    :'holdings' => :'holdings',
    :'securities' => :'securities',
    :'owners' => :'owners',
    :'numbers' => :'numbers',
    :'data_sources' => :'data_sources',
    :'account_details_401k' => :'account_details_401k',
    :'is_investments_fallback_item' => :'is_investments_fallback_item',
    :'request_id' => :'request_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 223

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 64

def self.openapi_types
  {
    :'account' => :'AccountBase',
    :'holdings' => :'Array<Holding>',
    :'securities' => :'Array<Security>',
    :'owners' => :'Array<InvestmentsAuthOwner>',
    :'numbers' => :'InvestmentsAuthGetNumbers',
    :'data_sources' => :'InvestmentsAuthDataSources',
    :'account_details_401k' => :'Array<InvestmentsAuthAccountDetails401k>',
    :'is_investments_fallback_item' => :'Boolean',
    :'request_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      holdings == o.holdings &&
      securities == o.securities &&
      owners == o.owners &&
      numbers == o.numbers &&
      data_sources == o.data_sources &&
       == o. &&
      is_investments_fallback_item == o.is_investments_fallback_item &&
      request_id == o.request_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 254

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 325

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 230

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 216

def hash
  [, holdings, securities, owners, numbers, data_sources, , is_investments_fallback_item, request_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 146

def list_invalid_properties
  invalid_properties = Array.new
  if @account.nil?
    invalid_properties.push('invalid value for "account", account cannot be nil.')
  end

  if @holdings.nil?
    invalid_properties.push('invalid value for "holdings", holdings cannot be nil.')
  end

  if @securities.nil?
    invalid_properties.push('invalid value for "securities", securities cannot be nil.')
  end

  if @owners.nil?
    invalid_properties.push('invalid value for "owners", owners cannot be nil.')
  end

  if @numbers.nil?
    invalid_properties.push('invalid value for "numbers", numbers cannot be nil.')
  end

  if @data_sources.nil?
    invalid_properties.push('invalid value for "data_sources", data_sources cannot be nil.')
  end

  if @request_id.nil?
    invalid_properties.push('invalid value for "request_id", request_id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



301
302
303
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 301

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



295
296
297
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 295

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
190
# File 'lib/plaid/models/processor_investments_auth_get_response.rb', line 181

def valid?
  return false if @account.nil?
  return false if @holdings.nil?
  return false if @securities.nil?
  return false if @owners.nil?
  return false if @numbers.nil?
  return false if @data_sources.nil?
  return false if @request_id.nil?
  true
end