Class: Plaid::ProductsTerminateReasonCode

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/products_terminate_reason_code.rb

Constant Summary collapse

FRAUD_FIRST_PARTY =
"FRAUD_FIRST_PARTY".freeze
FRAUD_FALSE_IDENTITY =
"FRAUD_FALSE_IDENTITY".freeze
FRAUD_ABUSE =
"FRAUD_ABUSE".freeze
FRAUD_OTHER =
"FRAUD_OTHER".freeze
FRAUD_TRANSACTION =
"FRAUD_TRANSACTION".freeze
CONSUMER_LOAN_PAID_OFF =
"CONSUMER_LOAN_PAID_OFF".freeze
CONSUMER_ACCOUNT_CLOSED =
"CONSUMER_ACCOUNT_CLOSED".freeze
CONSUMER_CHARGE_OFF =
"CONSUMER_CHARGE_OFF".freeze
CONSUMER_PAYMENT_METHOD_SWITCHED =
"CONSUMER_PAYMENT_METHOD_SWITCHED".freeze
USER_OFFBOARDING =
"USER_OFFBOARDING".freeze
DUPLICATE_ITEM =
"DUPLICATE_ITEM".freeze
BILLING_TERMINATION =
"BILLING_TERMINATION".freeze
OTHER =
"OTHER".freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



35
36
37
# File 'lib/plaid/models/products_terminate_reason_code.rb', line 35

def self.build_from_hash(value)
  new.build_from_hash(value)
end

Instance Method Details

#build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



42
43
44
45
46
47
# File 'lib/plaid/models/products_terminate_reason_code.rb', line 42

def build_from_hash(value)
  # We do not validate that the value is one of the enums set in the OpenAPI
  # file because we want to be able to add to our list of enums without
  # breaking this client library.
  value
end