Class: Plaid::ProtectReportCreateRequest
- Inherits:
-
Object
- Object
- Plaid::ProtectReportCreateRequest
- Defined in:
- lib/plaid/models/protect_report_create_request.rb
Overview
Request object for ‘/protect/report/create`. You must provide either `user_id`, or an `incident_event` with at least one supported identifier: `link_session_id`, `idv_session_id`, `protect_event_id`, `signal_client_transaction_id`, or `access_token`. Context fields such as `internal_reference`, `time`, `amount`, and `bank_account` do not satisfy this identifier requirement.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ach_return_code ⇒ Object
Must be a valid ACH return code (e.g. ‘R01`), required if `report_type` is `ACH_RETURN`.
-
#bank_account ⇒ Object
Returns the value of attribute bank_account.
-
#client_id ⇒ Object
Your Plaid API ‘client_id`.
-
#incident_event ⇒ Object
Returns the value of attribute incident_event.
-
#notes ⇒ Object
Additional context or details about the report, required if ‘report_type` is `OTHER`.
-
#report_confidence ⇒ Object
Returns the value of attribute report_confidence.
-
#report_source ⇒ Object
Returns the value of attribute report_source.
-
#report_type ⇒ Object
Returns the value of attribute report_type.
-
#secret ⇒ Object
Your Plaid API ‘secret`.
-
#user_id ⇒ Object
The Plaid User ID associated with the report.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProtectReportCreateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ProtectReportCreateRequest
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::ProtectReportCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::ProtectReportCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'incident_event') self.incident_event = attributes[:'incident_event'] end if attributes.key?(:'report_confidence') self.report_confidence = attributes[:'report_confidence'] end if attributes.key?(:'report_type') self.report_type = attributes[:'report_type'] end if attributes.key?(:'report_source') self.report_source = attributes[:'report_source'] end if attributes.key?(:'bank_account') self.bank_account = attributes[:'bank_account'] end if attributes.key?(:'ach_return_code') self.ach_return_code = attributes[:'ach_return_code'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end end |
Instance Attribute Details
#ach_return_code ⇒ Object
Must be a valid ACH return code (e.g. ‘R01`), required if `report_type` is `ACH_RETURN`.
39 40 41 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 39 def ach_return_code @ach_return_code end |
#bank_account ⇒ Object
Returns the value of attribute bank_account.
36 37 38 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 36 def bank_account @bank_account end |
#client_id ⇒ Object
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
20 21 22 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 20 def client_id @client_id end |
#incident_event ⇒ Object
Returns the value of attribute incident_event.
28 29 30 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 28 def incident_event @incident_event end |
#notes ⇒ Object
Additional context or details about the report, required if ‘report_type` is `OTHER`.
42 43 44 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 42 def notes @notes end |
#report_confidence ⇒ Object
Returns the value of attribute report_confidence.
30 31 32 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 30 def report_confidence @report_confidence end |
#report_source ⇒ Object
Returns the value of attribute report_source.
34 35 36 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 34 def report_source @report_source end |
#report_type ⇒ Object
Returns the value of attribute report_type.
32 33 34 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 32 def report_type @report_type end |
#secret ⇒ Object
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
23 24 25 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 23 def secret @secret end |
#user_id ⇒ Object
The Plaid User ID associated with the report.
26 27 28 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 26 def user_id @user_id end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 83 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 67 def self.attribute_map { :'client_id' => :'client_id', :'secret' => :'secret', :'user_id' => :'user_id', :'incident_event' => :'incident_event', :'report_confidence' => :'report_confidence', :'report_type' => :'report_type', :'report_source' => :'report_source', :'bank_account' => :'bank_account', :'ach_return_code' => :'ach_return_code', :'notes' => :'notes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 229 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 108 109 110 111 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 104 def self.openapi_nullable Set.new([ :'incident_event', :'bank_account', :'ach_return_code', :'notes' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 88 def self.openapi_types { :'client_id' => :'String', :'secret' => :'String', :'user_id' => :'String', :'incident_event' => :'ProtectIncidentEvent', :'report_confidence' => :'ProtectReportConfidence', :'report_type' => :'ProtectReportType', :'report_source' => :'ProtectReportSource', :'bank_account' => :'ProtectBankAccount', :'ach_return_code' => :'String', :'notes' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && secret == o.secret && user_id == o.user_id && incident_event == o.incident_event && report_confidence == o.report_confidence && report_type == o.report_type && report_source == o.report_source && bank_account == o.bank_account && ach_return_code == o.ach_return_code && notes == o.notes end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 260 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 331 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 236 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 222 def hash [client_id, secret, user_id, incident_event, report_confidence, report_type, report_source, bank_account, ach_return_code, notes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 171 def list_invalid_properties invalid_properties = Array.new if @report_confidence.nil? invalid_properties.push('invalid value for "report_confidence", report_confidence cannot be nil.') end if @report_type.nil? invalid_properties.push('invalid value for "report_type", report_type cannot be nil.') end if @report_source.nil? invalid_properties.push('invalid value for "report_source", report_source cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
307 308 309 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 307 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
301 302 303 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 301 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
190 191 192 193 194 195 |
# File 'lib/plaid/models/protect_report_create_request.rb', line 190 def valid? return false if @report_confidence.nil? return false if @report_type.nil? return false if @report_source.nil? true end |