Class: Plaid::SandboxIncomeWebhookFireRequestWebhookCode
- Inherits:
-
Object
- Object
- Plaid::SandboxIncomeWebhookFireRequestWebhookCode
- Defined in:
- lib/plaid/models/sandbox_income_webhook_fire_request_webhook_code.rb
Constant Summary collapse
- INCOME_VERIFICATION =
"INCOME_VERIFICATION".freeze
- USER_INCOME_VERIFICATION =
"USER_INCOME_VERIFICATION".freeze
- INCOME_VERIFICATION_RISK_SIGNALS =
"INCOME_VERIFICATION_RISK_SIGNALS".freeze
- USER_INCOME_VERIFICATION_RISK_SIGNALS =
"USER_INCOME_VERIFICATION_RISK_SIGNALS".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
26 27 28 |
# File 'lib/plaid/models/sandbox_income_webhook_fire_request_webhook_code.rb', line 26 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
33 34 35 36 37 38 |
# File 'lib/plaid/models/sandbox_income_webhook_fire_request_webhook_code.rb', line 33 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |