Class: Plaid::Transaction
- Inherits:
-
Object
- Object
- Plaid::Transaction
- Defined in:
- lib/plaid/models/transaction.rb
Overview
A representation of a transaction
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account in which this transaction occurred.
-
#account_owner ⇒ Object
This field is not typically populated and only relevant when dealing with sub-accounts.
-
#amount ⇒ Object
The settled value of the transaction, denominated in the transaction's currency, as stated in
iso_currency_codeorunofficial_currency_code. -
#authorized_date ⇒ Object
The date that the transaction was authorized.
-
#authorized_datetime ⇒ Object
Date and time when a transaction was authorized in ISO 8601 format (
YYYY-MM-DDTHH:mm:ssZ). -
#business_finance_category ⇒ Object
Returns the value of attribute business_finance_category.
-
#category ⇒ Object
A hierarchical array of the categories to which this transaction belongs.
-
#category_id ⇒ Object
The ID of the category to which this transaction belongs.
-
#check_number ⇒ Object
The check number of the transaction.
-
#client_customization ⇒ Object
Returns the value of attribute client_customization.
-
#counterparties ⇒ Object
The counterparties present in the transaction.
-
#date ⇒ Object
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted.
-
#datetime ⇒ Object
Date and time when a transaction was posted in ISO 8601 format (
YYYY-MM-DDTHH:mm:ssZ). -
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the transaction.
-
#location ⇒ Object
Returns the value of attribute location.
-
#logo_url ⇒ Object
The URL of a logo associated with this transaction, if available.
-
#merchant_category_code ⇒ Object
The merchant category code for the transaction, typically a four-digit ISO 18245 string.
-
#merchant_entity_id ⇒ Object
A unique, stable, Plaid-generated ID that maps to the merchant.
-
#merchant_name ⇒ Object
The merchant name, as enriched by Plaid from the
namefield. -
#name ⇒ Object
The merchant name or transaction description.
-
#original_description ⇒ Object
The string returned by the financial institution to describe the transaction.
-
#payment_channel ⇒ Object
The channel used to make a payment.
-
#payment_meta ⇒ Object
Returns the value of attribute payment_meta.
-
#pending ⇒ Object
When
true, identifies the transaction as pending or unsettled. -
#pending_transaction_id ⇒ Object
The ID of a posted transaction's associated pending transaction, where applicable.
-
#personal_finance_category ⇒ Object
Returns the value of attribute personal_finance_category.
-
#personal_finance_category_icon_url ⇒ Object
The URL of an icon associated with the primary personal finance category.
-
#transaction_code ⇒ Object
Returns the value of attribute transaction_code.
-
#transaction_id ⇒ Object
The unique ID of the transaction.
-
#transaction_type ⇒ Object
Please use the
payment_channelfield,transaction_typewill be deprecated in the future. -
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the transaction.
-
#website ⇒ Object
The website associated with this transaction, if available.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Transaction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Transaction
Initializes the object
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/plaid/models/transaction.rb', line 248 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::Transaction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::Transaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'iso_currency_code') self.iso_currency_code = attributes[:'iso_currency_code'] end if attributes.key?(:'unofficial_currency_code') self.unofficial_currency_code = attributes[:'unofficial_currency_code'] end if attributes.key?(:'category') if (value = attributes[:'category']).is_a?(Array) self.category = value end end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'check_number') self.check_number = attributes[:'check_number'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'location') self.location = attributes[:'location'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'merchant_name') self.merchant_name = attributes[:'merchant_name'] end if attributes.key?(:'original_description') self.original_description = attributes[:'original_description'] end if attributes.key?(:'payment_meta') self. = attributes[:'payment_meta'] end if attributes.key?(:'pending') self.pending = attributes[:'pending'] end if attributes.key?(:'pending_transaction_id') self.pending_transaction_id = attributes[:'pending_transaction_id'] end if attributes.key?(:'account_owner') self.account_owner = attributes[:'account_owner'] end if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'transaction_type') self.transaction_type = attributes[:'transaction_type'] end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] end if attributes.key?(:'website') self.website = attributes[:'website'] end if attributes.key?(:'authorized_date') self. = attributes[:'authorized_date'] end if attributes.key?(:'authorized_datetime') self. = attributes[:'authorized_datetime'] end if attributes.key?(:'datetime') self.datetime = attributes[:'datetime'] end if attributes.key?(:'payment_channel') self.payment_channel = attributes[:'payment_channel'] end if attributes.key?(:'personal_finance_category') self.personal_finance_category = attributes[:'personal_finance_category'] end if attributes.key?(:'business_finance_category') self.business_finance_category = attributes[:'business_finance_category'] end if attributes.key?(:'transaction_code') self.transaction_code = attributes[:'transaction_code'] end if attributes.key?(:'personal_finance_category_icon_url') self.personal_finance_category_icon_url = attributes[:'personal_finance_category_icon_url'] end if attributes.key?(:'counterparties') if (value = attributes[:'counterparties']).is_a?(Array) self.counterparties = value end end if attributes.key?(:'merchant_entity_id') self.merchant_entity_id = attributes[:'merchant_entity_id'] end if attributes.key?(:'merchant_category_code') self.merchant_category_code = attributes[:'merchant_category_code'] end if attributes.key?(:'client_customization') self.client_customization = attributes[:'client_customization'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account in which this transaction occurred.
20 21 22 |
# File 'lib/plaid/models/transaction.rb', line 20 def account_id @account_id end |
#account_owner ⇒ Object
This field is not typically populated and only relevant when dealing with sub-accounts. A sub-account most commonly exists in cases where a single account is linked to multiple cards, each with its own card number and card holder name; each card will be considered a sub-account. If the account does have sub-accounts, this field will typically be some combination of the sub-account owner's name and/or the sub-account mask. The format of this field is not standardized and will vary based on institution.
63 64 65 |
# File 'lib/plaid/models/transaction.rb', line 63 def account_owner @account_owner end |
#amount ⇒ Object
The settled value of the transaction, denominated in the transaction's currency, as stated in iso_currency_code or unofficial_currency_code. For all products except Income: Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative. For Income endpoints, values are positive when representing income.
23 24 25 |
# File 'lib/plaid/models/transaction.rb', line 23 def amount @amount end |
#authorized_date ⇒ Object
The date that the transaction was authorized. For posted transactions, the date field will indicate the posted date, but authorized_date will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the authorized_date, when available, is generally preferable to use over the date field for posted transactions, as it will generally represent the date the user actually made the transaction. Dates are returned in an ISO 8601 format ( YYYY-MM-DD ).
78 79 80 |
# File 'lib/plaid/models/transaction.rb', line 78 def @authorized_date end |
#authorized_datetime ⇒ Object
Date and time when a transaction was authorized in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ). For posted transactions, the datetime field will indicate the posted date, but authorized_datetime will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the authorized_datetime, when available, is generally preferable to use over the datetime field for posted transactions, as it will generally represent the date the user actually made the transaction. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.
81 82 83 |
# File 'lib/plaid/models/transaction.rb', line 81 def @authorized_datetime end |
#business_finance_category ⇒ Object
Returns the value of attribute business_finance_category.
91 92 93 |
# File 'lib/plaid/models/transaction.rb', line 91 def business_finance_category @business_finance_category end |
#category ⇒ Object
A hierarchical array of the categories to which this transaction belongs. For a full list of categories, see /categories/get. All Transactions implementations are recommended to use the new personal_finance_category instead of category, as it provides greater accuracy and more meaningful categorization. If the transactions object was returned by an Assets endpoint such as /asset_report/get or /asset_report/pdf/get, this field will only appear in an Asset Report with Insights.
32 33 34 |
# File 'lib/plaid/models/transaction.rb', line 32 def category @category end |
#category_id ⇒ Object
The ID of the category to which this transaction belongs. For a full list of categories, see /categories/get. All Transactions implementations are recommended to use the new personal_finance_category instead of category, as it provides greater accuracy and more meaningful categorization. If the transactions object was returned by an Assets endpoint such as /asset_report/get or /asset_report/pdf/get, this field will only appear in an Asset Report with Insights.
35 36 37 |
# File 'lib/plaid/models/transaction.rb', line 35 def category_id @category_id end |
#check_number ⇒ Object
The check number of the transaction. This field is only populated for check transactions.
38 39 40 |
# File 'lib/plaid/models/transaction.rb', line 38 def check_number @check_number end |
#client_customization ⇒ Object
Returns the value of attribute client_customization.
107 108 109 |
# File 'lib/plaid/models/transaction.rb', line 107 def client_customization @client_customization end |
#counterparties ⇒ Object
The counterparties present in the transaction. Counterparties, such as the merchant or the financial institution, are extracted by Plaid from the raw description.
99 100 101 |
# File 'lib/plaid/models/transaction.rb', line 99 def counterparties @counterparties end |
#date ⇒ Object
For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an ISO 8601 format ( YYYY-MM-DD ). To receive information about the date that a posted transaction was initiated, see the authorized_date field.
41 42 43 |
# File 'lib/plaid/models/transaction.rb', line 41 def date @date end |
#datetime ⇒ Object
Date and time when a transaction was posted in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ). For the date that the transaction was initiated, rather than posted, see the authorized_datetime field. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.
84 85 86 |
# File 'lib/plaid/models/transaction.rb', line 84 def datetime @datetime end |
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the transaction. Always null if unofficial_currency_code is non-null.
26 27 28 |
# File 'lib/plaid/models/transaction.rb', line 26 def iso_currency_code @iso_currency_code end |
#location ⇒ Object
Returns the value of attribute location.
43 44 45 |
# File 'lib/plaid/models/transaction.rb', line 43 def location @location end |
#logo_url ⇒ Object
The URL of a logo associated with this transaction, if available. The logo will always be a 100×100 pixel PNG file.
72 73 74 |
# File 'lib/plaid/models/transaction.rb', line 72 def logo_url @logo_url end |
#merchant_category_code ⇒ Object
The merchant category code for the transaction, typically a four-digit ISO 18245 string. Not populated for every transaction.
105 106 107 |
# File 'lib/plaid/models/transaction.rb', line 105 def merchant_category_code @merchant_category_code end |
#merchant_entity_id ⇒ Object
A unique, stable, Plaid-generated ID that maps to the merchant. In the case of a merchant with multiple retail locations, this field will map to the broader merchant, not a specific location or store.
102 103 104 |
# File 'lib/plaid/models/transaction.rb', line 102 def merchant_entity_id @merchant_entity_id end |
#merchant_name ⇒ Object
The merchant name, as enriched by Plaid from the name field. This is typically a more human-readable version of the merchant counterparty in the transaction. For some bank transactions (such as checks or account transfers) where there is no meaningful merchant name, this value will be null.
49 50 51 |
# File 'lib/plaid/models/transaction.rb', line 49 def merchant_name @merchant_name end |
#name ⇒ Object
The merchant name or transaction description. Note: While Plaid does not currently plan to remove this field, it is a legacy field that is not actively maintained. Use merchant_name instead for the merchant name. If the transactions object was returned by a Transactions endpoint such as /transactions/sync or /transactions/get, this field will always appear. If the transactions object was returned by an Assets endpoint such as /asset_report/get or /asset_report/pdf/get, this field will only appear in an Asset Report with Insights.
46 47 48 |
# File 'lib/plaid/models/transaction.rb', line 46 def name @name end |
#original_description ⇒ Object
The string returned by the financial institution to describe the transaction. For transactions returned by /transactions/sync or /transactions/get, this field will only be included if the client has set options.include_original_description to true.
52 53 54 |
# File 'lib/plaid/models/transaction.rb', line 52 def original_description @original_description end |
#payment_channel ⇒ Object
The channel used to make a payment. online: transactions that took place online. in store: transactions that were made at a physical location. other: transactions that relate to banks, e.g. fees or deposits. This field replaces the transaction_type field.
87 88 89 |
# File 'lib/plaid/models/transaction.rb', line 87 def payment_channel @payment_channel end |
#payment_meta ⇒ Object
Returns the value of attribute payment_meta.
54 55 56 |
# File 'lib/plaid/models/transaction.rb', line 54 def @payment_meta end |
#pending ⇒ Object
When true, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled. Not all institutions provide pending transactions.
57 58 59 |
# File 'lib/plaid/models/transaction.rb', line 57 def pending @pending end |
#pending_transaction_id ⇒ Object
The ID of a posted transaction's associated pending transaction, where applicable. Not all institutions provide pending transactions.
60 61 62 |
# File 'lib/plaid/models/transaction.rb', line 60 def pending_transaction_id @pending_transaction_id end |
#personal_finance_category ⇒ Object
Returns the value of attribute personal_finance_category.
89 90 91 |
# File 'lib/plaid/models/transaction.rb', line 89 def personal_finance_category @personal_finance_category end |
#personal_finance_category_icon_url ⇒ Object
The URL of an icon associated with the primary personal finance category. The icon will always be a 100×100 pixel PNG file.
96 97 98 |
# File 'lib/plaid/models/transaction.rb', line 96 def personal_finance_category_icon_url @personal_finance_category_icon_url end |
#transaction_code ⇒ Object
Returns the value of attribute transaction_code.
93 94 95 |
# File 'lib/plaid/models/transaction.rb', line 93 def transaction_code @transaction_code end |
#transaction_id ⇒ Object
The unique ID of the transaction. Like all Plaid identifiers, the transaction_id is case sensitive.
66 67 68 |
# File 'lib/plaid/models/transaction.rb', line 66 def transaction_id @transaction_id end |
#transaction_type ⇒ Object
Please use the payment_channel field, transaction_type will be deprecated in the future. digital: transactions that took place online. place: transactions that were made at a physical location. special: transactions that relate to banks, e.g. fees or deposits. unresolved: transactions that do not fit into the other three types.
69 70 71 |
# File 'lib/plaid/models/transaction.rb', line 69 def transaction_type @transaction_type end |
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the transaction. Always null if iso_currency_code is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries. See the currency code schema for a full listing of supported unofficial_currency_codes.
29 30 31 |
# File 'lib/plaid/models/transaction.rb', line 29 def unofficial_currency_code @unofficial_currency_code end |
#website ⇒ Object
The website associated with this transaction, if available.
75 76 77 |
# File 'lib/plaid/models/transaction.rb', line 75 def website @website end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
170 171 172 |
# File 'lib/plaid/models/transaction.rb', line 170 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/plaid/models/transaction.rb', line 132 def self.attribute_map { :'account_id' => :'account_id', :'amount' => :'amount', :'iso_currency_code' => :'iso_currency_code', :'unofficial_currency_code' => :'unofficial_currency_code', :'category' => :'category', :'category_id' => :'category_id', :'check_number' => :'check_number', :'date' => :'date', :'location' => :'location', :'name' => :'name', :'merchant_name' => :'merchant_name', :'original_description' => :'original_description', :'payment_meta' => :'payment_meta', :'pending' => :'pending', :'pending_transaction_id' => :'pending_transaction_id', :'account_owner' => :'account_owner', :'transaction_id' => :'transaction_id', :'transaction_type' => :'transaction_type', :'logo_url' => :'logo_url', :'website' => :'website', :'authorized_date' => :'authorized_date', :'authorized_datetime' => :'authorized_datetime', :'datetime' => :'datetime', :'payment_channel' => :'payment_channel', :'personal_finance_category' => :'personal_finance_category', :'business_finance_category' => :'business_finance_category', :'transaction_code' => :'transaction_code', :'personal_finance_category_icon_url' => :'personal_finance_category_icon_url', :'counterparties' => :'counterparties', :'merchant_entity_id' => :'merchant_entity_id', :'merchant_category_code' => :'merchant_category_code', :'client_customization' => :'client_customization' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
530 531 532 |
# File 'lib/plaid/models/transaction.rb', line 530 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
239 240 241 242 243 244 |
# File 'lib/plaid/models/transaction.rb', line 239 def self.openapi_all_of [ :'TransactionAllOf', :'TransactionBase' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/plaid/models/transaction.rb', line 213 def self.openapi_nullable Set.new([ :'iso_currency_code', :'unofficial_currency_code', :'category', :'category_id', :'check_number', :'merchant_name', :'original_description', :'pending_transaction_id', :'account_owner', :'logo_url', :'website', :'authorized_date', :'authorized_datetime', :'datetime', :'personal_finance_category', :'business_finance_category', :'transaction_code', :'merchant_entity_id', :'merchant_category_code', :'client_customization' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/plaid/models/transaction.rb', line 175 def self.openapi_types { :'account_id' => :'String', :'amount' => :'Float', :'iso_currency_code' => :'String', :'unofficial_currency_code' => :'String', :'category' => :'Array<String>', :'category_id' => :'String', :'check_number' => :'String', :'date' => :'Date', :'location' => :'Location', :'name' => :'String', :'merchant_name' => :'String', :'original_description' => :'String', :'payment_meta' => :'PaymentMeta', :'pending' => :'Boolean', :'pending_transaction_id' => :'String', :'account_owner' => :'String', :'transaction_id' => :'String', :'transaction_type' => :'String', :'logo_url' => :'String', :'website' => :'String', :'authorized_date' => :'Date', :'authorized_datetime' => :'Time', :'datetime' => :'Time', :'payment_channel' => :'String', :'personal_finance_category' => :'PersonalFinanceCategory', :'business_finance_category' => :'BusinessFinanceCategory', :'transaction_code' => :'TransactionCode', :'personal_finance_category_icon_url' => :'String', :'counterparties' => :'Array<TransactionCounterparty>', :'merchant_entity_id' => :'String', :'merchant_category_code' => :'String', :'client_customization' => :'ClientCustomization' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 |
# File 'lib/plaid/models/transaction.rb', line 478 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && amount == o.amount && iso_currency_code == o.iso_currency_code && unofficial_currency_code == o.unofficial_currency_code && category == o.category && category_id == o.category_id && check_number == o.check_number && date == o.date && location == o.location && name == o.name && merchant_name == o.merchant_name && original_description == o.original_description && == o. && pending == o.pending && pending_transaction_id == o.pending_transaction_id && account_owner == o.account_owner && transaction_id == o.transaction_id && transaction_type == o.transaction_type && logo_url == o.logo_url && website == o.website && == o. && == o. && datetime == o.datetime && payment_channel == o.payment_channel && personal_finance_category == o.personal_finance_category && business_finance_category == o.business_finance_category && transaction_code == o.transaction_code && personal_finance_category_icon_url == o.personal_finance_category_icon_url && counterparties == o.counterparties && merchant_entity_id == o.merchant_entity_id && merchant_category_code == o.merchant_category_code && client_customization == o.client_customization end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 |
# File 'lib/plaid/models/transaction.rb', line 561 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/plaid/models/transaction.rb', line 632 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/plaid/models/transaction.rb', line 537 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
517 518 519 |
# File 'lib/plaid/models/transaction.rb', line 517 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
523 524 525 |
# File 'lib/plaid/models/transaction.rb', line 523 def hash [account_id, amount, iso_currency_code, unofficial_currency_code, category, category_id, check_number, date, location, name, merchant_name, original_description, , pending, pending_transaction_id, account_owner, transaction_id, transaction_type, logo_url, website, , , datetime, payment_channel, personal_finance_category, business_finance_category, transaction_code, personal_finance_category_icon_url, counterparties, merchant_entity_id, merchant_category_code, client_customization].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/plaid/models/transaction.rb', line 396 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end if @location.nil? invalid_properties.push('invalid value for "location", location cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @payment_meta.nil? invalid_properties.push('invalid value for "payment_meta", payment_meta cannot be nil.') end if @pending.nil? invalid_properties.push('invalid value for "pending", pending cannot be nil.') end if @transaction_id.nil? invalid_properties.push('invalid value for "transaction_id", transaction_id cannot be nil.') end if @payment_channel.nil? invalid_properties.push('invalid value for "payment_channel", payment_channel cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
608 609 610 |
# File 'lib/plaid/models/transaction.rb', line 608 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/plaid/models/transaction.rb', line 614 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
602 603 604 |
# File 'lib/plaid/models/transaction.rb', line 602 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 |
# File 'lib/plaid/models/transaction.rb', line 439 def valid? return false if @account_id.nil? return false if @amount.nil? return false if @date.nil? return false if @location.nil? return false if @name.nil? return false if @payment_meta.nil? return false if @pending.nil? return false if @transaction_id.nil? transaction_type_validator = EnumAttributeValidator.new('String', ["digital", "place", "special", "unresolved"]) return false unless transaction_type_validator.valid?(@transaction_type) return false if @payment_channel.nil? payment_channel_validator = EnumAttributeValidator.new('String', ["online", "in store", "other"]) return false unless payment_channel_validator.valid?(@payment_channel) true end |