Class: Plaid::TransactionAllOf

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/transaction_all_of.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TransactionAllOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/plaid/models/transaction_all_of.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::TransactionAllOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::TransactionAllOf`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'authorized_date')
    self.authorized_date = attributes[:'authorized_date']
  end

  if attributes.key?(:'authorized_datetime')
    self.authorized_datetime = attributes[:'authorized_datetime']
  end

  if attributes.key?(:'datetime')
    self.datetime = attributes[:'datetime']
  end

  if attributes.key?(:'payment_channel')
    self.payment_channel = attributes[:'payment_channel']
  end

  if attributes.key?(:'personal_finance_category')
    self.personal_finance_category = attributes[:'personal_finance_category']
  end

  if attributes.key?(:'business_finance_category')
    self.business_finance_category = attributes[:'business_finance_category']
  end

  if attributes.key?(:'transaction_code')
    self.transaction_code = attributes[:'transaction_code']
  end

  if attributes.key?(:'personal_finance_category_icon_url')
    self.personal_finance_category_icon_url = attributes[:'personal_finance_category_icon_url']
  end

  if attributes.key?(:'counterparties')
    if (value = attributes[:'counterparties']).is_a?(Array)
      self.counterparties = value
    end
  end

  if attributes.key?(:'merchant_entity_id')
    self.merchant_entity_id = attributes[:'merchant_entity_id']
  end

  if attributes.key?(:'merchant_category_code')
    self.merchant_category_code = attributes[:'merchant_category_code']
  end

  if attributes.key?(:'client_customization')
    self.client_customization = attributes[:'client_customization']
  end
end

Instance Attribute Details

#authorized_dateObject

The date that the transaction was authorized. For posted transactions, the date field will indicate the posted date, but authorized_date will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the authorized_date, when available, is generally preferable to use over the date field for posted transactions, as it will generally represent the date the user actually made the transaction. Dates are returned in an ISO 8601 format ( YYYY-MM-DD ).



19
20
21
# File 'lib/plaid/models/transaction_all_of.rb', line 19

def authorized_date
  @authorized_date
end

#authorized_datetimeObject

Date and time when a transaction was authorized in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ). For posted transactions, the datetime field will indicate the posted date, but authorized_datetime will indicate the day the transaction was authorized by the financial institution. If presenting transactions to the user in a UI, the authorized_datetime, when available, is generally preferable to use over the datetime field for posted transactions, as it will generally represent the date the user actually made the transaction. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.



22
23
24
# File 'lib/plaid/models/transaction_all_of.rb', line 22

def authorized_datetime
  @authorized_datetime
end

#business_finance_categoryObject

Returns the value of attribute business_finance_category.



32
33
34
# File 'lib/plaid/models/transaction_all_of.rb', line 32

def business_finance_category
  @business_finance_category
end

#client_customizationObject

Returns the value of attribute client_customization.



48
49
50
# File 'lib/plaid/models/transaction_all_of.rb', line 48

def client_customization
  @client_customization
end

#counterpartiesObject

The counterparties present in the transaction. Counterparties, such as the merchant or the financial institution, are extracted by Plaid from the raw description.



40
41
42
# File 'lib/plaid/models/transaction_all_of.rb', line 40

def counterparties
  @counterparties
end

#datetimeObject

Date and time when a transaction was posted in ISO 8601 format ( YYYY-MM-DDTHH:mm:ssZ ). For the date that the transaction was initiated, rather than posted, see the authorized_datetime field. This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00). This field is only populated in API version 2019-05-29 and later.



25
26
27
# File 'lib/plaid/models/transaction_all_of.rb', line 25

def datetime
  @datetime
end

#merchant_category_codeObject

The merchant category code for the transaction, typically a four-digit ISO 18245 string. Not populated for every transaction.



46
47
48
# File 'lib/plaid/models/transaction_all_of.rb', line 46

def merchant_category_code
  @merchant_category_code
end

#merchant_entity_idObject

A unique, stable, Plaid-generated ID that maps to the merchant. In the case of a merchant with multiple retail locations, this field will map to the broader merchant, not a specific location or store.



43
44
45
# File 'lib/plaid/models/transaction_all_of.rb', line 43

def merchant_entity_id
  @merchant_entity_id
end

#payment_channelObject

The channel used to make a payment. online: transactions that took place online. in store: transactions that were made at a physical location. other: transactions that relate to banks, e.g. fees or deposits. This field replaces the transaction_type field.



28
29
30
# File 'lib/plaid/models/transaction_all_of.rb', line 28

def payment_channel
  @payment_channel
end

#personal_finance_categoryObject

Returns the value of attribute personal_finance_category.



30
31
32
# File 'lib/plaid/models/transaction_all_of.rb', line 30

def personal_finance_category
  @personal_finance_category
end

#personal_finance_category_icon_urlObject

The URL of an icon associated with the primary personal finance category. The icon will always be a 100×100 pixel PNG file.



37
38
39
# File 'lib/plaid/models/transaction_all_of.rb', line 37

def personal_finance_category_icon_url
  @personal_finance_category_icon_url
end

#transaction_codeObject

Returns the value of attribute transaction_code.



34
35
36
# File 'lib/plaid/models/transaction_all_of.rb', line 34

def transaction_code
  @transaction_code
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/plaid/models/transaction_all_of.rb', line 91

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/plaid/models/transaction_all_of.rb', line 73

def self.attribute_map
  {
    :'authorized_date' => :'authorized_date',
    :'authorized_datetime' => :'authorized_datetime',
    :'datetime' => :'datetime',
    :'payment_channel' => :'payment_channel',
    :'personal_finance_category' => :'personal_finance_category',
    :'business_finance_category' => :'business_finance_category',
    :'transaction_code' => :'transaction_code',
    :'personal_finance_category_icon_url' => :'personal_finance_category_icon_url',
    :'counterparties' => :'counterparties',
    :'merchant_entity_id' => :'merchant_entity_id',
    :'merchant_category_code' => :'merchant_category_code',
    :'client_customization' => :'client_customization'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
# File 'lib/plaid/models/transaction_all_of.rb', line 258

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/plaid/models/transaction_all_of.rb', line 114

def self.openapi_nullable
  Set.new([
    :'authorized_date',
    :'authorized_datetime',
    :'datetime',
    :'personal_finance_category',
    :'business_finance_category',
    :'transaction_code',
    :'merchant_entity_id',
    :'merchant_category_code',
    :'client_customization'
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/plaid/models/transaction_all_of.rb', line 96

def self.openapi_types
  {
    :'authorized_date' => :'Date',
    :'authorized_datetime' => :'Time',
    :'datetime' => :'Time',
    :'payment_channel' => :'String',
    :'personal_finance_category' => :'PersonalFinanceCategory',
    :'business_finance_category' => :'BusinessFinanceCategory',
    :'transaction_code' => :'TransactionCode',
    :'personal_finance_category_icon_url' => :'String',
    :'counterparties' => :'Array<TransactionCounterparty>',
    :'merchant_entity_id' => :'String',
    :'merchant_category_code' => :'String',
    :'client_customization' => :'ClientCustomization'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/plaid/models/transaction_all_of.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authorized_date == o.authorized_date &&
      authorized_datetime == o.authorized_datetime &&
      datetime == o.datetime &&
      payment_channel == o.payment_channel &&
      personal_finance_category == o.personal_finance_category &&
      business_finance_category == o.business_finance_category &&
      transaction_code == o.transaction_code &&
      personal_finance_category_icon_url == o.personal_finance_category_icon_url &&
      counterparties == o.counterparties &&
      merchant_entity_id == o.merchant_entity_id &&
      merchant_category_code == o.merchant_category_code &&
      client_customization == o.client_customization
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/plaid/models/transaction_all_of.rb', line 289

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/plaid/models/transaction_all_of.rb', line 360

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/plaid/models/transaction_all_of.rb', line 265

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/plaid/models/transaction_all_of.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/plaid/models/transaction_all_of.rb', line 251

def hash
  [authorized_date, authorized_datetime, datetime, payment_channel, personal_finance_category, business_finance_category, transaction_code, personal_finance_category_icon_url, counterparties, merchant_entity_id, merchant_category_code, client_customization].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
# File 'lib/plaid/models/transaction_all_of.rb', line 196

def list_invalid_properties
  invalid_properties = Array.new
  if @payment_channel.nil?
    invalid_properties.push('invalid value for "payment_channel", payment_channel cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
# File 'lib/plaid/models/transaction_all_of.rb', line 336

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/plaid/models/transaction_all_of.rb', line 342

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



330
331
332
# File 'lib/plaid/models/transaction_all_of.rb', line 330

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
# File 'lib/plaid/models/transaction_all_of.rb', line 207

def valid?
  return false if @payment_channel.nil?
  payment_channel_validator = EnumAttributeValidator.new('String', ["online", "in store", "other"])
  return false unless payment_channel_validator.valid?(@payment_channel)
  true
end