Class: Plaid::Transfer

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/transfer.rb

Overview

Represents a transfer within the Transfers API.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Transfer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/plaid/models/transfer.rb', line 239

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::Transfer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::Transfer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'authorization_id')
    self.authorization_id = attributes[:'authorization_id']
  end

  if attributes.key?(:'ach_class')
    self.ach_class = attributes[:'ach_class']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'funding_account_id')
    self. = attributes[:'funding_account_id']
  end

  if attributes.key?(:'ledger_id')
    self.ledger_id = attributes[:'ledger_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'sweep_status')
    self.sweep_status = attributes[:'sweep_status']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'wire_details')
    self.wire_details = attributes[:'wire_details']
  end

  if attributes.key?(:'cancellable')
    self.cancellable = attributes[:'cancellable']
  end

  if attributes.key?(:'failure_reason')
    self.failure_reason = attributes[:'failure_reason']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'origination_account_id')
    self. = attributes[:'origination_account_id']
  end

  if attributes.key?(:'guarantee_decision')
    self.guarantee_decision = attributes[:'guarantee_decision']
  end

  if attributes.key?(:'guarantee_decision_rationale')
    self.guarantee_decision_rationale = attributes[:'guarantee_decision_rationale']
  end

  if attributes.key?(:'guarantee_details')
    self.guarantee_details = attributes[:'guarantee_details']
  end

  if attributes.key?(:'iso_currency_code')
    self.iso_currency_code = attributes[:'iso_currency_code']
  end

  if attributes.key?(:'standard_return_window')
    self.standard_return_window = attributes[:'standard_return_window']
  end

  if attributes.key?(:'unauthorized_return_window')
    self.unauthorized_return_window = attributes[:'unauthorized_return_window']
  end

  if attributes.key?(:'expected_settlement_date')
    self.expected_settlement_date = attributes[:'expected_settlement_date']
  end

  if attributes.key?(:'expected_funds_available_date')
    self.expected_funds_available_date = attributes[:'expected_funds_available_date']
  end

  if attributes.key?(:'originator_client_id')
    self.originator_client_id = attributes[:'originator_client_id']
  end

  if attributes.key?(:'refunds')
    if (value = attributes[:'refunds']).is_a?(Array)
      self.refunds = value
    end
  end

  if attributes.key?(:'recurring_transfer_id')
    self.recurring_transfer_id = attributes[:'recurring_transfer_id']
  end

  if attributes.key?(:'expected_sweep_settlement_schedule')
    if (value = attributes[:'expected_sweep_settlement_schedule']).is_a?(Array)
      self.expected_sweep_settlement_schedule = value
    end
  end

  if attributes.key?(:'credit_funds_source')
    self.credit_funds_source = attributes[:'credit_funds_source']
  end

  if attributes.key?(:'facilitator_fee')
    self.facilitator_fee = attributes[:'facilitator_fee']
  end

  if attributes.key?(:'network_trace_id')
    self.network_trace_id = attributes[:'network_trace_id']
  end
end

Instance Attribute Details

#account_idObject

The Plaid ‘account_id` corresponding to the end-user account that will be debited or credited.



28
29
30
# File 'lib/plaid/models/transfer.rb', line 28

def 
  @account_id
end

#ach_classObject

Returns the value of attribute ach_class.



25
26
27
# File 'lib/plaid/models/transfer.rb', line 25

def ach_class
  @ach_class
end

#amountObject

The amount of the transfer (decimal string with two digits of precision e.g. "10.00"). When calling ‘/transfer/authorization/create`, specify the maximum amount to authorize. When calling `/transfer/create`, specify the exact amount of the transfer, up to a maximum of the amount authorized. If this field is left blank when calling `/transfer/create`, the maximum amount authorized in the `authorization_id` will be sent.



41
42
43
# File 'lib/plaid/models/transfer.rb', line 41

def amount
  @amount
end

#authorization_idObject

Plaid’s unique identifier for a transfer authorization.



23
24
25
# File 'lib/plaid/models/transfer.rb', line 23

def authorization_id
  @authorization_id
end

#cancellableObject

When ‘true`, you can still cancel this transfer.



58
59
60
# File 'lib/plaid/models/transfer.rb', line 58

def cancellable
  @cancellable
end

#createdObject

The datetime when this transfer was created. This will be of the form ‘2006-01-02T15:04:05Z`



47
48
49
# File 'lib/plaid/models/transfer.rb', line 47

def created
  @created
end

#credit_funds_sourceObject

Returns the value of attribute credit_funds_source.



101
102
103
# File 'lib/plaid/models/transfer.rb', line 101

def credit_funds_source
  @credit_funds_source
end

#descriptionObject

The description of the transfer.



44
45
46
# File 'lib/plaid/models/transfer.rb', line 44

def description
  @description
end

#expected_funds_available_dateObject

The expected date when funds from a transfer will be made available and can be withdrawn from the associated ledger balance, assuming the debit does not return before this date. If the transfer does return before this date, this field will be null. Only applies to debit transfers. This will be of the form YYYY-MM-DD.



87
88
89
# File 'lib/plaid/models/transfer.rb', line 87

def expected_funds_available_date
  @expected_funds_available_date
end

#expected_settlement_dateObject

Deprecated for Plaid Ledger clients, use ‘expected_funds_available_date` instead.



84
85
86
# File 'lib/plaid/models/transfer.rb', line 84

def expected_settlement_date
  @expected_settlement_date
end

#expected_sweep_settlement_scheduleObject

The expected sweep settlement schedule of this transfer, assuming this transfer is not ‘returned`. Only applies to ACH debit transfers.



99
100
101
# File 'lib/plaid/models/transfer.rb', line 99

def expected_sweep_settlement_schedule
  @expected_sweep_settlement_schedule
end

#facilitator_feeObject

The amount to deduct from ‘transfer.amount` and distribute to the platform’s Ledger balance as a facilitator fee (decimal string with two digits of precision e.g. "10.00"). The remainder will go to the end-customer’s Ledger balance. This must be value greater than 0 and less than or equal to the ‘transfer.amount`.



104
105
106
# File 'lib/plaid/models/transfer.rb', line 104

def facilitator_fee
  @facilitator_fee
end

#failure_reasonObject

Returns the value of attribute failure_reason.



60
61
62
# File 'lib/plaid/models/transfer.rb', line 60

def failure_reason
  @failure_reason
end

#funding_account_idObject

The id of the associated funding account, available in the Plaid Dashboard. If present, this indicates which of your business checking accounts will be credited or debited.



31
32
33
# File 'lib/plaid/models/transfer.rb', line 31

def 
  @funding_account_id
end

#guarantee_decisionObject

Returns the value of attribute guarantee_decision.



68
69
70
# File 'lib/plaid/models/transfer.rb', line 68

def guarantee_decision
  @guarantee_decision
end

#guarantee_decision_rationaleObject

Returns the value of attribute guarantee_decision_rationale.



70
71
72
# File 'lib/plaid/models/transfer.rb', line 70

def guarantee_decision_rationale
  @guarantee_decision_rationale
end

#guarantee_detailsObject

Returns the value of attribute guarantee_details.



72
73
74
# File 'lib/plaid/models/transfer.rb', line 72

def guarantee_details
  @guarantee_details
end

#idObject

Plaid’s unique identifier for a transfer.



20
21
22
# File 'lib/plaid/models/transfer.rb', line 20

def id
  @id
end

#iso_currency_codeObject

The currency of the transfer amount, e.g. "USD"



75
76
77
# File 'lib/plaid/models/transfer.rb', line 75

def iso_currency_code
  @iso_currency_code
end

#ledger_idObject

Plaid’s unique identifier for a Plaid Ledger Balance.



34
35
36
# File 'lib/plaid/models/transfer.rb', line 34

def ledger_id
  @ledger_id
end

#metadataObject

The Metadata object is a mapping of client-provided string fields to any string value. The following limitations apply: The JSON values must be Strings (no nested JSON objects allowed) Only ASCII characters may be used Maximum of 50 key/value pairs Maximum key length of 40 characters Maximum value length of 500 characters



63
64
65
# File 'lib/plaid/models/transfer.rb', line 63

def 
  @metadata
end

#networkObject

Returns the value of attribute network.



53
54
55
# File 'lib/plaid/models/transfer.rb', line 53

def network
  @network
end

#network_trace_idObject

The trace identifier for the transfer based on its network. This will only be set after the transfer has posted. For ‘ach` or `same-day-ach` transfers, this is the ACH trace number. For `rtp` transfers, this is the Transaction Identification number. For `wire` transfers, this is the IMAD (Input Message Accountability Data) number.



107
108
109
# File 'lib/plaid/models/transfer.rb', line 107

def network_trace_id
  @network_trace_id
end

#origination_account_idObject

Plaid’s unique identifier for the origination account that was used for this transfer.



66
67
68
# File 'lib/plaid/models/transfer.rb', line 66

def 
  @origination_account_id
end

#originator_client_idObject

The Plaid client ID that is the originator of this transfer. Only present if created on behalf of another client as a [Platform customer](plaid.com/docs/transfer/application/#originators-vs-platforms).



90
91
92
# File 'lib/plaid/models/transfer.rb', line 90

def originator_client_id
  @originator_client_id
end

#recurring_transfer_idObject

The id of the recurring transfer if this transfer belongs to a recurring transfer.



96
97
98
# File 'lib/plaid/models/transfer.rb', line 96

def recurring_transfer_id
  @recurring_transfer_id
end

#refundsObject

A list of refunds associated with this transfer.



93
94
95
# File 'lib/plaid/models/transfer.rb', line 93

def refunds
  @refunds
end

#standard_return_windowObject

The date 3 business days from settlement date indicating the following ACH returns can no longer happen: R01, R02, R03, R29. This will be of the form YYYY-MM-DD.



78
79
80
# File 'lib/plaid/models/transfer.rb', line 78

def standard_return_window
  @standard_return_window
end

#statusObject

Returns the value of attribute status.



49
50
51
# File 'lib/plaid/models/transfer.rb', line 49

def status
  @status
end

#sweep_statusObject

Returns the value of attribute sweep_status.



51
52
53
# File 'lib/plaid/models/transfer.rb', line 51

def sweep_status
  @sweep_status
end

#typeObject

Returns the value of attribute type.



36
37
38
# File 'lib/plaid/models/transfer.rb', line 36

def type
  @type
end

#unauthorized_return_windowObject

The date 61 business days from settlement date indicating the following ACH returns can no longer happen: R05, R07, R10, R11, R51, R33, R37, R38, R51, R52, R53. This will be of the form YYYY-MM-DD.



81
82
83
# File 'lib/plaid/models/transfer.rb', line 81

def unauthorized_return_window
  @unauthorized_return_window
end

#userObject

Returns the value of attribute user.



38
39
40
# File 'lib/plaid/models/transfer.rb', line 38

def user
  @user
end

#wire_detailsObject

Returns the value of attribute wire_details.



55
56
57
# File 'lib/plaid/models/transfer.rb', line 55

def wire_details
  @wire_details
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



172
173
174
# File 'lib/plaid/models/transfer.rb', line 172

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/plaid/models/transfer.rb', line 132

def self.attribute_map
  {
    :'id' => :'id',
    :'authorization_id' => :'authorization_id',
    :'ach_class' => :'ach_class',
    :'account_id' => :'account_id',
    :'funding_account_id' => :'funding_account_id',
    :'ledger_id' => :'ledger_id',
    :'type' => :'type',
    :'user' => :'user',
    :'amount' => :'amount',
    :'description' => :'description',
    :'created' => :'created',
    :'status' => :'status',
    :'sweep_status' => :'sweep_status',
    :'network' => :'network',
    :'wire_details' => :'wire_details',
    :'cancellable' => :'cancellable',
    :'failure_reason' => :'failure_reason',
    :'metadata' => :'metadata',
    :'origination_account_id' => :'origination_account_id',
    :'guarantee_decision' => :'guarantee_decision',
    :'guarantee_decision_rationale' => :'guarantee_decision_rationale',
    :'guarantee_details' => :'guarantee_details',
    :'iso_currency_code' => :'iso_currency_code',
    :'standard_return_window' => :'standard_return_window',
    :'unauthorized_return_window' => :'unauthorized_return_window',
    :'expected_settlement_date' => :'expected_settlement_date',
    :'expected_funds_available_date' => :'expected_funds_available_date',
    :'originator_client_id' => :'originator_client_id',
    :'refunds' => :'refunds',
    :'recurring_transfer_id' => :'recurring_transfer_id',
    :'expected_sweep_settlement_schedule' => :'expected_sweep_settlement_schedule',
    :'credit_funds_source' => :'credit_funds_source',
    :'facilitator_fee' => :'facilitator_fee',
    :'network_trace_id' => :'network_trace_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



548
549
550
# File 'lib/plaid/models/transfer.rb', line 548

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/plaid/models/transfer.rb', line 217

def self.openapi_nullable
  Set.new([
    :'funding_account_id',
    :'ledger_id',
    :'sweep_status',
    :'wire_details',
    :'failure_reason',
    :'metadata',
    :'guarantee_decision_rationale',
    :'guarantee_details',
    :'standard_return_window',
    :'unauthorized_return_window',
    :'expected_settlement_date',
    :'expected_funds_available_date',
    :'originator_client_id',
    :'recurring_transfer_id',
    :'network_trace_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/plaid/models/transfer.rb', line 177

def self.openapi_types
  {
    :'id' => :'String',
    :'authorization_id' => :'String',
    :'ach_class' => :'ACHClass',
    :'account_id' => :'String',
    :'funding_account_id' => :'String',
    :'ledger_id' => :'String',
    :'type' => :'TransferType',
    :'user' => :'TransferUserInResponse',
    :'amount' => :'String',
    :'description' => :'String',
    :'created' => :'Time',
    :'status' => :'TransferStatus',
    :'sweep_status' => :'TransferSweepStatus',
    :'network' => :'TransferNetwork',
    :'wire_details' => :'TransferWireDetails',
    :'cancellable' => :'Boolean',
    :'failure_reason' => :'TransferFailure',
    :'metadata' => :'Hash<String, String>',
    :'origination_account_id' => :'String',
    :'guarantee_decision' => :'TransferAuthorizationGuaranteeDecision',
    :'guarantee_decision_rationale' => :'TransferAuthorizationGuaranteeDecisionRationale',
    :'guarantee_details' => :'TransferGuaranteeDetails',
    :'iso_currency_code' => :'String',
    :'standard_return_window' => :'Date',
    :'unauthorized_return_window' => :'Date',
    :'expected_settlement_date' => :'Date',
    :'expected_funds_available_date' => :'Date',
    :'originator_client_id' => :'String',
    :'refunds' => :'Array<TransferRefund>',
    :'recurring_transfer_id' => :'String',
    :'expected_sweep_settlement_schedule' => :'Array<TransferExpectedSweepSettlementScheduleItem>',
    :'credit_funds_source' => :'TransferCreditFundsSource',
    :'facilitator_fee' => :'String',
    :'network_trace_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/plaid/models/transfer.rb', line 494

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      authorization_id == o.authorization_id &&
      ach_class == o.ach_class &&
       == o. &&
       == o. &&
      ledger_id == o.ledger_id &&
      type == o.type &&
      user == o.user &&
      amount == o.amount &&
      description == o.description &&
      created == o.created &&
      status == o.status &&
      sweep_status == o.sweep_status &&
      network == o.network &&
      wire_details == o.wire_details &&
      cancellable == o.cancellable &&
      failure_reason == o.failure_reason &&
       == o. &&
       == o. &&
      guarantee_decision == o.guarantee_decision &&
      guarantee_decision_rationale == o.guarantee_decision_rationale &&
      guarantee_details == o.guarantee_details &&
      iso_currency_code == o.iso_currency_code &&
      standard_return_window == o.standard_return_window &&
      unauthorized_return_window == o.unauthorized_return_window &&
      expected_settlement_date == o.expected_settlement_date &&
      expected_funds_available_date == o.expected_funds_available_date &&
      originator_client_id == o.originator_client_id &&
      refunds == o.refunds &&
      recurring_transfer_id == o.recurring_transfer_id &&
      expected_sweep_settlement_schedule == o.expected_sweep_settlement_schedule &&
      credit_funds_source == o.credit_funds_source &&
      facilitator_fee == o.facilitator_fee &&
      network_trace_id == o.network_trace_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
# File 'lib/plaid/models/transfer.rb', line 579

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



650
651
652
653
654
655
656
657
658
659
660
661
662
# File 'lib/plaid/models/transfer.rb', line 650

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/plaid/models/transfer.rb', line 555

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


535
536
537
# File 'lib/plaid/models/transfer.rb', line 535

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



541
542
543
# File 'lib/plaid/models/transfer.rb', line 541

def hash
  [id, authorization_id, ach_class, , , ledger_id, type, user, amount, description, created, status, sweep_status, network, wire_details, cancellable, failure_reason, , , guarantee_decision, guarantee_decision_rationale, guarantee_details, iso_currency_code, standard_return_window, unauthorized_return_window, expected_settlement_date, expected_funds_available_date, originator_client_id, refunds, recurring_transfer_id, expected_sweep_settlement_schedule, credit_funds_source, facilitator_fee, network_trace_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/plaid/models/transfer.rb', line 397

def list_invalid_properties
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @authorization_id.nil?
    invalid_properties.push('invalid value for "authorization_id", authorization_id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @network.nil?
    invalid_properties.push('invalid value for "network", network cannot be nil.')
  end

  if @cancellable.nil?
    invalid_properties.push('invalid value for "cancellable", cancellable cannot be nil.')
  end


  if @origination_account_id.nil?
    invalid_properties.push('invalid value for "origination_account_id", origination_account_id cannot be nil.')
  end

  if @guarantee_decision.nil?
    invalid_properties.push('invalid value for "guarantee_decision", guarantee_decision cannot be nil.')
  end

  if @iso_currency_code.nil?
    invalid_properties.push('invalid value for "iso_currency_code", iso_currency_code cannot be nil.')
  end

  if @refunds.nil?
    invalid_properties.push('invalid value for "refunds", refunds cannot be nil.')
  end

  if @credit_funds_source.nil?
    invalid_properties.push('invalid value for "credit_funds_source", credit_funds_source cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



626
627
628
# File 'lib/plaid/models/transfer.rb', line 626

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



632
633
634
635
636
637
638
639
640
641
642
643
644
# File 'lib/plaid/models/transfer.rb', line 632

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



620
621
622
# File 'lib/plaid/models/transfer.rb', line 620

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
# File 'lib/plaid/models/transfer.rb', line 465

def valid?
  return false if @id.nil?
  return false if @authorization_id.nil?
  return false if @type.nil?
  return false if @user.nil?
  return false if @amount.nil?
  return false if @description.nil?
  return false if @created.nil?
  return false if @status.nil?
  return false if @network.nil?
  return false if @cancellable.nil?
  return false if @metadata.length > 50
  return false if @origination_account_id.nil?
  return false if @guarantee_decision.nil?
  return false if @iso_currency_code.nil?
  return false if @refunds.nil?
  return false if @credit_funds_source.nil?
  true
end