Class: Plaid::TransferAuthorizationCreateRequest
- Inherits:
-
Object
- Object
- Plaid::TransferAuthorizationCreateRequest
- Defined in:
- lib/plaid/models/transfer_authorization_create_request.rb
Overview
Defines the request schema for ‘/transfer/authorization/create`
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_token ⇒ Object
The Plaid ‘access_token` for the account that will be debited or credited.
-
#account_id ⇒ Object
The Plaid ‘account_id` corresponding to the end-user account that will be debited or credited.
-
#ach_class ⇒ Object
Returns the value of attribute ach_class.
-
#amount ⇒ Object
The amount of the transfer (decimal string with two digits of precision e.g. "10.00").
-
#beacon_session_id ⇒ Object
The unique identifier returned by Plaid’s [beacon](plaid.com/docs/transfer/guarantee/#using-a-beacon) when it is run on your webpage.
-
#client_id ⇒ Object
Your Plaid API ‘client_id`.
-
#credit_funds_source ⇒ Object
Returns the value of attribute credit_funds_source.
-
#custom_attributes ⇒ Object
A free-form map of client-supplied risk-relevant context for this authorization.
-
#device ⇒ Object
Returns the value of attribute device.
-
#funding_account_id ⇒ Object
Specify the account used to fund the transfer.
-
#idempotency_key ⇒ Object
A random key provided by the client, per unique authorization, which expires after 48 hours.
-
#iso_currency_code ⇒ Object
The currency of the transfer amount.
-
#ledger_id ⇒ Object
Specify which ledger balance should be used to fund the transfer.
-
#network ⇒ Object
Returns the value of attribute network.
-
#origination_account_id ⇒ Object
Plaid’s unique identifier for the origination account for this authorization.
-
#originator_client_id ⇒ Object
The Plaid client ID that is the originator of this transfer.
-
#payment_profile_token ⇒ Object
The payment profile token associated with the Payment Profile that will be debited or credited.
-
#request_guarantee ⇒ Object
Indicates whether the transfer should be evaluated for guarantee coverage.
-
#ruleset_key ⇒ Object
The key of the Ruleset for the transaction.
-
#secret ⇒ Object
Your Plaid API ‘secret`.
-
#test_clock_id ⇒ Object
Plaid’s unique identifier for a test clock.
-
#type ⇒ Object
Returns the value of attribute type.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_present ⇒ Object
If the end user is initiating the specific transfer themselves via an interactive UI, this should be ‘true`; for automatic recurring payments where the end user is not actually initiating each individual transfer, it should be `false`.
-
#wire_details ⇒ Object
Returns the value of attribute wire_details.
-
#with_guarantee ⇒ Object
If set to ‘false`, Plaid will not offer a `guarantee_decision` for this request (Guarantee customers only).
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TransferAuthorizationCreateRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TransferAuthorizationCreateRequest
Initializes the object
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 201 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::TransferAuthorizationCreateRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::TransferAuthorizationCreateRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'access_token') self.access_token = attributes[:'access_token'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'funding_account_id') self.funding_account_id = attributes[:'funding_account_id'] end if attributes.key?(:'ledger_id') self.ledger_id = attributes[:'ledger_id'] end if attributes.key?(:'payment_profile_token') self.payment_profile_token = attributes[:'payment_profile_token'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'network') self.network = attributes[:'network'] end if attributes.key?(:'amount') self.amount = attributes[:'amount'] end if attributes.key?(:'ach_class') self.ach_class = attributes[:'ach_class'] end if attributes.key?(:'wire_details') self.wire_details = attributes[:'wire_details'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'device') self.device = attributes[:'device'] end if attributes.key?(:'origination_account_id') self.origination_account_id = attributes[:'origination_account_id'] end if attributes.key?(:'iso_currency_code') self.iso_currency_code = attributes[:'iso_currency_code'] end if attributes.key?(:'idempotency_key') self.idempotency_key = attributes[:'idempotency_key'] end if attributes.key?(:'user_present') self.user_present = attributes[:'user_present'] end if attributes.key?(:'with_guarantee') self.with_guarantee = attributes[:'with_guarantee'] else self.with_guarantee = true end if attributes.key?(:'request_guarantee') self.request_guarantee = attributes[:'request_guarantee'] end if attributes.key?(:'beacon_session_id') self.beacon_session_id = attributes[:'beacon_session_id'] end if attributes.key?(:'originator_client_id') self.originator_client_id = attributes[:'originator_client_id'] end if attributes.key?(:'credit_funds_source') self.credit_funds_source = attributes[:'credit_funds_source'] end if attributes.key?(:'test_clock_id') self.test_clock_id = attributes[:'test_clock_id'] end if attributes.key?(:'ruleset_key') self.ruleset_key = attributes[:'ruleset_key'] end if attributes.key?(:'custom_attributes') if (value = attributes[:'custom_attributes']).is_a?(Hash) self.custom_attributes = value end end end |
Instance Attribute Details
#access_token ⇒ Object
The Plaid ‘access_token` for the account that will be debited or credited.
26 27 28 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 26 def access_token @access_token end |
#account_id ⇒ Object
The Plaid ‘account_id` corresponding to the end-user account that will be debited or credited.
29 30 31 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 29 def account_id @account_id end |
#ach_class ⇒ Object
Returns the value of attribute ach_class.
47 48 49 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 47 def ach_class @ach_class end |
#amount ⇒ Object
The amount of the transfer (decimal string with two digits of precision e.g. "10.00"). When calling ‘/transfer/authorization/create`, specify the maximum amount to authorize. When calling `/transfer/create`, specify the exact amount of the transfer, up to a maximum of the amount authorized. If this field is left blank when calling `/transfer/create`, the maximum amount authorized in the `authorization_id` will be sent.
45 46 47 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 45 def amount @amount end |
#beacon_session_id ⇒ Object
The unique identifier returned by Plaid’s [beacon](plaid.com/docs/transfer/guarantee/#using-a-beacon) when it is run on your webpage.
74 75 76 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 74 def beacon_session_id @beacon_session_id end |
#client_id ⇒ Object
Your Plaid API ‘client_id`. The `client_id` is required and may be provided either in the `PLAID-CLIENT-ID` header or as part of a request body.
20 21 22 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 20 def client_id @client_id end |
#credit_funds_source ⇒ Object
Returns the value of attribute credit_funds_source.
79 80 81 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 79 def credit_funds_source @credit_funds_source end |
#custom_attributes ⇒ Object
A free-form map of client-supplied risk-relevant context for this authorization. Plaid may use these attributes to inform future versions of our risk models. The following limitations apply: Keys must match the regular expression ‘^[A-Za-z0-9_.-]1,40$` Values must be strings (no nested objects, arrays, numbers, or booleans allowed; stringify non-string values client-side) Maximum of 50 key/value pairs Maximum value length of 500 characters Do not include personally identifiable information or other sensitive data.
88 89 90 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 88 def custom_attributes @custom_attributes end |
#device ⇒ Object
Returns the value of attribute device.
53 54 55 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 53 def device @device end |
#funding_account_id ⇒ Object
Specify the account used to fund the transfer. Should be specified if using legacy funding methods only. If using Plaid Ledger, leave this field blank. Customers can find a list of ‘funding_account_id`s in the Accounts page of your Plaid Dashboard, under the "Account ID" column. If this field is left blank and you are using legacy funding methods, this will default to the default `funding_account_id` specified during onboarding. Otherwise, Plaid Ledger will be used.
32 33 34 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 32 def funding_account_id @funding_account_id end |
#idempotency_key ⇒ Object
A random key provided by the client, per unique authorization, which expires after 48 hours. Maximum of 50 characters. The API supports idempotency for safely retrying requests without accidentally performing the same operation twice. For example, if a request to create an authorization fails due to a network connection error, you can retry the request with the same idempotency key to guarantee that only a single authorization is created. Idempotency does not apply to authorizations whose decisions are ‘user_action_required`. Therefore you may re-attempt the authorization after completing the required user action without changing `idempotency_key`. This idempotency key expires after 48 hours, after which the same key can be reused. Failure to provide this key may result in duplicate charges.
62 63 64 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 62 def idempotency_key @idempotency_key end |
#iso_currency_code ⇒ Object
The currency of the transfer amount. The default value is "USD".
59 60 61 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 59 def iso_currency_code @iso_currency_code end |
#ledger_id ⇒ Object
Specify which ledger balance should be used to fund the transfer. You can find a list of ‘ledger_id`s in the Accounts page of your Plaid Dashboard. If this field is left blank, this will default to id of the default ledger balance.
35 36 37 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 35 def ledger_id @ledger_id end |
#network ⇒ Object
Returns the value of attribute network.
42 43 44 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 42 def network @network end |
#origination_account_id ⇒ Object
Plaid’s unique identifier for the origination account for this authorization. If not specified, the default account will be used.
56 57 58 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 56 def origination_account_id @origination_account_id end |
#originator_client_id ⇒ Object
The Plaid client ID that is the originator of this transfer. Only needed if creating transfers on behalf of another client as a [Platform customer](plaid.com/docs/transfer/application/#originators-vs-platforms).
77 78 79 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 77 def originator_client_id @originator_client_id end |
#payment_profile_token ⇒ Object
The payment profile token associated with the Payment Profile that will be debited or credited. Required if not using ‘access_token`.
38 39 40 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 38 def payment_profile_token @payment_profile_token end |
#request_guarantee ⇒ Object
Indicates whether the transfer should be evaluated for guarantee coverage. When set to ‘true`, Plaid assesses the transfer for guarantee coverage and returns a decision in the authorization response. When omitted or set to `false`, the authorization is evaluated without guarantee coverage.
71 72 73 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 71 def request_guarantee @request_guarantee end |
#ruleset_key ⇒ Object
The key of the Ruleset for the transaction. If not provided, Signal will use the ‘default` ruleset.
85 86 87 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 85 def ruleset_key @ruleset_key end |
#secret ⇒ Object
Your Plaid API ‘secret`. The `secret` is required and may be provided either in the `PLAID-SECRET` header or as part of a request body.
23 24 25 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 23 def secret @secret end |
#test_clock_id ⇒ Object
Plaid’s unique identifier for a test clock. This field may only be used when using ‘sandbox` environment. If provided, the `authorization` is created at the `virtual_time` on the provided test clock.
82 83 84 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 82 def test_clock_id @test_clock_id end |
#type ⇒ Object
Returns the value of attribute type.
40 41 42 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 40 def type @type end |
#user ⇒ Object
Returns the value of attribute user.
51 52 53 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 51 def user @user end |
#user_present ⇒ Object
If the end user is initiating the specific transfer themselves via an interactive UI, this should be ‘true`; for automatic recurring payments where the end user is not actually initiating each individual transfer, it should be `false`. This field is not currently used and is present to support planned future functionality.
65 66 67 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 65 def user_present @user_present end |
#wire_details ⇒ Object
Returns the value of attribute wire_details.
49 50 51 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 49 def wire_details @wire_details end |
#with_guarantee ⇒ Object
If set to ‘false`, Plaid will not offer a `guarantee_decision` for this request (Guarantee customers only). This field is deprecated in favor for `guarantee`.
68 69 70 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 68 def with_guarantee @with_guarantee end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
145 146 147 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 145 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 113 def self.attribute_map { :'client_id' => :'client_id', :'secret' => :'secret', :'access_token' => :'access_token', :'account_id' => :'account_id', :'funding_account_id' => :'funding_account_id', :'ledger_id' => :'ledger_id', :'payment_profile_token' => :'payment_profile_token', :'type' => :'type', :'network' => :'network', :'amount' => :'amount', :'ach_class' => :'ach_class', :'wire_details' => :'wire_details', :'user' => :'user', :'device' => :'device', :'origination_account_id' => :'origination_account_id', :'iso_currency_code' => :'iso_currency_code', :'idempotency_key' => :'idempotency_key', :'user_present' => :'user_present', :'with_guarantee' => :'with_guarantee', :'request_guarantee' => :'request_guarantee', :'beacon_session_id' => :'beacon_session_id', :'originator_client_id' => :'originator_client_id', :'credit_funds_source' => :'credit_funds_source', :'test_clock_id' => :'test_clock_id', :'ruleset_key' => :'ruleset_key', :'custom_attributes' => :'custom_attributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
440 441 442 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 440 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 182 def self.openapi_nullable Set.new([ :'funding_account_id', :'ledger_id', :'wire_details', :'idempotency_key', :'user_present', :'with_guarantee', :'request_guarantee', :'beacon_session_id', :'originator_client_id', :'test_clock_id', :'ruleset_key', :'custom_attributes' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 150 def self.openapi_types { :'client_id' => :'String', :'secret' => :'String', :'access_token' => :'String', :'account_id' => :'String', :'funding_account_id' => :'String', :'ledger_id' => :'String', :'payment_profile_token' => :'String', :'type' => :'TransferType', :'network' => :'TransferNetwork', :'amount' => :'String', :'ach_class' => :'ACHClass', :'wire_details' => :'TransferWireDetails', :'user' => :'TransferAuthorizationUserInRequest', :'device' => :'TransferAuthorizationDevice', :'origination_account_id' => :'String', :'iso_currency_code' => :'String', :'idempotency_key' => :'String', :'user_present' => :'Boolean', :'with_guarantee' => :'Boolean', :'request_guarantee' => :'Boolean', :'beacon_session_id' => :'String', :'originator_client_id' => :'String', :'credit_funds_source' => :'TransferCreditFundsSource', :'test_clock_id' => :'String', :'ruleset_key' => :'String', :'custom_attributes' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 394 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && secret == o.secret && access_token == o.access_token && account_id == o.account_id && funding_account_id == o.funding_account_id && ledger_id == o.ledger_id && payment_profile_token == o.payment_profile_token && type == o.type && network == o.network && amount == o.amount && ach_class == o.ach_class && wire_details == o.wire_details && user == o.user && device == o.device && origination_account_id == o.origination_account_id && iso_currency_code == o.iso_currency_code && idempotency_key == o.idempotency_key && user_present == o.user_present && with_guarantee == o.with_guarantee && request_guarantee == o.request_guarantee && beacon_session_id == o.beacon_session_id && originator_client_id == o.originator_client_id && credit_funds_source == o.credit_funds_source && test_clock_id == o.test_clock_id && ruleset_key == o.ruleset_key && custom_attributes == o.custom_attributes end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 471 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 542 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 447 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
427 428 429 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 427 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
433 434 435 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 433 def hash [client_id, secret, access_token, account_id, funding_account_id, ledger_id, payment_profile_token, type, network, amount, ach_class, wire_details, user, device, origination_account_id, iso_currency_code, idempotency_key, user_present, with_guarantee, request_guarantee, beacon_session_id, originator_client_id, credit_funds_source, test_clock_id, ruleset_key, custom_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 325 def list_invalid_properties invalid_properties = Array.new if @access_token.nil? invalid_properties.push('invalid value for "access_token", access_token cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @network.nil? invalid_properties.push('invalid value for "network", network cannot be nil.') end if @amount.nil? invalid_properties.push('invalid value for "amount", amount cannot be nil.') end if @user.nil? invalid_properties.push('invalid value for "user", user cannot be nil.') end if !@idempotency_key.nil? && @idempotency_key.to_s.length > 50 invalid_properties.push('invalid value for "idempotency_key", the character length must be smaller than or equal to 50.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
518 519 520 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 518 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 524 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
512 513 514 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 512 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/plaid/models/transfer_authorization_create_request.rb', line 362 def valid? return false if @access_token.nil? return false if @account_id.nil? return false if @type.nil? return false if @network.nil? return false if @amount.nil? return false if @user.nil? return false if !@idempotency_key.nil? && @idempotency_key.to_s.length > 50 return false if !@custom_attributes.nil? && @custom_attributes.length > 50 true end |