Class: Plaid::TransferAuthorizationProposedTransfer

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/transfer_authorization_proposed_transfer.rb

Overview

Details regarding the proposed transfer.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TransferAuthorizationProposedTransfer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::TransferAuthorizationProposedTransfer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::TransferAuthorizationProposedTransfer`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ach_class')
    self.ach_class = attributes[:'ach_class']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'funding_account_id')
    self. = attributes[:'funding_account_id']
  end

  if attributes.key?(:'ledger_id')
    self.ledger_id = attributes[:'ledger_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'requested_amount')
    self.requested_amount = attributes[:'requested_amount']
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  end

  if attributes.key?(:'wire_details')
    self.wire_details = attributes[:'wire_details']
  end

  if attributes.key?(:'origination_account_id')
    self. = attributes[:'origination_account_id']
  end

  if attributes.key?(:'iso_currency_code')
    self.iso_currency_code = attributes[:'iso_currency_code']
  end

  if attributes.key?(:'originator_client_id')
    self.originator_client_id = attributes[:'originator_client_id']
  end

  if attributes.key?(:'credit_funds_source')
    self.credit_funds_source = attributes[:'credit_funds_source']
  end
end

Instance Attribute Details

#account_idObject

The Plaid ‘account_id` for the account that will be debited or credited.



22
23
24
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 22

def 
  @account_id
end

#ach_classObject

Returns the value of attribute ach_class.



19
20
21
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 19

def ach_class
  @ach_class
end

#amountObject

The amount of the transfer (decimal string with two digits of precision e.g. "10.00"). When calling ‘/transfer/authorization/create`, specify the maximum amount to authorize. When calling `/transfer/create`, specify the exact amount of the transfer, up to a maximum of the amount authorized. If this field is left blank when calling `/transfer/create`, the maximum amount authorized in the `authorization_id` will be sent.



35
36
37
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 35

def amount
  @amount
end

#credit_funds_sourceObject

Returns the value of attribute credit_funds_source.



54
55
56
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 54

def credit_funds_source
  @credit_funds_source
end

#funding_account_idObject

The id of the associated funding account, available in the Plaid Dashboard. If present, this indicates which of your business checking accounts will be credited or debited.



25
26
27
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 25

def 
  @funding_account_id
end

#iso_currency_codeObject

The currency of the transfer amount. The default value is "USD".



49
50
51
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 49

def iso_currency_code
  @iso_currency_code
end

#ledger_idObject

Plaid’s unique identifier for a Plaid Ledger Balance.



28
29
30
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 28

def ledger_id
  @ledger_id
end

#networkObject

The network or rails used for the transfer.



41
42
43
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 41

def network
  @network
end

#origination_account_idObject

Plaid’s unique identifier for the origination account that was used for this transfer.



46
47
48
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 46

def 
  @origination_account_id
end

#originator_client_idObject

The Plaid client ID that is the originator of this transfer. Only present if created on behalf of another client as a [Platform customer](plaid.com/docs/transfer/application/#originators-vs-platforms).



52
53
54
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 52

def originator_client_id
  @originator_client_id
end

#requested_amountObject

The amount originally requested by the client when creating the authorization (decimal string with two digits of precision e.g. "800.00"). This may differ from ‘amount`, the amount Plaid proposes to transfer, when only a partial amount is offered as part of an Adaptive Guarantee.



38
39
40
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 38

def requested_amount
  @requested_amount
end

#typeObject

Returns the value of attribute type.



30
31
32
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 30

def type
  @type
end

#userObject

Returns the value of attribute user.



32
33
34
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 32

def user
  @user
end

#wire_detailsObject

Returns the value of attribute wire_details.



43
44
45
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 43

def wire_details
  @wire_details
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 99

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 79

def self.attribute_map
  {
    :'ach_class' => :'ach_class',
    :'account_id' => :'account_id',
    :'funding_account_id' => :'funding_account_id',
    :'ledger_id' => :'ledger_id',
    :'type' => :'type',
    :'user' => :'user',
    :'amount' => :'amount',
    :'requested_amount' => :'requested_amount',
    :'network' => :'network',
    :'wire_details' => :'wire_details',
    :'origination_account_id' => :'origination_account_id',
    :'iso_currency_code' => :'iso_currency_code',
    :'originator_client_id' => :'originator_client_id',
    :'credit_funds_source' => :'credit_funds_source'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



294
295
296
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 294

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
128
129
130
131
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 124

def self.openapi_nullable
  Set.new([
    :'funding_account_id',
    :'ledger_id',
    :'wire_details',
    :'originator_client_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 104

def self.openapi_types
  {
    :'ach_class' => :'ACHClass',
    :'account_id' => :'String',
    :'funding_account_id' => :'String',
    :'ledger_id' => :'String',
    :'type' => :'TransferType',
    :'user' => :'TransferUserInResponse',
    :'amount' => :'String',
    :'requested_amount' => :'String',
    :'network' => :'String',
    :'wire_details' => :'TransferWireDetails',
    :'origination_account_id' => :'String',
    :'iso_currency_code' => :'String',
    :'originator_client_id' => :'String',
    :'credit_funds_source' => :'TransferCreditFundsSource'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 260

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ach_class == o.ach_class &&
       == o. &&
       == o. &&
      ledger_id == o.ledger_id &&
      type == o.type &&
      user == o.user &&
      amount == o.amount &&
      requested_amount == o.requested_amount &&
      network == o.network &&
      wire_details == o.wire_details &&
       == o. &&
      iso_currency_code == o.iso_currency_code &&
      originator_client_id == o.originator_client_id &&
      credit_funds_source == o.credit_funds_source
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 325

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 396

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 301

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


281
282
283
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 281

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



287
288
289
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 287

def hash
  [ach_class, , , ledger_id, type, user, amount, requested_amount, network, wire_details, , iso_currency_code, originator_client_id, credit_funds_source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 207

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @requested_amount.nil?
    invalid_properties.push('invalid value for "requested_amount", requested_amount cannot be nil.')
  end

  if @network.nil?
    invalid_properties.push('invalid value for "network", network cannot be nil.')
  end

  if @origination_account_id.nil?
    invalid_properties.push('invalid value for "origination_account_id", origination_account_id cannot be nil.')
  end

  if @iso_currency_code.nil?
    invalid_properties.push('invalid value for "iso_currency_code", iso_currency_code cannot be nil.')
  end

  if @credit_funds_source.nil?
    invalid_properties.push('invalid value for "credit_funds_source", credit_funds_source cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



372
373
374
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 372

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 378

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



366
367
368
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 366

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
# File 'lib/plaid/models/transfer_authorization_proposed_transfer.rb', line 246

def valid?
  return false if @type.nil?
  return false if @user.nil?
  return false if @amount.nil?
  return false if @requested_amount.nil?
  return false if @network.nil?
  return false if @origination_account_id.nil?
  return false if @iso_currency_code.nil?
  return false if @credit_funds_source.nil?
  true
end