Class: Plaid::TransferGuaranteeOutcome
- Inherits:
-
Object
- Object
- Plaid::TransferGuaranteeOutcome
- Defined in:
- lib/plaid/models/transfer_guarantee_outcome.rb
Constant Summary collapse
- FULL_INSTANT =
"FULL_INSTANT".freeze
- PARTIAL_INSTANT_ONLY =
"PARTIAL_INSTANT_ONLY".freeze
- PARTIAL_INSTANT_WITH_OBSERVATION_WINDOW =
"PARTIAL_INSTANT_WITH_OBSERVATION_WINDOW".freeze
- NOT_GUARANTEED =
"NOT_GUARANTEED".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
26 27 28 |
# File 'lib/plaid/models/transfer_guarantee_outcome.rb', line 26 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
33 34 35 36 37 38 |
# File 'lib/plaid/models/transfer_guarantee_outcome.rb', line 33 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |