Class: Plaid::UserBasedProducts

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/user_based_products.rb

Constant Summary collapse

CRA_BASE_REPORT =
"cra_base_report".freeze
CRA_INCOME_INSIGHTS =
"cra_income_insights".freeze
CRA_PARTNER_INSIGHTS =
"cra_partner_insights".freeze
CRA_NETWORK_INSIGHTS =
"cra_network_insights".freeze
CRA_CASHFLOW_INSIGHTS =
"cra_cashflow_insights".freeze
CRA_MONITORING =
"cra_monitoring".freeze
CRA_LEND_SCORE =
"cra_lend_score".freeze
CRA_PLAID_CREDIT_SCORE =
"cra_plaid_credit_score".freeze
INVESTMENTS =
"investments".freeze
LIABILITIES =
"liabilities".freeze
PROTECT_LINKED_BANK =
"protect_linked_bank".freeze
PROTECT_TRANSACTIONS =
"protect_transactions".freeze
TRANSACTIONS =
"transactions".freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



35
36
37
# File 'lib/plaid/models/user_based_products.rb', line 35

def self.build_from_hash(value)
  new.build_from_hash(value)
end

Instance Method Details

#build_from_hash(value) ⇒ String

Builds the enum from string

Parameters:

  • The (String)

    enum value in the form of the string

Returns:

  • (String)

    The enum value



42
43
44
45
46
47
# File 'lib/plaid/models/user_based_products.rb', line 42

def build_from_hash(value)
  # We do not validate that the value is one of the enums set in the OpenAPI
  # file because we want to be able to add to our list of enums without
  # breaking this client library.
  value
end