Class: Plaid::WalletTransaction

Inherits:
Object
  • Object
show all
Defined in:
lib/plaid/models/wallet_transaction.rb

Overview

The transaction details

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WalletTransaction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/plaid/models/wallet_transaction.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::WalletTransaction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::WalletTransaction`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'transaction_id')
    self.transaction_id = attributes[:'transaction_id']
  end

  if attributes.key?(:'wallet_id')
    self.wallet_id = attributes[:'wallet_id']
  end

  if attributes.key?(:'reference')
    self.reference = attributes[:'reference']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'scheme')
    self.scheme = attributes[:'scheme']
  end

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  end

  if attributes.key?(:'counterparty')
    self.counterparty = attributes[:'counterparty']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'last_status_update')
    self.last_status_update = attributes[:'last_status_update']
  end

  if attributes.key?(:'payee_verification_status')
    self.payee_verification_status = attributes[:'payee_verification_status']
  end

  if attributes.key?(:'payment_id')
    self.payment_id = attributes[:'payment_id']
  end

  if attributes.key?(:'failure_reason')
    self.failure_reason = attributes[:'failure_reason']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'related_transactions')
    if (value = attributes[:'related_transactions']).is_a?(Array)
      self.related_transactions = value
    end
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



33
34
35
# File 'lib/plaid/models/wallet_transaction.rb', line 33

def amount
  @amount
end

#counterpartyObject

Returns the value of attribute counterparty.



35
36
37
# File 'lib/plaid/models/wallet_transaction.rb', line 35

def counterparty
  @counterparty
end

#created_atObject

Timestamp when the transaction was created, in [ISO 8601](wikipedia.org/wiki/ISO_8601) format.



40
41
42
# File 'lib/plaid/models/wallet_transaction.rb', line 40

def created_at
  @created_at
end

#errorObject

Returns the value of attribute error.



52
53
54
# File 'lib/plaid/models/wallet_transaction.rb', line 52

def error
  @error
end

#failure_reasonObject

Returns the value of attribute failure_reason.



50
51
52
# File 'lib/plaid/models/wallet_transaction.rb', line 50

def failure_reason
  @failure_reason
end

#last_status_updateObject

The date and time of the last time the ‘status` was updated, in IS0 8601 format



43
44
45
# File 'lib/plaid/models/wallet_transaction.rb', line 43

def last_status_update
  @last_status_update
end

#payee_verification_statusObject

Returns the value of attribute payee_verification_status.



45
46
47
# File 'lib/plaid/models/wallet_transaction.rb', line 45

def payee_verification_status
  @payee_verification_status
end

#payment_idObject

The payment id that this transaction is associated with, if any. This is present only for transaction types ‘PIS_PAY_IN` and `REFUND`.



48
49
50
# File 'lib/plaid/models/wallet_transaction.rb', line 48

def payment_id
  @payment_id
end

#referenceObject

A reference for the transaction



26
27
28
# File 'lib/plaid/models/wallet_transaction.rb', line 26

def reference
  @reference
end

A list of wallet transactions that this transaction is associated with, if any.



55
56
57
# File 'lib/plaid/models/wallet_transaction.rb', line 55

def related_transactions
  @related_transactions
end

#schemeObject

Returns the value of attribute scheme.



31
32
33
# File 'lib/plaid/models/wallet_transaction.rb', line 31

def scheme
  @scheme
end

#statusObject

Returns the value of attribute status.



37
38
39
# File 'lib/plaid/models/wallet_transaction.rb', line 37

def status
  @status
end

#transaction_idObject

A unique ID identifying the transaction



20
21
22
# File 'lib/plaid/models/wallet_transaction.rb', line 20

def transaction_id
  @transaction_id
end

#typeObject

The type of the transaction. The supported transaction types that are returned are: ‘BANK_TRANSFER:` a transaction which credits an e-wallet through an external bank transfer. `PAYOUT:` a transaction which debits an e-wallet by disbursing funds to a counterparty. `PIS_PAY_IN:` a payment which credits an e-wallet through Plaid’s Payment Initiation Services (PIS) APIs. For more information see the [Payment Initiation endpoints](plaid.com/docs/api/products/payment-initiation/). ‘REFUND:` a transaction which debits an e-wallet by refunding a previously initiated payment made through Plaid’s [PIS APIs](plaid.com/docs/api/products/payment-initiation/). ‘FUNDS_SWEEP`: an automated transaction which debits funds from an e-wallet to a designated client-owned account. `RETURN`: an automated transaction where a debit transaction was reversed and money moved back to originating account. `RECALL`: a transaction where the sending bank has requested the return of funds due to a fraud claim, technical error, or other issue associated with the payment.



29
30
31
# File 'lib/plaid/models/wallet_transaction.rb', line 29

def type
  @type
end

#wallet_idObject

The EMI (E-Money Institution) wallet that this payment is associated with, if any. This wallet is used as an intermediary account to enable Plaid to reconcile the settlement of funds for Payment Initiation requests.



23
24
25
# File 'lib/plaid/models/wallet_transaction.rb', line 23

def wallet_id
  @wallet_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/plaid/models/wallet_transaction.rb', line 101

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/plaid/models/wallet_transaction.rb', line 80

def self.attribute_map
  {
    :'transaction_id' => :'transaction_id',
    :'wallet_id' => :'wallet_id',
    :'reference' => :'reference',
    :'type' => :'type',
    :'scheme' => :'scheme',
    :'amount' => :'amount',
    :'counterparty' => :'counterparty',
    :'status' => :'status',
    :'created_at' => :'created_at',
    :'last_status_update' => :'last_status_update',
    :'payee_verification_status' => :'payee_verification_status',
    :'payment_id' => :'payment_id',
    :'failure_reason' => :'failure_reason',
    :'error' => :'error',
    :'related_transactions' => :'related_transactions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



322
323
324
# File 'lib/plaid/models/wallet_transaction.rb', line 322

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
131
132
133
134
135
# File 'lib/plaid/models/wallet_transaction.rb', line 127

def self.openapi_nullable
  Set.new([
    :'scheme',
    :'payee_verification_status',
    :'payment_id',
    :'failure_reason',
    :'error',
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/plaid/models/wallet_transaction.rb', line 106

def self.openapi_types
  {
    :'transaction_id' => :'String',
    :'wallet_id' => :'String',
    :'reference' => :'String',
    :'type' => :'String',
    :'scheme' => :'WalletPaymentScheme',
    :'amount' => :'WalletTransactionAmount',
    :'counterparty' => :'WalletTransactionCounterparty',
    :'status' => :'WalletTransactionStatus',
    :'created_at' => :'Time',
    :'last_status_update' => :'Time',
    :'payee_verification_status' => :'WalletTransactionPayeeVerificationStatus',
    :'payment_id' => :'String',
    :'failure_reason' => :'WalletTransactionFailureReason',
    :'error' => :'PlaidError',
    :'related_transactions' => :'Array<WalletTransactionRelation>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/plaid/models/wallet_transaction.rb', line 287

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      transaction_id == o.transaction_id &&
      wallet_id == o.wallet_id &&
      reference == o.reference &&
      type == o.type &&
      scheme == o.scheme &&
      amount == o.amount &&
      counterparty == o.counterparty &&
      status == o.status &&
      created_at == o.created_at &&
      last_status_update == o.last_status_update &&
      payee_verification_status == o.payee_verification_status &&
      payment_id == o.payment_id &&
      failure_reason == o.failure_reason &&
      error == o.error &&
      related_transactions == o.related_transactions
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/plaid/models/wallet_transaction.rb', line 353

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Plaid.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/plaid/models/wallet_transaction.rb', line 424

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/plaid/models/wallet_transaction.rb', line 329

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


309
310
311
# File 'lib/plaid/models/wallet_transaction.rb', line 309

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



315
316
317
# File 'lib/plaid/models/wallet_transaction.rb', line 315

def hash
  [transaction_id, wallet_id, reference, type, scheme, amount, counterparty, status, created_at, last_status_update, payee_verification_status, payment_id, failure_reason, error, related_transactions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/plaid/models/wallet_transaction.rb', line 217

def list_invalid_properties
  invalid_properties = Array.new
  if @transaction_id.nil?
    invalid_properties.push('invalid value for "transaction_id", transaction_id cannot be nil.')
  end

  if @wallet_id.nil?
    invalid_properties.push('invalid value for "wallet_id", wallet_id cannot be nil.')
  end

  if @reference.nil?
    invalid_properties.push('invalid value for "reference", reference cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @counterparty.nil?
    invalid_properties.push('invalid value for "counterparty", counterparty cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @last_status_update.nil?
    invalid_properties.push('invalid value for "last_status_update", last_status_update cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



400
401
402
# File 'lib/plaid/models/wallet_transaction.rb', line 400

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/plaid/models/wallet_transaction.rb', line 406

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



394
395
396
# File 'lib/plaid/models/wallet_transaction.rb', line 394

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/plaid/models/wallet_transaction.rb', line 260

def valid?
  return false if @transaction_id.nil?
  return false if @wallet_id.nil?
  return false if @reference.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["BANK_TRANSFER", "PAYOUT", "PIS_PAY_IN", "REFUND", "FUNDS_SWEEP", "RETURN", "RECALL"])
  return false unless type_validator.valid?(@type)
  return false if @amount.nil?
  return false if @counterparty.nil?
  return false if @status.nil?
  return false if @created_at.nil?
  return false if @last_status_update.nil?
  true
end