Method: Plaid::LinkTokenCreateRequestAuth#auth_type_select_enabled
- Defined in:
- lib/plaid/models/link_token_create_request_auth.rb
#auth_type_select_enabled ⇒ Object
Specifies whether Auth Type Select is enabled for the Link session, allowing the end user to choose between linking via a credentials-based flow (i.e. Instant Auth, Instant Match, Automated Micro-deposits) or a manual flow that does not require login (all other Auth flows) prior to selecting their financial institution. Default behavior is false.
20 21 22 |
# File 'lib/plaid/models/link_token_create_request_auth.rb', line 20 def auth_type_select_enabled @auth_type_select_enabled end |