Class: Plaid::CraBankIncomeSource
- Inherits:
-
Object
- Object
- Plaid::CraBankIncomeSource
- Defined in:
- lib/plaid/models/cra_bank_income_source.rb
Overview
Detailed information for the income source.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account ID with which this income source is associated.
-
#employer ⇒ Object
Returns the value of attribute employer.
-
#end_date ⇒ Object
Maximum of all dates within the specific income sources in the user’s bank account for days requested by the client.
-
#forecasted_average_monthly_income ⇒ Object
The predicted average monthly net income amount for the income source(s).
-
#forecasted_average_monthly_income_prediction_intervals ⇒ Object
The prediction interval(s) for the forecasted average monthly income.
-
#historical_average_monthly_gross_income ⇒ Object
An estimate of the average gross monthly income based on the historical net amount and income category for the income source(s).
-
#historical_average_monthly_income ⇒ Object
The average monthly net income amount estimated based on the historical data for the income source(s).
-
#historical_summary ⇒ Object
Returns the value of attribute historical_summary.
-
#income_category ⇒ Object
Returns the value of attribute income_category.
-
#income_description ⇒ Object
The most common name or original description for the underlying income transactions.
-
#income_provider ⇒ Object
Returns the value of attribute income_provider.
-
#income_source_id ⇒ Object
A unique identifier for an income source.
-
#iso_currency_code ⇒ Object
The ISO 4217 currency code of the amount or balance.
-
#next_payment_date ⇒ Object
The expected date of the end user’s next paycheck for the income source.
-
#pay_frequency ⇒ Object
Returns the value of attribute pay_frequency.
-
#start_date ⇒ Object
Minimum of all dates within the specific income sources in the user’s bank account for days requested by the client.
-
#status ⇒ Object
Returns the value of attribute status.
-
#total_amount ⇒ Object
Total amount of earnings in the user’s bank account for the specific income source for days requested by the client.
-
#transaction_count ⇒ Object
Number of transactions for the income source within the start and end date.
-
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the amount or balance.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CraBankIncomeSource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CraBankIncomeSource
Initializes the object
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 167 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::CraBankIncomeSource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::CraBankIncomeSource`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'income_source_id') self.income_source_id = attributes[:'income_source_id'] end if attributes.key?(:'income_description') self.income_description = attributes[:'income_description'] end if attributes.key?(:'income_category') self.income_category = attributes[:'income_category'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'pay_frequency') self.pay_frequency = attributes[:'pay_frequency'] end if attributes.key?(:'total_amount') self.total_amount = attributes[:'total_amount'] end if attributes.key?(:'iso_currency_code') self.iso_currency_code = attributes[:'iso_currency_code'] end if attributes.key?(:'unofficial_currency_code') self.unofficial_currency_code = attributes[:'unofficial_currency_code'] end if attributes.key?(:'transaction_count') self.transaction_count = attributes[:'transaction_count'] end if attributes.key?(:'next_payment_date') self.next_payment_date = attributes[:'next_payment_date'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'historical_average_monthly_gross_income') self.historical_average_monthly_gross_income = attributes[:'historical_average_monthly_gross_income'] end if attributes.key?(:'historical_average_monthly_income') self.historical_average_monthly_income = attributes[:'historical_average_monthly_income'] end if attributes.key?(:'forecasted_average_monthly_income') self.forecasted_average_monthly_income = attributes[:'forecasted_average_monthly_income'] end if attributes.key?(:'forecasted_average_monthly_income_prediction_intervals') if (value = attributes[:'forecasted_average_monthly_income_prediction_intervals']).is_a?(Array) self.forecasted_average_monthly_income_prediction_intervals = value end end if attributes.key?(:'employer') self.employer = attributes[:'employer'] end if attributes.key?(:'income_provider') self.income_provider = attributes[:'income_provider'] end if attributes.key?(:'historical_summary') if (value = attributes[:'historical_summary']).is_a?(Array) self.historical_summary = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The account ID with which this income source is associated.
20 21 22 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 20 def account_id @account_id end |
#employer ⇒ Object
Returns the value of attribute employer.
67 68 69 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 67 def employer @employer end |
#end_date ⇒ Object
Maximum of all dates within the specific income sources in the user’s bank account for days requested by the client. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
34 35 36 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 34 def end_date @end_date end |
#forecasted_average_monthly_income ⇒ Object
The predicted average monthly net income amount for the income source(s).
62 63 64 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 62 def forecasted_average_monthly_income @forecasted_average_monthly_income end |
#forecasted_average_monthly_income_prediction_intervals ⇒ Object
The prediction interval(s) for the forecasted average monthly income.
65 66 67 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 65 def forecasted_average_monthly_income_prediction_intervals @forecasted_average_monthly_income_prediction_intervals end |
#historical_average_monthly_gross_income ⇒ Object
An estimate of the average gross monthly income based on the historical net amount and income category for the income source(s).
56 57 58 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 56 def historical_average_monthly_gross_income @historical_average_monthly_gross_income end |
#historical_average_monthly_income ⇒ Object
The average monthly net income amount estimated based on the historical data for the income source(s).
59 60 61 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 59 def historical_average_monthly_income @historical_average_monthly_income end |
#historical_summary ⇒ Object
Returns the value of attribute historical_summary.
71 72 73 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 71 def historical_summary @historical_summary end |
#income_category ⇒ Object
Returns the value of attribute income_category.
28 29 30 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 28 def income_category @income_category end |
#income_description ⇒ Object
The most common name or original description for the underlying income transactions.
26 27 28 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 26 def income_description @income_description end |
#income_provider ⇒ Object
Returns the value of attribute income_provider.
69 70 71 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 69 def income_provider @income_provider end |
#income_source_id ⇒ Object
A unique identifier for an income source. If the report is regenerated and a new ‘report_id` is created, the new report will have a new set of `income_source_id`s.
23 24 25 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 23 def income_source_id @income_source_id end |
#iso_currency_code ⇒ Object
The ISO 4217 currency code of the amount or balance.
42 43 44 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 42 def iso_currency_code @iso_currency_code end |
#next_payment_date ⇒ Object
The expected date of the end user’s next paycheck for the income source. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
51 52 53 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 51 def next_payment_date @next_payment_date end |
#pay_frequency ⇒ Object
Returns the value of attribute pay_frequency.
36 37 38 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 36 def pay_frequency @pay_frequency end |
#start_date ⇒ Object
Minimum of all dates within the specific income sources in the user’s bank account for days requested by the client. The date will be returned in an ISO 8601 format (YYYY-MM-DD).
31 32 33 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 31 def start_date @start_date end |
#status ⇒ Object
Returns the value of attribute status.
53 54 55 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 53 def status @status end |
#total_amount ⇒ Object
Total amount of earnings in the user’s bank account for the specific income source for days requested by the client.
39 40 41 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 39 def total_amount @total_amount end |
#transaction_count ⇒ Object
Number of transactions for the income source within the start and end date.
48 49 50 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 48 def transaction_count @transaction_count end |
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the amount or balance. Always ‘null` if `iso_currency_code` is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.
45 46 47 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 45 def unofficial_currency_code @unofficial_currency_code end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
122 123 124 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 122 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 96 def self.attribute_map { :'account_id' => :'account_id', :'income_source_id' => :'income_source_id', :'income_description' => :'income_description', :'income_category' => :'income_category', :'start_date' => :'start_date', :'end_date' => :'end_date', :'pay_frequency' => :'pay_frequency', :'total_amount' => :'total_amount', :'iso_currency_code' => :'iso_currency_code', :'unofficial_currency_code' => :'unofficial_currency_code', :'transaction_count' => :'transaction_count', :'next_payment_date' => :'next_payment_date', :'status' => :'status', :'historical_average_monthly_gross_income' => :'historical_average_monthly_gross_income', :'historical_average_monthly_income' => :'historical_average_monthly_income', :'forecasted_average_monthly_income' => :'forecasted_average_monthly_income', :'forecasted_average_monthly_income_prediction_intervals' => :'forecasted_average_monthly_income_prediction_intervals', :'employer' => :'employer', :'income_provider' => :'income_provider', :'historical_summary' => :'historical_summary' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
325 326 327 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 325 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 153 def self.openapi_nullable Set.new([ :'iso_currency_code', :'unofficial_currency_code', :'next_payment_date', :'historical_average_monthly_gross_income', :'historical_average_monthly_income', :'forecasted_average_monthly_income', :'income_provider', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 127 def self.openapi_types { :'account_id' => :'String', :'income_source_id' => :'String', :'income_description' => :'String', :'income_category' => :'CreditBankIncomeCategory', :'start_date' => :'Date', :'end_date' => :'Date', :'pay_frequency' => :'CreditBankIncomePayFrequency', :'total_amount' => :'Float', :'iso_currency_code' => :'String', :'unofficial_currency_code' => :'String', :'transaction_count' => :'Integer', :'next_payment_date' => :'Date', :'status' => :'CraBankIncomeStatus', :'historical_average_monthly_gross_income' => :'Float', :'historical_average_monthly_income' => :'Float', :'forecasted_average_monthly_income' => :'Float', :'forecasted_average_monthly_income_prediction_intervals' => :'Array<CraPredictionInterval>', :'employer' => :'CraBankIncomeEmployer', :'income_provider' => :'CraBankIncomeIncomeProvider', :'historical_summary' => :'Array<CraBankIncomeHistoricalSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 285 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && income_source_id == o.income_source_id && income_description == o.income_description && income_category == o.income_category && start_date == o.start_date && end_date == o.end_date && pay_frequency == o.pay_frequency && total_amount == o.total_amount && iso_currency_code == o.iso_currency_code && unofficial_currency_code == o.unofficial_currency_code && transaction_count == o.transaction_count && next_payment_date == o.next_payment_date && status == o.status && historical_average_monthly_gross_income == o.historical_average_monthly_gross_income && historical_average_monthly_income == o.historical_average_monthly_income && forecasted_average_monthly_income == o.forecasted_average_monthly_income && forecasted_average_monthly_income_prediction_intervals == o.forecasted_average_monthly_income_prediction_intervals && employer == o.employer && income_provider == o.income_provider && historical_summary == o.historical_summary end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 356 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 427 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 332 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
312 313 314 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 312 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
318 319 320 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 318 def hash [account_id, income_source_id, income_description, income_category, start_date, end_date, pay_frequency, total_amount, iso_currency_code, unofficial_currency_code, transaction_count, next_payment_date, status, historical_average_monthly_gross_income, historical_average_monthly_income, forecasted_average_monthly_income, forecasted_average_monthly_income_prediction_intervals, employer, income_provider, historical_summary].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
267 268 269 270 271 272 273 274 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 267 def list_invalid_properties invalid_properties = Array.new if @forecasted_average_monthly_income_prediction_intervals.nil? invalid_properties.push('invalid value for "forecasted_average_monthly_income_prediction_intervals", forecasted_average_monthly_income_prediction_intervals cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
403 404 405 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 403 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 409 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
397 398 399 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 397 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
278 279 280 281 |
# File 'lib/plaid/models/cra_bank_income_source.rb', line 278 def valid? return false if @forecasted_average_monthly_income_prediction_intervals.nil? true end |