Class: Plaid::Holding
- Inherits:
-
Object
- Object
- Plaid::Holding
- Defined in:
- lib/plaid/models/holding.rb
Overview
A securities holding at an institution.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The Plaid ‘account_id` associated with the holding.
-
#cost_basis ⇒ Object
The total cost basis of the holding (e.g., the total amount spent to acquire all assets currently in the holding).
-
#institution_price ⇒ Object
The last price given by the institution for this security.
-
#institution_price_as_of ⇒ Object
The date at which ‘institution_price` was current.
-
#institution_price_datetime ⇒ Object
Date and time at which ‘institution_price` was current, in ISO 8601 format (YYYY-MM-DDTHH:mm:ssZ).
-
#institution_value ⇒ Object
The value of the holding, as reported by the institution.
-
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the holding.
-
#quantity ⇒ Object
The total quantity of the asset held, as reported by the financial institution.
-
#security_id ⇒ Object
The Plaid ‘security_id` associated with the holding.
-
#tax_lots ⇒ Object
Per-lot acquisition data for this holding.
-
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the holding.
-
#vested_quantity ⇒ Object
The total quantity of vested assets held, as reported by the financial institution.
-
#vested_value ⇒ Object
The value of the vested holdings as reported by the institution.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Holding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Holding
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/plaid/models/holding.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::Holding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::Holding`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'security_id') self.security_id = attributes[:'security_id'] end if attributes.key?(:'institution_price') self.institution_price = attributes[:'institution_price'] end if attributes.key?(:'institution_price_as_of') self.institution_price_as_of = attributes[:'institution_price_as_of'] end if attributes.key?(:'institution_price_datetime') self.institution_price_datetime = attributes[:'institution_price_datetime'] end if attributes.key?(:'institution_value') self.institution_value = attributes[:'institution_value'] end if attributes.key?(:'cost_basis') self.cost_basis = attributes[:'cost_basis'] end if attributes.key?(:'quantity') self.quantity = attributes[:'quantity'] end if attributes.key?(:'iso_currency_code') self.iso_currency_code = attributes[:'iso_currency_code'] end if attributes.key?(:'unofficial_currency_code') self.unofficial_currency_code = attributes[:'unofficial_currency_code'] end if attributes.key?(:'vested_quantity') self.vested_quantity = attributes[:'vested_quantity'] end if attributes.key?(:'vested_value') self.vested_value = attributes[:'vested_value'] end if attributes.key?(:'tax_lots') if (value = attributes[:'tax_lots']).is_a?(Array) self.tax_lots = value end end end |
Instance Attribute Details
#account_id ⇒ Object
The Plaid ‘account_id` associated with the holding.
20 21 22 |
# File 'lib/plaid/models/holding.rb', line 20 def account_id @account_id end |
#cost_basis ⇒ Object
The total cost basis of the holding (e.g., the total amount spent to acquire all assets currently in the holding).
38 39 40 |
# File 'lib/plaid/models/holding.rb', line 38 def cost_basis @cost_basis end |
#institution_price ⇒ Object
The last price given by the institution for this security.
26 27 28 |
# File 'lib/plaid/models/holding.rb', line 26 def institution_price @institution_price end |
#institution_price_as_of ⇒ Object
The date at which ‘institution_price` was current.
29 30 31 |
# File 'lib/plaid/models/holding.rb', line 29 def institution_price_as_of @institution_price_as_of end |
#institution_price_datetime ⇒ Object
Date and time at which ‘institution_price` was current, in ISO 8601 format (YYYY-MM-DDTHH:mm:ssZ). This field is returned for select financial institutions and comes as provided by the institution. It may contain default time values (such as 00:00:00).
32 33 34 |
# File 'lib/plaid/models/holding.rb', line 32 def institution_price_datetime @institution_price_datetime end |
#institution_value ⇒ Object
The value of the holding, as reported by the institution.
35 36 37 |
# File 'lib/plaid/models/holding.rb', line 35 def institution_value @institution_value end |
#iso_currency_code ⇒ Object
The ISO-4217 currency code of the holding. Always ‘null` if `unofficial_currency_code` is non-`null`.
44 45 46 |
# File 'lib/plaid/models/holding.rb', line 44 def iso_currency_code @iso_currency_code end |
#quantity ⇒ Object
The total quantity of the asset held, as reported by the financial institution. If the security is an option, ‘quantity` will reflect the total number of options (typically the number of contracts multiplied by 100), not the number of contracts.
41 42 43 |
# File 'lib/plaid/models/holding.rb', line 41 def quantity @quantity end |
#security_id ⇒ Object
The Plaid ‘security_id` associated with the holding. Security data is not specific to a user’s account; any user who held the same security at the same financial institution at the same time would have identical security data. The ‘security_id` for the same security will typically be the same across different institutions, but this is not guaranteed. The `security_id` does not typically change, but may change if inherent details of the security change due to a corporate action, for example, in the event of a ticker symbol change or CUSIP change.
23 24 25 |
# File 'lib/plaid/models/holding.rb', line 23 def security_id @security_id end |
#tax_lots ⇒ Object
Per-lot acquisition data for this holding. An empty array indicates the institution does not provide lot-level data.
56 57 58 |
# File 'lib/plaid/models/holding.rb', line 56 def tax_lots @tax_lots end |
#unofficial_currency_code ⇒ Object
The unofficial currency code associated with the holding. Always ‘null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries. See the [currency code schema](plaid.com/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.
47 48 49 |
# File 'lib/plaid/models/holding.rb', line 47 def unofficial_currency_code @unofficial_currency_code end |
#vested_quantity ⇒ Object
The total quantity of vested assets held, as reported by the financial institution. Vested assets are only associated with [equities](plaid.com/docs/api/products/investments/#investments-holdings-get-response-securities-type).
50 51 52 |
# File 'lib/plaid/models/holding.rb', line 50 def vested_quantity @vested_quantity end |
#vested_value ⇒ Object
The value of the vested holdings as reported by the institution.
53 54 55 |
# File 'lib/plaid/models/holding.rb', line 53 def vested_value @vested_value end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/plaid/models/holding.rb', line 78 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/plaid/models/holding.rb', line 59 def self.attribute_map { :'account_id' => :'account_id', :'security_id' => :'security_id', :'institution_price' => :'institution_price', :'institution_price_as_of' => :'institution_price_as_of', :'institution_price_datetime' => :'institution_price_datetime', :'institution_value' => :'institution_value', :'cost_basis' => :'cost_basis', :'quantity' => :'quantity', :'iso_currency_code' => :'iso_currency_code', :'unofficial_currency_code' => :'unofficial_currency_code', :'vested_quantity' => :'vested_quantity', :'vested_value' => :'vested_value', :'tax_lots' => :'tax_lots' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 |
# File 'lib/plaid/models/holding.rb', line 257 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/plaid/models/holding.rb', line 102 def self.openapi_nullable Set.new([ :'institution_price_as_of', :'institution_price_datetime', :'cost_basis', :'iso_currency_code', :'unofficial_currency_code', :'vested_quantity', :'vested_value', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/plaid/models/holding.rb', line 83 def self.openapi_types { :'account_id' => :'String', :'security_id' => :'String', :'institution_price' => :'Float', :'institution_price_as_of' => :'Date', :'institution_price_datetime' => :'Time', :'institution_value' => :'Float', :'cost_basis' => :'Float', :'quantity' => :'Float', :'iso_currency_code' => :'String', :'unofficial_currency_code' => :'String', :'vested_quantity' => :'Float', :'vested_value' => :'Float', :'tax_lots' => :'Array<HoldingTaxLot>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/plaid/models/holding.rb', line 224 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && security_id == o.security_id && institution_price == o.institution_price && institution_price_as_of == o.institution_price_as_of && institution_price_datetime == o.institution_price_datetime && institution_value == o.institution_value && cost_basis == o.cost_basis && quantity == o.quantity && iso_currency_code == o.iso_currency_code && unofficial_currency_code == o.unofficial_currency_code && vested_quantity == o.vested_quantity && vested_value == o.vested_value && tax_lots == o.tax_lots end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/plaid/models/holding.rb', line 288 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/plaid/models/holding.rb', line 359 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/plaid/models/holding.rb', line 264 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
244 245 246 |
# File 'lib/plaid/models/holding.rb', line 244 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
250 251 252 |
# File 'lib/plaid/models/holding.rb', line 250 def hash [account_id, security_id, institution_price, institution_price_as_of, institution_price_datetime, institution_value, cost_basis, quantity, iso_currency_code, unofficial_currency_code, vested_quantity, vested_value, tax_lots].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/plaid/models/holding.rb', line 186 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @security_id.nil? invalid_properties.push('invalid value for "security_id", security_id cannot be nil.') end if @institution_price.nil? invalid_properties.push('invalid value for "institution_price", institution_price cannot be nil.') end if @institution_value.nil? invalid_properties.push('invalid value for "institution_value", institution_value cannot be nil.') end if @quantity.nil? invalid_properties.push('invalid value for "quantity", quantity cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
335 336 337 |
# File 'lib/plaid/models/holding.rb', line 335 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/plaid/models/holding.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
329 330 331 |
# File 'lib/plaid/models/holding.rb', line 329 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 |
# File 'lib/plaid/models/holding.rb', line 213 def valid? return false if @account_id.nil? return false if @security_id.nil? return false if @institution_price.nil? return false if @institution_value.nil? return false if @quantity.nil? true end |