Class: Plaid::LoanLiability
- Inherits:
-
Object
- Object
- Plaid::LoanLiability
- Defined in:
- lib/plaid/models/loan_liability.rb
Overview
Contains details about a closed-end loan account.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The ID of the account that this liability belongs to.
-
#account_number ⇒ Object
The account number of the loan.
-
#compounding_period ⇒ Object
Returns the value of attribute compounding_period.
-
#interest_rate ⇒ Object
Returns the value of attribute interest_rate.
-
#last_payment_amount ⇒ Object
The amount of the most recent payment.
-
#last_payment_date ⇒ Object
The date of the most recent payment, in ISO 8601 format (YYYY-MM-DD).
-
#loan_term_months ⇒ Object
The length of the loan term in months.
-
#maturity_date ⇒ Object
The date on which the loan is scheduled to be fully paid, in ISO 8601 format (YYYY-MM-DD).
-
#next_payment_amount ⇒ Object
The amount of the next scheduled payment.
-
#next_payment_due_date ⇒ Object
The due date of the next payment, in ISO 8601 format (YYYY-MM-DD).
-
#origination_date ⇒ Object
The date on which the loan was originated, in ISO 8601 format (YYYY-MM-DD).
-
#origination_principal_amount ⇒ Object
The original principal amount of the loan.
-
#payment_count ⇒ Object
The total number of payments scheduled for the loan.
-
#payment_frequency ⇒ Object
Returns the value of attribute payment_frequency.
-
#payoff_amount ⇒ Object
The amount required to fully pay off the loan.
-
#principal_balance ⇒ Object
The outstanding principal balance of the loan.
-
#ytd_interest_paid ⇒ Object
The year-to-date interest paid on the loan.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LoanLiability
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ LoanLiability
Initializes the object
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/plaid/models/loan_liability.rb', line 164 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Plaid::LoanLiability` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Plaid::LoanLiability`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_number') self.account_number = attributes[:'account_number'] end if attributes.key?(:'interest_rate') self.interest_rate = attributes[:'interest_rate'] end if attributes.key?(:'principal_balance') self.principal_balance = attributes[:'principal_balance'] end if attributes.key?(:'origination_principal_amount') self.origination_principal_amount = attributes[:'origination_principal_amount'] end if attributes.key?(:'origination_date') self.origination_date = attributes[:'origination_date'] end if attributes.key?(:'loan_term_months') self.loan_term_months = attributes[:'loan_term_months'] end if attributes.key?(:'maturity_date') self.maturity_date = attributes[:'maturity_date'] end if attributes.key?(:'payment_count') self.payment_count = attributes[:'payment_count'] end if attributes.key?(:'payment_frequency') self.payment_frequency = attributes[:'payment_frequency'] end if attributes.key?(:'next_payment_amount') self.next_payment_amount = attributes[:'next_payment_amount'] end if attributes.key?(:'next_payment_due_date') self.next_payment_due_date = attributes[:'next_payment_due_date'] end if attributes.key?(:'last_payment_amount') self.last_payment_amount = attributes[:'last_payment_amount'] end if attributes.key?(:'last_payment_date') self.last_payment_date = attributes[:'last_payment_date'] end if attributes.key?(:'payoff_amount') self.payoff_amount = attributes[:'payoff_amount'] end if attributes.key?(:'ytd_interest_paid') self.ytd_interest_paid = attributes[:'ytd_interest_paid'] end if attributes.key?(:'compounding_period') self.compounding_period = attributes[:'compounding_period'] end end |
Instance Attribute Details
#account_id ⇒ Object
The ID of the account that this liability belongs to.
20 21 22 |
# File 'lib/plaid/models/loan_liability.rb', line 20 def account_id @account_id end |
#account_number ⇒ Object
The account number of the loan. For some institutions, this may be a masked version of the number (e.g., the last 4 digits instead of the entire number).
23 24 25 |
# File 'lib/plaid/models/loan_liability.rb', line 23 def account_number @account_number end |
#compounding_period ⇒ Object
Returns the value of attribute compounding_period.
65 66 67 |
# File 'lib/plaid/models/loan_liability.rb', line 65 def compounding_period @compounding_period end |
#interest_rate ⇒ Object
Returns the value of attribute interest_rate.
25 26 27 |
# File 'lib/plaid/models/loan_liability.rb', line 25 def interest_rate @interest_rate end |
#last_payment_amount ⇒ Object
The amount of the most recent payment.
54 55 56 |
# File 'lib/plaid/models/loan_liability.rb', line 54 def last_payment_amount @last_payment_amount end |
#last_payment_date ⇒ Object
The date of the most recent payment, in ISO 8601 format (YYYY-MM-DD).
57 58 59 |
# File 'lib/plaid/models/loan_liability.rb', line 57 def last_payment_date @last_payment_date end |
#loan_term_months ⇒ Object
The length of the loan term in months.
37 38 39 |
# File 'lib/plaid/models/loan_liability.rb', line 37 def loan_term_months @loan_term_months end |
#maturity_date ⇒ Object
The date on which the loan is scheduled to be fully paid, in ISO 8601 format (YYYY-MM-DD).
40 41 42 |
# File 'lib/plaid/models/loan_liability.rb', line 40 def maturity_date @maturity_date end |
#next_payment_amount ⇒ Object
The amount of the next scheduled payment.
48 49 50 |
# File 'lib/plaid/models/loan_liability.rb', line 48 def next_payment_amount @next_payment_amount end |
#next_payment_due_date ⇒ Object
The due date of the next payment, in ISO 8601 format (YYYY-MM-DD).
51 52 53 |
# File 'lib/plaid/models/loan_liability.rb', line 51 def next_payment_due_date @next_payment_due_date end |
#origination_date ⇒ Object
The date on which the loan was originated, in ISO 8601 format (YYYY-MM-DD).
34 35 36 |
# File 'lib/plaid/models/loan_liability.rb', line 34 def origination_date @origination_date end |
#origination_principal_amount ⇒ Object
The original principal amount of the loan.
31 32 33 |
# File 'lib/plaid/models/loan_liability.rb', line 31 def origination_principal_amount @origination_principal_amount end |
#payment_count ⇒ Object
The total number of payments scheduled for the loan.
43 44 45 |
# File 'lib/plaid/models/loan_liability.rb', line 43 def payment_count @payment_count end |
#payment_frequency ⇒ Object
Returns the value of attribute payment_frequency.
45 46 47 |
# File 'lib/plaid/models/loan_liability.rb', line 45 def payment_frequency @payment_frequency end |
#payoff_amount ⇒ Object
The amount required to fully pay off the loan.
60 61 62 |
# File 'lib/plaid/models/loan_liability.rb', line 60 def payoff_amount @payoff_amount end |
#principal_balance ⇒ Object
The outstanding principal balance of the loan.
28 29 30 |
# File 'lib/plaid/models/loan_liability.rb', line 28 def principal_balance @principal_balance end |
#ytd_interest_paid ⇒ Object
The year-to-date interest paid on the loan.
63 64 65 |
# File 'lib/plaid/models/loan_liability.rb', line 63 def ytd_interest_paid @ytd_interest_paid end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/plaid/models/loan_liability.rb', line 113 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/plaid/models/loan_liability.rb', line 90 def self.attribute_map { :'account_id' => :'account_id', :'account_number' => :'account_number', :'interest_rate' => :'interest_rate', :'principal_balance' => :'principal_balance', :'origination_principal_amount' => :'origination_principal_amount', :'origination_date' => :'origination_date', :'loan_term_months' => :'loan_term_months', :'maturity_date' => :'maturity_date', :'payment_count' => :'payment_count', :'payment_frequency' => :'payment_frequency', :'next_payment_amount' => :'next_payment_amount', :'next_payment_due_date' => :'next_payment_due_date', :'last_payment_amount' => :'last_payment_amount', :'last_payment_date' => :'last_payment_date', :'payoff_amount' => :'payoff_amount', :'ytd_interest_paid' => :'ytd_interest_paid', :'compounding_period' => :'compounding_period' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
303 304 305 |
# File 'lib/plaid/models/loan_liability.rb', line 303 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/plaid/models/loan_liability.rb', line 141 def self.openapi_nullable Set.new([ :'account_number', :'interest_rate', :'principal_balance', :'origination_principal_amount', :'origination_date', :'loan_term_months', :'maturity_date', :'payment_count', :'payment_frequency', :'next_payment_amount', :'next_payment_due_date', :'last_payment_amount', :'last_payment_date', :'payoff_amount', :'ytd_interest_paid', :'compounding_period' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/plaid/models/loan_liability.rb', line 118 def self.openapi_types { :'account_id' => :'String', :'account_number' => :'String', :'interest_rate' => :'LoanInterestRate', :'principal_balance' => :'Float', :'origination_principal_amount' => :'Float', :'origination_date' => :'Date', :'loan_term_months' => :'Integer', :'maturity_date' => :'Date', :'payment_count' => :'Integer', :'payment_frequency' => :'LoanPaymentFrequency', :'next_payment_amount' => :'Float', :'next_payment_due_date' => :'Date', :'last_payment_amount' => :'Float', :'last_payment_date' => :'Date', :'payoff_amount' => :'Float', :'ytd_interest_paid' => :'Float', :'compounding_period' => :'LoanCompoundingPeriod' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/plaid/models/loan_liability.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && account_number == o.account_number && interest_rate == o.interest_rate && principal_balance == o.principal_balance && origination_principal_amount == o.origination_principal_amount && origination_date == o.origination_date && loan_term_months == o.loan_term_months && maturity_date == o.maturity_date && payment_count == o.payment_count && payment_frequency == o.payment_frequency && next_payment_amount == o.next_payment_amount && next_payment_due_date == o.next_payment_due_date && last_payment_amount == o.last_payment_amount && last_payment_date == o.last_payment_date && payoff_amount == o.payoff_amount && ytd_interest_paid == o.ytd_interest_paid && compounding_period == o.compounding_period end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/plaid/models/loan_liability.rb', line 334 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Plaid.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/plaid/models/loan_liability.rb', line 405 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/plaid/models/loan_liability.rb', line 310 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
290 291 292 |
# File 'lib/plaid/models/loan_liability.rb', line 290 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
296 297 298 |
# File 'lib/plaid/models/loan_liability.rb', line 296 def hash [account_id, account_number, interest_rate, principal_balance, origination_principal_amount, origination_date, loan_term_months, maturity_date, payment_count, payment_frequency, next_payment_amount, next_payment_due_date, last_payment_amount, last_payment_date, payoff_amount, ytd_interest_paid, compounding_period].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
248 249 250 251 252 253 254 255 |
# File 'lib/plaid/models/loan_liability.rb', line 248 def list_invalid_properties invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
381 382 383 |
# File 'lib/plaid/models/loan_liability.rb', line 381 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/plaid/models/loan_liability.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
375 376 377 |
# File 'lib/plaid/models/loan_liability.rb', line 375 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 |
# File 'lib/plaid/models/loan_liability.rb', line 259 def valid? return false if @account_id.nil? true end |