Class: Plaid::WalletTransactionFailureReason
- Inherits:
-
Object
- Object
- Plaid::WalletTransactionFailureReason
- Defined in:
- lib/plaid/models/wallet_transaction_failure_reason.rb
Constant Summary collapse
- EXTERNAL_SYSTEM =
"EXTERNAL_SYSTEM".freeze
- EXPIRED =
"EXPIRED".freeze
- CANCELLED =
"CANCELLED".freeze
- INVALID =
"INVALID".freeze
- ACCOUNT_INVALID =
"ACCOUNT_INVALID".freeze
- AUTHENTICATION_FAILED =
"AUTHENTICATION_FAILED".freeze
- UNKNOWN =
"UNKNOWN".freeze
Class Method Summary collapse
-
.build_from_hash(value) ⇒ String
Builds the enum from string.
Instance Method Summary collapse
-
#build_from_hash(value) ⇒ String
Builds the enum from string.
Class Method Details
.build_from_hash(value) ⇒ String
Builds the enum from string
29 30 31 |
# File 'lib/plaid/models/wallet_transaction_failure_reason.rb', line 29 def self.build_from_hash(value) new.build_from_hash(value) end |
Instance Method Details
#build_from_hash(value) ⇒ String
Builds the enum from string
36 37 38 39 40 41 |
# File 'lib/plaid/models/wallet_transaction_failure_reason.rb', line 36 def build_from_hash(value) # We do not validate that the value is one of the enums set in the OpenAPI # file because we want to be able to add to our list of enums without # breaking this client library. value end |